{-# LANGUAGE OverloadedStrings #-}
-- | Automatically generated syntax definition for Fortran (Fixed Format).
-- DO NOT EDIT THIS FILE MANUALLY.
-- Instead, modify xml/fortran-fixed.xml and 'make bootstrap'.
module Skylighting.Syntax.FortranFixed (syntax) where

import Skylighting.Types
import Data.Binary

-- | Syntax definition for Fortran (Fixed Format).
syntax :: Syntax
syntax = decode "\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNFortran (Fixed Format)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1fortran-fixed.xml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFortranFixed\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIelemental_procs\NUL\NUL\NUL\NUL\NUL\NUL\NULz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXabs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcabs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdabs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTiabs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQaimag\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTaint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQanint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdnint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aceiling\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcmplx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdcmplx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdimag\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfloor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTnint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKidnint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQidint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTifix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTreal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfloat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsngl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdble\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdreal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKaprime\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdconjg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdfloat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQddmim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTrand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmodulo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQconjg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdprod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTddim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTidim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmax\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQamax0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQamax1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmax0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmax1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdmax1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQamin0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQamin1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmin0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmin1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdmin1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTamod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdmod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsign\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdsign\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQisign\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTacos\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdacos\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTasin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdasin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTatan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdatan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQatan2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdatan2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcos\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTccos\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdcos\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcosh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdcosh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXexp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcexp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdexp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTalog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdlog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTclog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlog10\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKalog10\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdlog10\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcsin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdsin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsinh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdsinh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsqrt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcsqrt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdsqrt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXtan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdtan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtanh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdtanh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQachar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTchar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKiachar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQichar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlge\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlgt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXllt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aadjustl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aadjustr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQindex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\blen_trim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTscan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKverify\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\alogical\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bexponent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bfraction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\anearest\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\trrspacing\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQscale\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fset_exponent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aspacing\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbtest\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTiand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQibclr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQibits\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQibset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTieor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXior\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQishft\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKishftc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXnot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmvbits\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmerge\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEinquire_keywords\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTunit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKiostat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXerr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQexist\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKopened\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKnumber\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQnamed\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTname\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKaccess\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nsequential\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdirect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTform\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tformatted\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vunformatted\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTrecl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\anextrec\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQblank\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bposition\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKaction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTread\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwrite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\treadwrite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdelim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXpad\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ninquiry_fn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nassociated\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apresent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTkind\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdigits\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aepsilon\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOThuge\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vmaxexponent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vminexponent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tprecision\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQradix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrange\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtiny\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bbit_size\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tallocated\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlbound\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKubound\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQshape\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fio_functions\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKaccess\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tbackspace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQclose\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ainquire\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTopen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQprint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTread\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrewind\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwrite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKformat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vio_keywords\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTunit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXerr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXfmt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKiostat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstatus\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aadvance\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXeor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bkeywords\NUL\NUL\NUL\NUL\NUL\NUL\NUL(\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ballocate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbreak\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcommon\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcontinue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcycle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ndeallocate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKforall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwhere\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\telsewhere\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vequivalence\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTexit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bexternal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXfor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXgo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTgoto\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bimplicit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ainclude\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tinterface\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tintrinsic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bnamelist\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTnone\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\anullify\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\boperator\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nassignment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpause\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tprocedure\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTpure\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\telemental\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrecord\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\trecursive\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKresult\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKreturn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTstop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXto\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXuse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTonly\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQentry\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwhile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rnon_elem_subr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rdate_and_time\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fsystem_clock\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rrandom_number\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vrandom_seed\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ropen_keywords\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTunit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKiostat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXerr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstatus\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKaccess\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTform\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTrecl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQblank\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bposition\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKaction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdelim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXpad\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ftransform_fn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrepeat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtrim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1selected_int_kind\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2selected_real_kind\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btransfer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vdot_product\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmatmul\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXany\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcount\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmaxval\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKminval\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aproduct\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTpack\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKunpack\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\areshape\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKspread\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcshift\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aeoshift\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ttranspose\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afindloc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmaxloc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKminloc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtypes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tparameter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsave\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apointer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpublic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aprivate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKtarget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vallocatable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\boptional\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsequence\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acomment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acomment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNFortran (Fixed Format)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bComments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adefault\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adefault\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNFortran (Fixed Format)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNFortran (Fixed Format)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1find_preprocessor\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNFortran (Fixed Format)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rfind_comments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNFortran (Fixed Format)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ffind_strings\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNFortran (Fixed Format)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nfind_decls\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNFortran (Fixed Format)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIfind_intrinsics\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNFortran (Fixed Format)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOfind_io_stmnts\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNFortran (Fixed Format)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIfind_op_and_log\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNFortran (Fixed Format)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ffind_numbers\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNFortran (Fixed Format)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rfind_continue\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNFortran (Fixed Format)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ffind_symbols\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNFortran (Fixed Format)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1find_begin_stmnts\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNFortran (Fixed Format)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIfind_end_stmnts\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNFortran (Fixed Format)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIfind_mid_stmnts\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rend_of_string\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rend_of_string\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNFortran (Fixed Format)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ&\\s*$\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL&\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX*Cc\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNFortran (Fixed Format)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acomment\NUL!\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNFortran (Fixed Format)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acomment\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1find_begin_stmnts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1find_begin_stmnts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNFortran (Fixed Format)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYN\\bmodule\\s+procedure\\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL7\\b(?:subroutine|function|block\\s*data|program|module)\\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\\b(?:then|do|select\\s+case)\\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rfind_comments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rfind_comments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNFortran (Fixed Format)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX*Cc\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNFortran (Fixed Format)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acomment\NUL!\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNFortran (Fixed Format)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acomment\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH.\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NULH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNFortran (Fixed Format)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acomment\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rfind_continue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rfind_continue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNFortran (Fixed Format)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r     [^0-9\\s]\NUL\NAK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nfind_decls\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nfind_decls\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNFortran (Fixed Format)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL4\\b(?:integer|real|complex)[\\*]\\d{1,2}|\\bend\\s*type\\b\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vallocatable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\boptional\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tparameter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apointer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aprivate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpublic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsave\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsequence\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKtarget\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdata\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYN\\bcharacter[*][0-9]+\\b\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NULH\\b(?:type|integer|real|complex|character|logical|intent|dimension)\\s*[(]\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNFortran (Fixed Format)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nfind_paren\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NULW\\b(?:type|integer|real|complex|character|logical|double\\s*precision|intent|dimension)\\b\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH::\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIfind_end_stmnts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIfind_end_stmnts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNFortran (Fixed Format)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL=\\bend\\s*(?:subroutine|function|block\\s*data|program|module)\\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3\\bend\\s*(?:do|if)\\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL+\\bend\\s*(?:select|where|forall|interface)\\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r\\belse\\s*if\\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIfind_intrinsics\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIfind_intrinsics\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNFortran (Fixed Format)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL(\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ballocate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nassignment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbreak\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcommon\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcontinue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcycle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ndeallocate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\telemental\NUL\NUL\NUL\NUL\NUL\NUL\NUL\telsewhere\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQentry\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vequivalence\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTexit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bexternal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXfor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKforall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXgo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTgoto\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bimplicit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ainclude\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tinterface\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tintrinsic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bnamelist\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTnone\NUL\NUL\NUL\NUL\NUL\NUL\NUL\anullify\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTonly\NUL\NUL\NUL\NUL\NUL\NUL\NUL\boperator\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpause\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tprocedure\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTpure\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrecord\NUL\NUL\NUL\NUL\NUL\NUL\NUL\trecursive\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKresult\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKreturn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTstop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXto\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXuse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwhere\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwhile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NULz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXabs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQachar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTacos\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aadjustl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aadjustr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQaimag\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTaint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTalog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKalog10\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQamax0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQamax1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQamin0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQamin1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTamod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQanint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKaprime\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTasin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTatan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQatan2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbtest\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcabs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTccos\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aceiling\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcexp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTchar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTclog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcmplx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQconjg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcos\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcosh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcsin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcsqrt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdabs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdacos\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdasin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdatan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdatan2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdble\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdcmplx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdconjg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdcos\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdcosh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTddim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQddmim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdexp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdfloat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdimag\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdlog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdlog10\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdmax1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdmin1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdmod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdnint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdprod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdreal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdsign\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdsin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdsinh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdsqrt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdtan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdtanh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXexp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bexponent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfloat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfloor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bfraction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTiabs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKiachar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTiand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQibclr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQibits\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQibset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQichar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTidim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQidint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKidnint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTieor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTifix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQindex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXior\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQishft\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKishftc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQisign\NUL\NUL\NUL\NUL\NUL\NUL\NUL\blen_trim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlge\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlgt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXllt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlog10\NUL\NUL\NUL\NUL\NUL\NUL\NUL\alogical\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmax\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmax0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmax1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmerge\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmin0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmin1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmodulo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmvbits\NUL\NUL\NUL\NUL\NUL\NUL\NUL\anearest\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTnint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXnot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTrand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTreal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\trrspacing\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQscale\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTscan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fset_exponent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsign\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsinh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsngl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aspacing\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsqrt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXtan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtanh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKverify\NAK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tallocated\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nassociated\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bbit_size\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdigits\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aepsilon\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOThuge\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTkind\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlbound\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vmaxexponent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vminexponent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tprecision\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apresent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQradix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrange\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQshape\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtiny\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKubound\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXany\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcount\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcshift\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vdot_product\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aeoshift\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afindloc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmatmul\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmaxloc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmaxval\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKminloc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKminval\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTpack\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aproduct\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrepeat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\areshape\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1selected_int_kind\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2selected_real_kind\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKspread\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btransfer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ttranspose\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtrim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKunpack\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rdate_and_time\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rrandom_number\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vrandom_seed\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fsystem_clock\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rfind_io_paren\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rfind_io_paren\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNFortran (Fixed Format)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\NUL*\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL(\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNFortran (Fixed Format)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1inside_func_paren\NUL)\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aadvance\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXeor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXerr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXfmt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKiostat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstatus\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTunit\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKaccess\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKaction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQblank\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdelim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdirect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXerr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQexist\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTform\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tformatted\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKiostat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTname\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQnamed\NUL\NUL\NUL\NUL\NUL\NUL\NUL\anextrec\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKnumber\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKopened\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXpad\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bposition\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTread\NUL\NUL\NUL\NUL\NUL\NUL\NUL\treadwrite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTrecl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nsequential\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vunformatted\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTunit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwrite\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKaccess\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKaction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQblank\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdelim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXerr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTform\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKiostat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXpad\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bposition\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTrecl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstatus\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTunit\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNFortran (Fixed Format)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ffind_strings\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNFortran (Fixed Format)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIfind_intrinsics\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNFortran (Fixed Format)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ffind_numbers\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNFortran (Fixed Format)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ffind_symbols\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOfind_io_stmnts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOfind_io_stmnts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNFortran (Fixed Format)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NULE\\b(?:read|write|backspace|rewind|end\\s*file|close|open|inquire)\\s*[(]\NUL\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNFortran (Fixed Format)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rfind_io_paren\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\bformat\\s*[(]\NUL\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNFortran (Fixed Format)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fformat_stmnt\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\bend\\s*file\\b\NUL\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKaccess\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tbackspace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQclose\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKformat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ainquire\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTopen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQprint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTread\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrewind\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwrite\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIfind_mid_stmnts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIfind_mid_stmnts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNFortran (Fixed Format)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTelse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETB\\bcase(?:\\s+default)?\\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcontains\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ffind_numbers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ffind_numbers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNFortran (Fixed Format)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\203[0-9]*+\\.[0-9]++(?:[de][+-]?[0-9]+)?(?:[_](?:[0-9]++|[a-z][\\w_]*))?|\\b[0-9]++\\.[0-9]*+(?:[de][+-]?[0-9]+)?(?:[_](?:[0-9]++|[a-z][\\w_]*))?(?![a-z])|\\b[0-9]++[de][+-]?[0-9]++(?:[_](?:[0-9]++|[a-z][\\w_]*))?\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL_\\b[0-9]++(?:[_](?:[0-9]++|[a-zA-Z][\\w_]*))?|\\b[bozx](?:['][0-9a-fA-F]++[']|[\"][0-9a-fA-F]++[\"])\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIfind_op_and_log\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIfind_op_and_log\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNFortran (Fixed Format)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.true.\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a.false.\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r\\.[A-Za-z]+\\.\NUL\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH==\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH/=\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH<=\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH>=\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX%<>\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nfind_paren\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nfind_paren\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNFortran (Fixed Format)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL(\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNFortran (Fixed Format)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nfind_paren\NUL)\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1find_preprocessor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1find_preprocessor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNFortran (Fixed Format)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL#\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNFortran (Fixed Format)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fpreprocessor\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcDEC$\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNFortran (Fixed Format)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fpreprocessor\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQCDEC$\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNFortran (Fixed Format)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fpreprocessor\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ffind_strings\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ffind_strings\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNFortran (Fixed Format)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL'\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNFortran (Fixed Format)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bstring_1\NUL\"\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNFortran (Fixed Format)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bstring_2\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ffind_symbols\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ffind_symbols\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNFortran (Fixed Format)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\SOH**\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH(/\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH/)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO&*+-/=?[]^{|}~\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX(),\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fformat_stmnt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fformat_stmnt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNFortran (Fixed Format)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL(\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNFortran (Fixed Format)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fformat_stmnt\NUL)\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a[0-9]*/\NUL\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL:\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNFortran (Fixed Format)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ffind_strings\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNFortran (Fixed Format)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ffind_symbols\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1inside_func_paren\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1inside_func_paren\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNFortran (Fixed Format)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL(\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNFortran (Fixed Format)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1inside_func_paren\NUL)\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNFortran (Fixed Format)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ffind_strings\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNFortran (Fixed Format)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIfind_intrinsics\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNFortran (Fixed Format)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ffind_numbers\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fpreprocessor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fpreprocessor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNFortran (Fixed Format)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bstring_1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bstring_1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNFortran (Fixed Format)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK[^']*'\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ&\\s*$\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNFortran (Fixed Format)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rend_of_string\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v.*(?=&\\s*$)\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNFortran (Fixed Format)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rend_of_string\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bstring_2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bstring_2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNFortran (Fixed Format)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK[^\"]*\"\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ&\\s*$\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNFortran (Fixed Format)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rend_of_string\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v.*(?=&\\s*$)\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNFortran (Fixed Format)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rend_of_string\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL Franchin Matteo (fnch@libero.it)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX11\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXMIT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX*.f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX*.F\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.for\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.FOR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.fpp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.FPP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adefault"
