{-# LANGUAGE OverloadedStrings #-}
-- | Automatically generated syntax definition for Modelines.
-- DO NOT EDIT THIS FILE MANUALLY.
-- Instead, modify xml/modelines.xml and 'make bootstrap'.
module Skylighting.Syntax.Modelines (syntax) where

import Skylighting.Types
import Data.Binary

-- | Syntax definition for Modelines.
syntax :: Syntax
syntax = decode "\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tModelines\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rmodelines.xml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tModelines\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bBooleans\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rauto-brackets\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANautomatic-spell-checking\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1backspace-indents\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEbookmark-sorting\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXbom\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1byte-order-marker\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIbyte-order-mark\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1dynamic-word-wrap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBenter-to-insert-completion\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIfolding-markers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIfolding-preview\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vicon-border\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2indent-pasted-text\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1keep-extra-spaces\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fline-numbers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOnewline-at-eof\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOoverwrite-mode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4persistent-selection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1replace-tabs-save\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\freplace-tabs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nsmart-home\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1scrollbar-minimap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1scrollbar-preview\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fspace-indent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tshow-tabs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4show-trailing-spaces\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vtab-indents\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tword-wrap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQFalse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXoff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfalse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tIntegrals\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1auto-center-lines\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tfont-size\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\findent-width\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ttab-width\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEword-wrap-column\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4ModelineStartKeyword\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQkate:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fRemoveSpaces\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNremove-trailing-spaces\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3RemoveSpacesOptions\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH-\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTnone\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmodified\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH+\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aStrings\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEbackground-color\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBbracket-highlight-color\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2current-line-color\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2default-dictionary\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bencoding\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXeol\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vend-of-line\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfont\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXhl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOicon-bar-color\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vindent-mode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKscheme\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIselection-color\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsyntax\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNword-wrap-marker-color\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTrue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXon\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtrue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bBooleans\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bBooleans\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tModelines\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tModelines\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tSpacesEnd\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN\t\n !%&(),./;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXon\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtrue\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tModelines\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tSpacesEnd\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN\t\n !%&(),./;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfalse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXoff\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tModelines\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tSpacesEnd\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tIntegrals\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tIntegrals\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tModelines\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tModelines\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tSpacesEnd\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tModelines\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tSpacesEnd\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bModeline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bModeline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tModelines\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN\t\n !%&(),./;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rauto-brackets\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANautomatic-spell-checking\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1backspace-indents\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXbom\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEbookmark-sorting\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIbyte-order-mark\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1byte-order-marker\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1dynamic-word-wrap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBenter-to-insert-completion\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIfolding-markers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIfolding-preview\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vicon-border\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2indent-pasted-text\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1keep-extra-spaces\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fline-numbers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOnewline-at-eof\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOoverwrite-mode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4persistent-selection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\freplace-tabs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1replace-tabs-save\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1scrollbar-minimap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1scrollbar-preview\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tshow-tabs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4show-trailing-spaces\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nsmart-home\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fspace-indent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vtab-indents\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tword-wrap\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tModelines\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bBooleans\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN\t\n !%&(),./;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1auto-center-lines\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tfont-size\NUL\NUL\NUL\NUL\NUL\NUL\NUL\findent-width\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ttab-width\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEword-wrap-column\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tModelines\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tIntegrals\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN\t\n !%&(),./;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEbackground-color\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBbracket-highlight-color\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2current-line-color\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2default-dictionary\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bencoding\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vend-of-line\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXeol\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfont\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXhl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOicon-bar-color\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vindent-mode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKscheme\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIselection-color\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsyntax\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNword-wrap-marker-color\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tModelines\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aStrings\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN\t\n !%&(),./;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNremove-trailing-spaces\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tModelines\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fRemoveSpaces\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tModelines\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN\t\n !%&(),./;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQkate:\SO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tModelines\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bModeline\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fRemoveSpaces\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fRemoveSpaces\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tModelines\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tModelines\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tSpacesEnd\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN\t\n !%&(),./;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH+\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH-\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmodified\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTnone\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tModelines\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tSpacesEnd\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tSpacesEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tSpacesEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tModelines\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL;\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aStrings\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aStrings\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tModelines\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tModelines\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tSpacesEnd\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USAlex Turbov (i.zaufi@gmail.com)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH7\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXMIT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal"
