{-# LANGUAGE OverloadedStrings #-}
-- | Automatically generated syntax definition for QML.
-- DO NOT EDIT THIS FILE MANUALLY.
-- Instead, modify xml/qml.xml and 'make bootstrap'.
module Skylighting.Syntax.Qml (syntax) where

import Skylighting.Types
import Data.Binary

-- | Syntax definition for QML.
syntax :: Syntax
syntax = decode "\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXQML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aqml.xml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXQml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\belements\NUL\NUL\NUL\NUL\NUL\NUL\NULJ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQState\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIPropertyChanges\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nStateGroup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fParentChange\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1StateChangeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rAnchorChanges\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1PropertyAnimation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SINumberAnimation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOColorAnimation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3SequentialAnimation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ParallelAnimation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOPauseAnimation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOPropertyAction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fParentAction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fScriptAction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTransition\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSpringFollow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nEaseFollow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bBehavior\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aBinding\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tListModel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vListElement\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIVisualItemModel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fXmlListModel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aXmlRole\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1DateTimeFormatter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SINumberFormatter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vConnections\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tComponent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQTimer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bQtObject\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTItem\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tRectangle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQImage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vBorderImage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTText\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tTextInput\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bTextEdit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tMouseArea\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nFocusScope\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tFlickable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFlipable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aWebView\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKLoader\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bRepeater\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rSystemPalette\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBGraphicsObjectContainer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nLayoutItem\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bListView\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bGridView\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bPathView\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bPathLine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bPathQuad\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tPathCubic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rPathAttribute\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vPathPercent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKColumn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXRow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTGrid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQScale\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bRotation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBlur\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bColorize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nDropShadow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aOpacity\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tParticles\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4ParticleMotionLinear\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKParticleMotionGravity\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4ParticleMotionWander\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bGradient\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fGradientStop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vMouseRegion\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOextra-keywords\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpragma\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\breadonly\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\brequired\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtypes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbool\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcolor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXurl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTreal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdouble\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXvar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avariant\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKConditionalExpression\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKConditionalExpression\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXQML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX:}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL?\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXQML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKImport\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKImport\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXQML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nJavaScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\v\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXQML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKimport\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXQML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKImport\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NULJ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rAnchorChanges\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bBehavior\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aBinding\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBlur\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vBorderImage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOColorAnimation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bColorize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKColumn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tComponent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vConnections\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1DateTimeFormatter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nDropShadow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nEaseFollow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tFlickable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFlipable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nFocusScope\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bGradient\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fGradientStop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBGraphicsObjectContainer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTGrid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bGridView\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQImage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTItem\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nLayoutItem\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vListElement\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tListModel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bListView\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKLoader\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tMouseArea\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vMouseRegion\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SINumberAnimation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SINumberFormatter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aOpacity\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ParallelAnimation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fParentAction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fParentChange\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKParticleMotionGravity\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4ParticleMotionLinear\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4ParticleMotionWander\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tParticles\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rPathAttribute\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tPathCubic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bPathLine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vPathPercent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bPathQuad\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bPathView\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOPauseAnimation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOPropertyAction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1PropertyAnimation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIPropertyChanges\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bQtObject\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tRectangle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bRepeater\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bRotation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXRow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQScale\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fScriptAction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3SequentialAnimation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSpringFollow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQState\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1StateChangeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nStateGroup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rSystemPalette\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTText\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bTextEdit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tTextInput\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQTimer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTransition\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIVisualItemModel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aWebView\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fXmlListModel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aXmlRole\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpragma\NUL\NUL\NUL\NUL\NUL\NUL\NUL\breadonly\NUL\NUL\NUL\NUL\NUL\NUL\NUL\brequired\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsignal\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXQML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKSignal\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEdefault property\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXQML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bProperty\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bproperty\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXQML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bProperty\NUL\"\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXQML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKString\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXQML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKObject\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nJavaScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIFindSomeSymbols\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX([\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX)]\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nJavaScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNoRegExp\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nJavaScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFindNumbers\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nJavaScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindKeywords\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nJavaScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFindStrings\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\\bMath(?=\\s*\\.)\SOH\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nJavaScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4FindMemberObjectMath\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYN\\b[A-Z][\\w$]*(?=\\s*\\.)\SOH\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nJavaScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFindMembers\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nJavaScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSFindObjectMembersAndFunctions\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nJavaScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKJSBase\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKObject\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKObject\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXQML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL&[a-zA-Z_$][\\w$]*\\s*(?=(\\/\\*.*?\\*\\/)?:)\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL!\\?(?=[^\\}]*[a-zA-Z_$][\\w$]*\\s*\\:)\SOH\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXQML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKConditionalExpression\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXQML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bProperty\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bProperty\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXQML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQalias\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbool\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcolor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdouble\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTreal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXurl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXvar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avariant\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL:\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nJavaScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aShebang\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aShebang\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXQML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH#!\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXQML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fShebang Line\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXQML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXQML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXQML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fShebang Line\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fShebang Line\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXQML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXQML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKSignal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKSignal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXQML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL(\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXQML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SISignalParameter\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SISignalParameter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SISignalParameter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXQML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbool\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcolor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdouble\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTreal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXurl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXvar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avariant\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL)\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXQML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\"\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nJavaScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1RegExpAfterString\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nJavaScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKEscape\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSMilian Wolff (mail@milianw.de)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX13\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXMIT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.qml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n*.qmltypes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aShebang"
