{-# LANGUAGE OverloadedStrings #-}
-- | Automatically generated syntax definition for Lua.
-- DO NOT EDIT THIS FILE MANUALLY.
-- Instead, modify xml/lua.xml and 'make bootstrap'.
module Skylighting.Syntax.Lua (syntax) where

import Skylighting.Types
import Data.Binary

-- | Syntax definition for Lua.
syntax :: Syntax
syntax = decode "\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXLua\NUL\NUL\NUL\NUL\NUL\NUL\NUL\alua.xml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXLua\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bbasefunc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\238\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKassert\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOcollectgarbage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdofile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQerror\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fgetmetatable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKipairs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTload\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bloadfile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTnext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpairs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpcall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQprint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\brawequal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrawget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrawlen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrawset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKselect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fsetmetatable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btonumber\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btostring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTwarn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKxpcall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEcoroutine.create\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKcoroutine.isyieldable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEcoroutine.resume\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIcoroutine.close\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1coroutine.running\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEcoroutine.status\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOcoroutine.wrap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIcoroutine.yield\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\arequire\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIpackage.loadlib\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2package.searchpath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vstring.byte\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vstring.char\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vstring.dump\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vstring.find\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rstring.format\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rstring.gmatch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vstring.gsub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nstring.len\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fstring.lower\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fstring.match\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vstring.pack\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIstring.packsize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nstring.rep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOstring.reverse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nstring.sub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rstring.unpack\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fstring.upper\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tutf8.char\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nutf8.codes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOutf8.codepoint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\butf8.len\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vutf8.offset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ftable.concat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ftable.create\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ftable.insert\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ntable.move\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ntable.pack\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ftable.remove\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ntable.sort\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ftable.unpack\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmath.abs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tmath.acos\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tmath.asin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tmath.atan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tmath.ceil\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmath.cos\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmath.deg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmath.exp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nmath.floor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tmath.fmod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tmath.huge\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmath.log\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmath.max\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmath.min\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tmath.modf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmath.rad\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vmath.random\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SImath.randomseed\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmath.sin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tmath.sqrt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmath.tan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOmath.tointeger\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tmath.type\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmath.utl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bio.close\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bio.flush\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bio.input\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bio.lines\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aio.open\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tio.output\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bio.popen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aio.read\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tio.stderr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bio.stdin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tio.stdout\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nio.tmpfile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aio.type\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bio.write\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bos.clock\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aos.date\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vos.difftime\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nos.execute\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aos.exit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tos.getenv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tos.remove\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tos.rename\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fos.setlocale\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aos.time\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nos.tmpname\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vdebug.debug\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rdebug.gethook\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rdebug.getinfo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOdebug.getlocal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2debug.getmetatable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1debug.getregistry\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEdebug.getupvalue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2debug.getuservalue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rdebug.sethook\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOdebug.setlocal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2debug.setmetatable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEdebug.setupvalue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2debug.setuservalue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIdebug.traceback\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIdebug.upvalueid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1debug.upvaluejoin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcgilua\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBcgilua.addclosefunction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNcgilua.addopenfunction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBcgilua.addscripthandler\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBcgilua.buildprocesshandler\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4cgilua.contentheader\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKcgilua.cookies.delete\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2cgilua.cookies.get\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2cgilua.cookies.set\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNcgilua.cookies.sethtml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOcgilua.cookies\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vcgilua.doif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIcgilua.doscript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIcgilua.errorlog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIcgilua.handlelp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rcgilua.header\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1cgilua.htmlheader\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1cgilua.lp.compile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1cgilua.lp.include\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBcgilua.lp.setcompatmode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4cgilua.lp.setoutfunc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3cgilua.lp.translate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4cgilua.mkabsoluteurl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEcgilua.mkurlpath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vcgilua.pack\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ncgilua.put\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIcgilua.redirect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2cgilua.script_file\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2cgilua.script_path\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2cgilua.script_pdir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2cgilua.script_vdir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3cgilua.script_vpath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEcgilua.serialize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKcgilua.servervariable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4cgilua.session.close\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3cgilua.session.data\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKcgilua.session.delete\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3cgilua.session.load\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2cgilua.session.new\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3cgilua.session.open\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3cgilua.session.save\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FScgilua.session.setsessiondir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOcgilua.session\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNcgilua.seterrorhandler\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKcgilua.seterroroutput\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKcgilua.setmaxfilesize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2cgilua.setmaxinput\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1cgilua.setoutfunc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEcgilua.splitpath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBcgilua.urlcode.encodetable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKcgilua.urlcode.escape\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBcgilua.urlcode.insertfield\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMcgilua.urlcode.parsequery\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBcgilua.urlcode.unescape\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOcgilua.urlpath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlfs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOlfs.attributes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tlfs.chdir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOlfs.currentdir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\alfs.dir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\blfs.lock\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tlfs.mkdir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tlfs.rmdir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tlfs.touch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nlfs.unlock\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXzip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bzip.open\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fzip.openfile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbyte\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTchar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdump\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfind\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKformat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKgmatch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTgsub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlower\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmatch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTpack\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpacksize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\areverse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKunpack\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQupper\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKconcat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKinsert\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmove\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKremove\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsort\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcommit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aconnect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKescape\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aexecute\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfetch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vgetcolnames\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vgetcoltypes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rgetlastautoid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\anumrows\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\brollback\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rsetautocommit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfiles\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQclose\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQflush\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlines\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTread\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTseek\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asetvbuf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwrite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\abasevar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a_PROMPT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b_PROMPT2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLUA_PATH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tLUA_CPATH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLUA_INIT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT_ENV\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b_VERSION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX_G\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOpackage.config\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rpackage.cpath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOpackage.loaded\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fpackage.path\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIpackage.preload\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1package.searchers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEutf8.charpattern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SImath.maxinteger\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SImath.mininteger\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amath.pi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acontrol\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbreak\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTelse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKelseif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXfor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTgoto\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrepeat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKreturn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTthen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQuntil\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwhile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ndeprecated\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK_ALERT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r_ERRORMESSAGE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a_LOADED\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b__ipairs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aforeach\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bforeachi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nloadstring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nmath.atan2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tmath.cosh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nmath.frexp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nmath.ldexp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nmath.log10\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmath.mod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmath.pow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tmath.sinh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tmath.tanh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fstring.gfind\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rtable.foreach\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOtable.foreachi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ntable.getn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ntable.setn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\velsecontrol\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTelse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKelseif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nendcontrol\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQuntil\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bkeywords\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bfunction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlocal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXnot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKglobal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nmetamethod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ__add\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ__sub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ__mul\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ__div\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ__mod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ__pow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ__unm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK__idiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK__band\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ__bor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK__bxor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK__bnot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ__shl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ__shr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b__concat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ__len\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT__eq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT__lt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT__le\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a__index\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n__newindex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK__call\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n__tostring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK__name\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a__close\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a__pairs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v__metatable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT__gc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK__mode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vspecialvars\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXnil\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfalse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtrue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fstartcontrol\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrepeat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tAttribute\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tAttribute\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXLua\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETB<\\s*(?:close|const)\\s*>\SOH\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f<\\s*\\w*\\s*>?\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fBlockComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fBlockComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXLua\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXLua\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aComment\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT]%1]\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXLua\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bComments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFunction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFunction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXLua\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXLua\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLocal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLocal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXLua\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bfunction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXLua\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFunction\SOH--\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXLua\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fMatchComment\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4\\b[A-Z_][A-Z0-9_]*\\b\SOH\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXLua\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rLocalVariable\DC1\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXLua\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rLocalVariable\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rLocalVariable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rLocalVariable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXLua\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH--\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXLua\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fMatchComment\NUL,\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL<\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXLua\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tAttribute\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fMatchComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fMatchComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXLua\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nDoxygenLua\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n--\\[(=*)\\[\SOH\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXLua\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fBlockComment\SOH--\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXLua\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aComment\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXLua\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\SOH#!\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXLua\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vShebangLine\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\t\n !\"#%&'()*+,-/:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK_ALERT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r_ERRORMESSAGE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a_LOADED\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b__ipairs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aforeach\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bforeachi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nloadstring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nmath.atan2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tmath.cosh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nmath.frexp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nmath.ldexp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nmath.log10\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmath.mod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmath.pow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tmath.sinh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tmath.tanh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fstring.gfind\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rtable.foreach\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOtable.foreachi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ntable.getn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ntable.setn\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH--\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXLua\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fMatchComment\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\\[(=*)\\[\SOH\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXLua\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fString_block\NUL'\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXLua\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rString_single\NUL\"\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXLua\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rString_double\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\t\n !\"#%&'()*+,-/:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\238\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKassert\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbyte\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcgilua\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBcgilua.addclosefunction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNcgilua.addopenfunction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBcgilua.addscripthandler\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBcgilua.buildprocesshandler\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4cgilua.contentheader\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOcgilua.cookies\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKcgilua.cookies.delete\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2cgilua.cookies.get\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2cgilua.cookies.set\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNcgilua.cookies.sethtml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vcgilua.doif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIcgilua.doscript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIcgilua.errorlog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIcgilua.handlelp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rcgilua.header\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1cgilua.htmlheader\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1cgilua.lp.compile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1cgilua.lp.include\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBcgilua.lp.setcompatmode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4cgilua.lp.setoutfunc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3cgilua.lp.translate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4cgilua.mkabsoluteurl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEcgilua.mkurlpath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vcgilua.pack\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ncgilua.put\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIcgilua.redirect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2cgilua.script_file\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2cgilua.script_path\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2cgilua.script_pdir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2cgilua.script_vdir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3cgilua.script_vpath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEcgilua.serialize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKcgilua.servervariable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOcgilua.session\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4cgilua.session.close\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3cgilua.session.data\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKcgilua.session.delete\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3cgilua.session.load\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2cgilua.session.new\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3cgilua.session.open\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3cgilua.session.save\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FScgilua.session.setsessiondir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNcgilua.seterrorhandler\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKcgilua.seterroroutput\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKcgilua.setmaxfilesize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2cgilua.setmaxinput\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1cgilua.setoutfunc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEcgilua.splitpath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBcgilua.urlcode.encodetable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKcgilua.urlcode.escape\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBcgilua.urlcode.insertfield\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMcgilua.urlcode.parsequery\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBcgilua.urlcode.unescape\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOcgilua.urlpath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTchar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQclose\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOcollectgarbage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcommit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKconcat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aconnect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIcoroutine.close\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEcoroutine.create\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKcoroutine.isyieldable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEcoroutine.resume\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1coroutine.running\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEcoroutine.status\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOcoroutine.wrap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIcoroutine.yield\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vdebug.debug\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rdebug.gethook\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rdebug.getinfo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOdebug.getlocal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2debug.getmetatable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1debug.getregistry\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEdebug.getupvalue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2debug.getuservalue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rdebug.sethook\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOdebug.setlocal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2debug.setmetatable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEdebug.setupvalue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2debug.setuservalue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIdebug.traceback\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIdebug.upvalueid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1debug.upvaluejoin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdofile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdump\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQerror\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKescape\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aexecute\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfetch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfiles\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfind\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQflush\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKformat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vgetcolnames\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vgetcoltypes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rgetlastautoid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fgetmetatable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKgmatch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTgsub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKinsert\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bio.close\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bio.flush\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bio.input\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bio.lines\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aio.open\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tio.output\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bio.popen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aio.read\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tio.stderr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bio.stdin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tio.stdout\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nio.tmpfile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aio.type\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bio.write\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKipairs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlfs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOlfs.attributes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tlfs.chdir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOlfs.currentdir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\alfs.dir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\blfs.lock\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tlfs.mkdir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tlfs.rmdir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tlfs.touch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nlfs.unlock\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlines\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTload\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bloadfile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlower\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmatch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmath.abs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tmath.acos\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tmath.asin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tmath.atan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tmath.ceil\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmath.cos\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmath.deg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmath.exp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nmath.floor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tmath.fmod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tmath.huge\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmath.log\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmath.max\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmath.min\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tmath.modf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmath.rad\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vmath.random\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SImath.randomseed\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmath.sin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tmath.sqrt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmath.tan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOmath.tointeger\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tmath.type\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmath.utl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmove\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTnext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\anumrows\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bos.clock\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aos.date\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vos.difftime\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nos.execute\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aos.exit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tos.getenv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tos.remove\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tos.rename\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fos.setlocale\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aos.time\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nos.tmpname\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTpack\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIpackage.loadlib\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2package.searchpath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpacksize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpairs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpcall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQprint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\brawequal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrawget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrawlen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrawset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTread\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKremove\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\arequire\NUL\NUL\NUL\NUL\NUL\NUL\NUL\areverse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\brollback\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTseek\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKselect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rsetautocommit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fsetmetatable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asetvbuf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsort\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vstring.byte\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vstring.char\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vstring.dump\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vstring.find\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rstring.format\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rstring.gmatch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vstring.gsub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nstring.len\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fstring.lower\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fstring.match\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vstring.pack\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIstring.packsize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nstring.rep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOstring.reverse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nstring.sub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rstring.unpack\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fstring.upper\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ftable.concat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ftable.create\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ftable.insert\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ntable.move\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ntable.pack\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ftable.remove\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ntable.sort\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ftable.unpack\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btonumber\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btostring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKunpack\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQupper\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tutf8.char\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOutf8.codepoint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nutf8.codes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\butf8.len\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vutf8.offset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTwarn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwrite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKxpcall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXzip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bzip.open\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fzip.openfile\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\t\n !\"#%&'()*+,-/:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ__add\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK__band\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK__bnot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ__bor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK__bxor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK__call\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a__close\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b__concat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ__div\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT__eq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT__gc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK__idiv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a__index\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT__le\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ__len\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT__lt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v__metatable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ__mod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK__mode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ__mul\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK__name\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n__newindex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a__pairs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ__pow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ__shl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ__shr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ__sub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n__tostring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ__unm\NAK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\t\n !\"#%&'()*+,-/:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tLUA_CPATH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLUA_INIT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLUA_PATH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT_ENV\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX_G\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a_PROMPT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b_PROMPT2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b_VERSION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SImath.maxinteger\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SImath.mininteger\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amath.pi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOpackage.config\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rpackage.cpath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOpackage.loaded\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fpackage.path\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIpackage.preload\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1package.searchers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEutf8.charpattern\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bfunction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXLua\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFunction\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlocal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXLua\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLocal\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\t\n !\"#%&'()*+,-/:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bfunction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKglobal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlocal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXnot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\t\n !\"#%&'()*+,-/:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfalse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXnil\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtrue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTself\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\t\n !\"#%&'()*+,-/:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrepeat\DC3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXLua\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fStartControl\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\t\n !\"#%&'()*+,-/:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbreak\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTelse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKelseif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXfor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTgoto\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrepeat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKreturn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTthen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQuntil\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwhile\DC3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL.[a-zA-Z_][a-zA-Z0-9_]*(?=\\s*([({'\"]|\\[\\[|\\[=))\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2[A-Z_][A-Z0-9_]*\\b\SOH\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NULm(?:0[xX](?:\\.[0-9A-Fa-f]+|[0-9A-Fa-f]+\\.?[0-9A-Fa-f]*)(?:[pP][-+]?\\d*)?|(?:\\.\\d+|\\d+\\.?\\d*)(?:[eE][-+]?\\d*)?)\SOH\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXLua\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fNumberSuffix\SOH!=\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH-=\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH+=\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH++\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH.=\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAK#%&()*+,-./:;<=>[]^|~\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fNumberSuffix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fNumberSuffix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXLua\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\DC1\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vShebangLine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vShebangLine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXLua\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSpecial_char\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSpecial_char\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXLua\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\SO\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SOH\\z\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXLua\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SISpecial_char_\\z\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NULM\\\\(?:[abfnrtv'\"\\\\\\[\\]]|x[0-9A-Fa-f][0-9A-Fa-f]|\\d{1,3}|u\\{[0-9A-Fa-f]{1,6}\\})\SOH\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\\\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SISpecial_char_\\z\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SISpecial_char_\\z\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXLua\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SO\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NULz\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fStartControl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fStartControl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXLua\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\t\n !\"#%&'()*+,-/:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTelse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKelseif\DC3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\t\n !\"#%&'()*+,-/:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQuntil\DC3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXLua\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fString_block\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fString_block\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXLua\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT]%1]\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rString_double\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rString_double\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXLua\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\\\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXLua\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSpecial_char\NUL\"\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXLua\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOUnclosedString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rString_single\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rString_single\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXLua\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\\\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXLua\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSpecial_char\NUL'\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXLua\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOUnclosedString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOUnclosedString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOUnclosedString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXLua\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\DC1\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS([^-[()\"'\\s]|-(?!-)|\\[(?!=))+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX21\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.lua\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n*.rockspec\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal"
