{-# LANGUAGE OverloadedStrings #-}
-- | Automatically generated syntax definition for Odin.
-- DO NOT EDIT THIS FILE MANUALLY.
-- Instead, modify xml/odin.xml and 'make bootstrap'.
module Skylighting.Syntax.Odin (syntax) where

import Skylighting.Types
import Data.Binary

-- | Syntax definition for Odin.
syntax :: Syntax
syntax = decode "\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTOdin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bodin.xml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTOdin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nattributes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aprivate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\arequire\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tlink_name\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vlink_prefix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\alinkage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBdefault_calling_convention\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\flink_section\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2extra_linker_flags\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vdeferred_in\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fdeferred_out\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIdeferred_in_out\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rdeferred_none\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ndeprecated\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIrequire_results\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdisabled\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTinit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcold\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1optimization_mode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtest\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstatic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fthread_local\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\abuiltin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tobjc_type\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4objc_is_class_method\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNrequire_target_feature\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKenable_target_feature\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acontext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acontext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vcontrolflow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTelse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTwhen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXfor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKnot_in\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKswitch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKreturn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwhere\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vfallthrough\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbreak\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcontinue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aor_else\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tor_return\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bor_break\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vor_continue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKimport\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKimport\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apackage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aforeign\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bkeywords\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQconst\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdefer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXasm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdistinct\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXnil\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtrue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfalse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX---\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstruct\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTenum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQunion\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\abit_set\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adynamic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcast\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ttransmute\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tauto_cast\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fforce_inline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIforce_no_inline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asize_of\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\balign_of\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\toffset_of\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\atype_of\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ftype_info_of\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ttypeid_of\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tprocedure\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTproc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtypes\NUL\NUL\NUL\NUL\NUL\NUL\NUL:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXi8\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXi16\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXi32\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXi64\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTi128\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXu8\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXu16\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXu32\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXu64\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTu128\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTuint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\auintptr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXf16\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXf32\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXf64\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQf16le\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQf32le\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQf64le\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQf16be\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQf32be\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQf64be\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tcomplex32\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tcomplex64\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ncomplex128\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rcomplex_float\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOcomplex_double\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fquaternion64\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rquaternion128\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rquaternion256\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbool\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXb8\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXb16\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXb32\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXb64\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acstring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTrune\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrawptr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXany\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKtypeid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbyte\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQu16le\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQu32le\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQu64le\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKu128le\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQi16le\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQi32le\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQi64le\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKi128le\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQi16be\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQi32be\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQi64be\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKi128be\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQu16be\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQu32be\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQu64be\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKu128be\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEAttributeContext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEAttributeContext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTOdin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL(\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\abuiltin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcold\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBdefault_calling_convention\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vdeferred_in\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIdeferred_in_out\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rdeferred_none\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fdeferred_out\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ndeprecated\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdisabled\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKenable_target_feature\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2extra_linker_flags\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTinit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tlink_name\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vlink_prefix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\flink_section\NUL\NUL\NUL\NUL\NUL\NUL\NUL\alinkage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4objc_is_class_method\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tobjc_type\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1optimization_mode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aprivate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\arequire\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIrequire_results\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNrequire_target_feature\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstatic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtest\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fthread_local\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tCharacter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tCharacter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTOdin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\\\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTOdin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nEscapeChar\NUL'\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1DoubleQuoteString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1DoubleQuoteString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTOdin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\\\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTOdin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nEscapeChar\NUL\"\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nEscapeChar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nEscapeChar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTOdin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NULF\\\\([nrt'\"\\\\]|x[0-9a-fA-F]{2}|[0-7]{3}|u[0-9A-Fa-f]{4}|U[0-9A-Fa-f]{8})\SOH\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEMultiLineComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEMultiLineComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTOdin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bComments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH*/\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vNormal Text\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vNormal Text\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTOdin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAK\SOH//\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTOdin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1SingleLineComment\SOH/*\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTOdin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEMultiLineComment\SOH::\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTOdin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1DoubleQuoteString\NUL'\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTOdin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tCharacter\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbreak\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcontinue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTelse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vfallthrough\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXfor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKnot_in\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bor_break\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vor_continue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aor_else\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tor_return\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKreturn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKswitch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTwhen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwhere\DC3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX---\NUL\NUL\NUL\NUL\NUL\NUL\NUL\balign_of\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXasm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tauto_cast\NUL\NUL\NUL\NUL\NUL\NUL\NUL\abit_set\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcast\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQconst\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdefer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdistinct\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adynamic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTenum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfalse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fforce_inline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIforce_no_inline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXnil\NUL\NUL\NUL\NUL\NUL\NUL\NUL\toffset_of\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asize_of\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstruct\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ttransmute\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtrue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ftype_info_of\NUL\NUL\NUL\NUL\NUL\NUL\NUL\atype_of\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ttypeid_of\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQunion\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXany\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXb16\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXb32\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXb64\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXb8\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbool\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbyte\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ncomplex128\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tcomplex32\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tcomplex64\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOcomplex_double\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rcomplex_float\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acstring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXf16\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQf16be\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQf16le\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXf32\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQf32be\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQf32le\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXf64\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQf64be\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQf64le\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTi128\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKi128be\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKi128le\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXi16\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQi16be\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQi16le\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXi32\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQi32be\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQi32le\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXi64\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQi64be\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQi64le\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXi8\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rquaternion128\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rquaternion256\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fquaternion64\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrawptr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTrune\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKtypeid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTu128\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKu128be\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKu128le\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXu16\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQu16be\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQu16le\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXu32\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQu32be\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQu32le\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXu64\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQu64be\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQu64le\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXu8\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTuint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\auintptr\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acontext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL@\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTOdin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEAttributeContext\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n0123456789\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTOdin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNumber\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\\#\\w+\SOH\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\\w{1,}\\s{0,}::\\s{0,}(?=proc)\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTOdin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tProcedure\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYN[A-Za-z_0-9]*\\s*(?=\\()\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NULA\\w{1,},{0,1}\\s{0,}\\w{0,}\\s{0,}(?=:\\=|:\\s{0,}\\w{1,}\\s{0,}\\=)(?!::)\SOH\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYN!%&()*+,-./:;<=>?[]^|~\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL`\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTOdin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tRawString\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aforeign\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKimport\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apackage\v\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNumber\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNumber\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTOdin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NULx(?:[0-9]+(?:_[0-9]+)*)(\\.(?:[0-9]+(?:_[0-9]+)*)(?:[eE][+-]?(?:[0-9]+(?:_[0-9]+)*))?|(?:[eE][+-]?(?:[0-9]+(?:_[0-9]+)*)))\SOH\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTOdin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSuffixNumber\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL/0(?=[^xob]|$)|(?=0[xob])|(?:[0-9]+(?:_[0-9]+)*)\SOH\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTOdin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSuffixNumber\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL$0x(?:[0-9A-Fa-f]+(?:_[0-9A-Fa-f]+)*)\SOH\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTOdin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSuffixNumber\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN0o(?:[0-7]+(?:_[0-7]+)*)\SOH\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTOdin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSuffixNumber\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYN0b(?:[01]+(?:_[01]+)*)\SOH\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTOdin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSuffixNumber\NUL0\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTOdin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSuffixNumber\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tProcedure\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tProcedure\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTOdin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\SOH::\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTproc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTOdin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBSimpleDoubleQuoteString\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX(\\\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tRawString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tRawString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTOdin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL`\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBSimpleDoubleQuoteString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBSimpleDoubleQuoteString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTOdin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\"\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1SingleLineComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1SingleLineComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTOdin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bComments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSuffixNumber\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSuffixNumber\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTOdin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL:\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX..\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v.0123456789\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\DC1\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL%Akseli Lahtinen (akselmo@akselmo.dev)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH7\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXMIT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK*.odin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vNormal Text"
