{-# LANGUAGE OverloadedStrings #-}
-- | Automatically generated syntax definition for SQL (PostgreSQL).
-- DO NOT EDIT THIS FILE MANUALLY.
-- Instead, modify xml/sql-postgresql.xml and 'make bootstrap'.
module Skylighting.Syntax.SqlPostgresql (syntax) where

import Skylighting.Types
import Data.Binary

-- | Syntax definition for SQL (PostgreSQL).
syntax :: Syntax
syntax = decode "\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESQL (PostgreSQL)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2sql-postgresql.xml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rSqlPostgresql\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vcontrolFlow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQBEGIN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTCASE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTELSE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQELSIF\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXEND\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tEXCEPTION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXFOR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXIF\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTLOOP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKRETURN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTHEN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTWHEN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tfunctions\NUL\NUL\NUL\NUL\NUL\NUL\NUL\189\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXABS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTCBRT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTCEIL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCEILING\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aDEGREES\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXEXP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQFLOOR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXLN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXLOG\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXMOD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXPI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXPOW\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQPOWER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aRADIANS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKRANDOM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQROUND\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aSETSEED\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTSIGN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTSQRT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQTRUNC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fWIDTH_BUCKET\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTACOS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTASIN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTATAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQATAN2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXCOS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXCOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXSIN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXTAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nBIT_LENGTH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCHAR_LENGTH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLECHARACTER_LENGTH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKCONCAT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tCONCAT_WS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCONVERT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bGET_BYTE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aGET_BIT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLOWER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fOCTET_LENGTH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aOVERLAY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bPOSITION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aSET_BIT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tSUBSTRING\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTRIM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQUPPER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQASCII\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQBTRIM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXCHR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKDECODE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKENCODE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aINITCAP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKLENGTH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTLPAD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLTRIM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXMD5\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2PG_CLIENT_ENCODING\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vQUOTE_IDENT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rQUOTE_LITERAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOREGEXP_REPLACE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKREPEAT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aREPLACE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTRPAD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQRTRIM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nSPLIT_PART\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKSTRPOS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKSUBSTR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bTO_ASCII\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKTO_HEX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tTRANSLATE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aTO_CHAR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aTO_DATE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fTO_TIMESTAMP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tTO_NUMBER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAGE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tDATE_PART\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nDATE_TRUNC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aEXTRACT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bISFINITE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rJUSTIFY_HOURS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fJUSTIFY_DAYS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXNOW\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tTIMEOFDAY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tTIMESTAMP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTAREA\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKCENTER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bDIAMETER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKHEIGHT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bISCLOSED\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKISOPEN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aNPOINTS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPCLOSE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQPOPEN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKRADIUS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQWIDTH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXBOX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKCIRCLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTLSEG\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPATH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQPOINT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aPOLYGON\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tARRAY_CAT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fARRAY_APPEND\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rARRAY_PREPEND\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nARRAY_DIMS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vARRAY_LOWER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vARRAY_UPPER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIARRAY_TO_STRING\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SISTRING_TO_ARRAY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tBROADCAST\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTHOST\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aMASKLEN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vSET_MASKLEN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aNETMASK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bHOSTMASK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aNETWORK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTEXT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKABBREV\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKFAMILY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aNEXTVAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCURRVAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aLASTVAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKSETVAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bCOALESCE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNULLIF\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAVG\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aBIT_AND\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKBIT_OR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bBOOL_AND\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aBOOL_OR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQCOUNT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQEVERY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXMAX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXMIN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKSTDDEV\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXSUM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bVARIANCE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIGENERATE_SERIES\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLECURRENT_DATABASE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOCURRENT_SCHEMA\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SICURRENT_SCHEMAS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCURRENT_USER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEINET_CLIENT_ADDR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEINET_CLIENT_PORT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEINET_SERVER_ADDR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEINET_SERVER_PORT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSESSION_USER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANPG_POSTMASTER_START_TIME\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aVERSION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3HAS_TABLE_PRIVILEGE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHAS_DATABASE_PRIVILEGE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHAS_FUNCTION_PRIVILEGE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHAS_LANGUAGE_PRIVILEGE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vPG_HAS_ROLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HAS_SCHEMA_PRIVILEGE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHAS_TABLESPACE_PRIVILEGE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3PG_TABLE_IS_VISIBLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2PG_TYPE_IS_VISIBLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNPG_FUNCTION_IS_VISIBLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNPG_OPERATOR_IS_VISIBLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKPG_OPCLASS_IS_VISIBLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANPG_CONVERSION_IS_VISIBLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFORMAT_TYPE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4PG_GET_CONSTRAINTDEF\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vPG_GET_EXPR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIPG_GET_INDEXDEF\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOPG_GET_RULEDEF\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNPG_GET_SERIAL_SEQUENCE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBPG_TABLESPACE_DATABASES\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1PG_GET_TRIGGERDEF\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIPG_GET_USERBYID\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOPG_GET_VIEWDEF\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIOBJ_DESCRIPTION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SICOL_DESCRIPTION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SICURRENT_SETTING\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nSET_CONFIG\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1PG_CANCEL_BACKEND\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOPG_RELOAD_CONF\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1PG_ROTATE_LOGFILE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIPG_START_BACKUP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOPG_STOP_BACKUP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOPG_COLUMN_SIZE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2PG_TABLESPACE_SIZE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEPG_DATABASE_SIZE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEPG_RELATION_SIZE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNPG_TOTAL_RELATION_SIZE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOPG_SIZE_PRETTY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tPG_LS_DIR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fPG_READ_FILE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fPG_STAT_FILE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bkeywords\NUL\NUL\NUL\NUL\NUL\NUL\STX\171\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOHA\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQABORT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKABSENT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bABSOLUTE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKACCESS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tACCORDING\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKACTION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXADA\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXADD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQADMIN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQAFTER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tAGGREGATE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXALL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bALLOCATE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTALSO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQALTER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKALWAYS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aANALYZE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXANY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXARE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQARRAY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tARRAY_AGG\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKARRAY_MAX_CARDINALITY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXAS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXASC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nASENSITIVE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tASSERTION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nASSIGNMENT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nASYMMETRIC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXAT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKATOMIC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKATTACH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tATTRIBUTE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nATTRIBUTES\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rAUTHORIZATION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bBACKWARD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKBASE64\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKBEFORE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vBEGIN_FRAME\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIBEGIN_PARTITION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tBERNOULLI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKBINARY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBLOB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aBLOCKED\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXBOM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBOTH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aBREADTH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXBY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOHC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQCACHE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTCALL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKCALLED\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCARDINALITY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCASCADE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bCASCADED\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTCAST\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCATALOG\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCATALOG_NAME\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQCHAIN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SICHARACTERISTICS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nCHARACTERS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKCHARACTER_SET_CATALOG\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2CHARACTER_SET_NAME\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4CHARACTER_SET_SCHEMA\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQCHECK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nCHECKPOINT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQCLASS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCLASS_ORIGIN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTCLOB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQCLOSE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCLUSTER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQCOBOL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCOLLATE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tCOLLATION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1COLLATION_CATALOG\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOCOLLATION_NAME\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLECOLLATION_SCHEMA\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCOLLECT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKCOLUMN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCOLUMNS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCOLUMN_NAME\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLECOMMAND_FUNCTION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKCOMMAND_FUNCTION_CODE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCOMMENT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bCOMMENTS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKCOMMIT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tCOMMITTED\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCONCURRENTLY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tCONDITION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLECONDITION_NUMBER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rCONFIGURATION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bCONFLICT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCONNECT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nCONNECTION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SICONNECTION_NAME\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nCONSTRAINT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCONSTRAINTS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2CONSTRAINT_CATALOG\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SICONSTRAINT_NAME\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1CONSTRAINT_SCHEMA\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCONSTRUCTOR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bCONTAINS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCONTENT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bCONTINUE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCONTROL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nCONVERSION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTCOPY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTCORR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rCORRESPONDING\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTCOST\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tCOVAR_POP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nCOVAR_SAMP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKCREATE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQCROSS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXCSV\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTCUBE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tCUME_DIST\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCURRENT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SICURRENT_CATALOG\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCURRENT_DATE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USCURRENT_DEFAULT_TRANSFORM_GROUP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCURRENT_PATH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCURRENT_ROLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCURRENT_ROW\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCURRENT_TIME\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1CURRENT_TIMESTAMP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL CURRENT_TRANSFORM_GROUP_FOR_TYPE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKCURSOR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCURSOR_NAME\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQCYCLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDATA\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bDATABASE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bDATALINK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNDATETIME_INTERVAL_CODE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCDATETIME_INTERVAL_PRECISION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXDAY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXDB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nDEALLOCATE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXDEC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aDECLARE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aDEFAULT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bDEFAULTS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nDEFERRABLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bDEFERRED\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aDEFINED\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aDEFINER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKDEGREE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKDELETE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tDELIMITER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nDELIMITERS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nDENSE_RANK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aDEPENDS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQDEPTH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQDEREF\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aDERIVED\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDESC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bDESCRIBE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nDESCRIPTOR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aDESTROY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nDESTRUCTOR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKDETACH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rDETERMINISTIC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vDIAGNOSTICS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nDICTIONARY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aDISABLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aDISCARD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nDISCONNECT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bDISPATCH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bDISTINCT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tDLNEWCOPY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SODLPREVIOUSCOPY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rDLURLCOMPLETE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1DLURLCOMPLETEONLY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2DLURLCOMPLETEWRITE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tDLURLPATH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rDLURLPATHONLY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SODLURLPATHWRITE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vDLURLSCHEME\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vDLURLSERVER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aDLVALUE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXDO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bDOCUMENT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKDOMAIN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDROP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aDYNAMIC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEDYNAMIC_FUNCTION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKDYNAMIC_FUNCTION_CODE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTEACH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aELEMENT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQEMPTY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKENABLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bENCODING\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tENCRYPTED\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bEND-EXEC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tEND_FRAME\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rEND_PARTITION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bENFORCED\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTENUM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKEQUALS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKESCAPE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQEVENT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKEXCEPT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aEXCLUDE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tEXCLUDING\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tEXCLUSIVE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTEXEC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aEXECUTE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKEXISTS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aEXPLAIN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nEXPRESSION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tEXTENSION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bEXTERNAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQFALSE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQFETCH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTFILE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKFILTER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQFINAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQFIRST\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFIRST_VALUE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTFLAG\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQFLOAT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tFOLLOWING\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQFORCE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aFOREIGN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aFORTRAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aFORWARD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQFOUND\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tFRAME_ROW\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTFREE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKFREEZE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTFROM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXFS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTFULL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFUNCTION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tFUNCTIONS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKFUSION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOHG\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aGENERAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tGENERATED\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXGET\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKGLOBAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXGO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTGOTO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQGRANT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aGRANTED\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bGREATEST\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQGROUP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bGROUPING\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKGROUPS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aHANDLER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKHAVING\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKHEADER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXHEX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tHIERARCHY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTHOLD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTHOUR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXID\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bIDENTITY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKIGNORE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQILIKE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tIMMEDIATE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vIMMEDIATELY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tIMMUTABLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOIMPLEMENTATION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bIMPLICIT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKIMPORT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tINCLUDING\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tINCREMENT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKINDENT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQINDEX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aINDEXES\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tINDICATOR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aINHERIT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bINHERITS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tINITIALLY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKINLINE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQINNER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQINOUT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQINPUT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vINSENSITIVE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKINSERT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bINSTANCE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fINSTANTIABLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aINSTEAD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tINTEGRITY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tINTERSECT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fINTERSECTION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTINTO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aINVOKER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKISNULL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tISOLATION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTJOIN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOHK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXKEY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nKEY_MEMBER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bKEY_TYPE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLABEL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXLAG\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLANGUAGE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLARGE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTLAST\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nLAST_VALUE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aLATERAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTLEAD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aLEADING\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tLEAKPROOF\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLEAST\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTLEFT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLEVEL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aLIBRARY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nLIKE_REGEX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLIMIT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTLINK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKLISTEN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTLOAD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLOCAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tLOCALTIME\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOLOCALTIMESTAMP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLOCATION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aLOCATOR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTLOCK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKLOCKED\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKLOGGED\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOHM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXMAP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aMAPPING\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQMATCH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aMATCHED\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fMATERIALIZED\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bMAXVALUE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIMAX_CARDINALITY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKMEMBER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQMERGE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOMESSAGE_LENGTH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4MESSAGE_OCTET_LENGTH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fMESSAGE_TEXT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKMETHOD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKMINUTE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bMINVALUE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTMODE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bMODIFIES\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKMODULE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQMONTH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTMORE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTMOVE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bMULTISET\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQMUMPS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTNAME\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQNAMES\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tNAMESPACE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNATIONAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aNATURAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQNCHAR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQNCLOB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aNESTING\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXNEW\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTNEXT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXNFC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXNFD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTNFKC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTNFKD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXNIL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXNO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTNONE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tNORMALIZE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nNORMALIZED\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aNOTHING\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNOTIFY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aNOTNULL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNOWAIT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tNTH_VALUE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQNTILE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTNULL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNULLABLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQNULLS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNUMBER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKOBJECT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1OCCURRENCES_REGEX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKOCTETS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXOF\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXOFF\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKOFFSET\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTOIDS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXOLD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXON\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTONLY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTOPEN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bOPERATOR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKOPTION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aOPTIONS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQORDER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bORDERING\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nORDINALITY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKOTHERS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXOUT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQOUTER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKOUTPUT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTOVER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bOVERLAPS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nOVERRIDING\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQOWNED\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQOWNER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOHP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXPAD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bPARALLEL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tPARAMETER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOPARAMETER_MODE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOPARAMETER_NAME\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBPARAMETER_ORDINAL_POSITION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBPARAMETER_SPECIFIC_CATALOG\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBPARAMETER_SPECIFIC_NAME\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMPARAMETER_SPECIFIC_SCHEMA\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPARSER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aPARTIAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tPARTITION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPASCAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aPASSING\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vPASSTHROUGH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bPASSWORD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aPERCENT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIPERCENTILE_CONT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIPERCENTILE_DISC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fPERCENT_RANK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPERIOD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nPERMISSION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aPLACING\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQPLANS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXPLI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPOLICY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aPORTION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOPOSITION_REGEX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bPRECEDES\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tPRECEDING\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tPRECISION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aPREPARE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bPREPARED\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bPRESERVE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aPRIMARY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQPRIOR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nPRIVILEGES\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nPROCEDURAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tPROCEDURE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aPROGRAM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPUBLIC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vPUBLICATION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQQUOTE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQRANGE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTRANK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTREAD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQREADS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bREASSIGN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aRECHECK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bRECOVERY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tRECURSIVE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXREF\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nREFERENCES\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vREFERENCING\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aREFRESH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tREGR_AVGX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tREGR_AVGY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nREGR_COUNT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOREGR_INTERCEPT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aREGR_R2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nREGR_SLOPE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bREGR_SXX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bREGR_SXY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bREGR_SYY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aREINDEX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bRELATIVE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aRELEASE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKRENAME\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nREPEATABLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aREPLICA\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tREQUIRING\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQRESET\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aRESPECT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aRESTART\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aRESTORE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bRESTRICT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKRESULT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4RETURNED_CARDINALITY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIRETURNED_LENGTH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKRETURNED_OCTET_LENGTH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1RETURNED_SQLSTATE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tRETURNING\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aRETURNS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKREVOKE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQRIGHT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTROLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bROLLBACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKROLLUP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aROUTINE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIROUTINE_CATALOG\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fROUTINE_NAME\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOROUTINE_SCHEMA\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXROW\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTROWS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tROW_COUNT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nROW_NUMBER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTRULE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tSAVEPOINT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQSCALE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKSCHEMA\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aSCHEMAS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vSCHEMA_NAME\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQSCOPE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rSCOPE_CATALOG\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nSCOPE_NAME\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSCOPE_SCHEMA\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKSCROLL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKSEARCH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKSECOND\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aSECTION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bSECURITY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKSELECT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tSELECTIVE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTSELF\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tSENSITIVE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bSEQUENCE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tSEQUENCES\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSERIALIZABLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKSERVER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vSERVER_NAME\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aSESSION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXSET\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQSETOF\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTSETS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQSHARE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTSHOW\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aSIMILAR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKSIMPLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTSIZE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTSKIP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bSNAPSHOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTSOME\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKSOURCE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQSPACE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bSPECIFIC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSPECIFICTYPE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rSPECIFIC_NAME\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXSQL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aSQLCODE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bSQLERROR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSQLEXCEPTION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bSQLSTATE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nSQLWARNING\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKSTABLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nSTANDALONE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQSTART\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQSTATE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tSTATEMENT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKSTATIC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nSTATISTICS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nSTDDEV_POP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vSTDDEV_SAMP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQSTDIN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKSTDOUT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aSTORAGE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKSTRICT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQSTRIP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tSTRUCTURE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQSTYLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SISUBCLASS_ORIGIN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vSUBMULTISET\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSUBSCRIPTION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SISUBSTRING_REGEX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bSUCCEEDS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tSYMMETRIC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQSYSID\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKSYSTEM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vSYSTEM_TIME\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vSYSTEM_USER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOHT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQTABLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKTABLES\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vTABLESAMPLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTABLESPACE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTABLE_NAME\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTEMP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bTEMPLATE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tTEMPORARY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTIES\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rTIMEZONE_HOUR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SITIMEZONE_MINUTE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXTO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQTOKEN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SITOP_LEVEL_COUNT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bTRAILING\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vTRANSACTION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNTRANSACTIONS_COMMITTED\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANTRANSACTIONS_ROLLED_BACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2TRANSACTION_ACTIVE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tTRANSFORM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTRANSFORMS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SITRANSLATE_REGEX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vTRANSLATION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQTREAT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aTRIGGER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SITRIGGER_CATALOG\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fTRIGGER_NAME\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOTRIGGER_SCHEMA\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTRIM_ARRAY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTRUE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bTRUNCATE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aTRUSTED\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTYPE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQTYPES\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aUESCAPE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tUNBOUNDED\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vUNCOMMITTED\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQUNDER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vUNENCRYPTED\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQUNION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKUNIQUE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aUNKNOWN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKUNLINK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bUNLISTEN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bUNLOGGED\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aUNNAMED\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKUNNEST\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQUNTIL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aUNTYPED\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKUPDATE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXURI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQUSAGE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTUSER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMUSER_DEFINED_TYPE_CATALOG\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNUSER_DEFINED_TYPE_CODE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNUSER_DEFINED_TYPE_NAME\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANUSER_DEFINED_TYPE_SCHEMA\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQUSING\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKVACUUM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQVALID\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bVALIDATE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tVALIDATOR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQVALUE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKVALUES\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bVALUE_OF\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tVARBINARY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bVARIADIC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aVARYING\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aVAR_POP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bVAR_SAMP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aVERBOSE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nVERSIONING\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTVIEW\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQVIEWS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bVOLATILE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bWHENEVER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQWHERE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nWHITESPACE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKWINDOW\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTWITH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKWITHIN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aWITHOUT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTWORK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aWRAPPER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQWRITE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKXMLAGG\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rXMLATTRIBUTES\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tXMLBINARY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aXMLCAST\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nXMLCOMMENT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tXMLCONCAT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOXMLDECLARATION\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vXMLDOCUMENT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nXMLELEMENT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tXMLEXISTS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tXMLFOREST\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nXMLITERATE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rXMLNAMESPACES\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bXMLPARSE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQXMLPI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bXMLQUERY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aXMLROOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tXMLSCHEMA\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fXMLSERIALIZE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bXMLTABLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aXMLTEXT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vXMLVALIDATE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYEAR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXYES\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTZONE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\toperators\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAND\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aBETWEEN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXIN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXIS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTLIKE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXNOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXOR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEpostgisFunctions\NUL\NUL\NUL\NUL\NUL\NUL\NUL\241\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQBox2D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQBox3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fGeometryType\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIPostGIS_AddBBox\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEPostGIS_DropBBox\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBPostGIS_Extensions_Upgrade\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4PostGIS_Full_Version\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4PostGIS_GEOS_Version\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIPostGIS_HasBBox\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNPostGIS_LibXML_Version\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNPostGIS_Lib_Build_Date\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3PostGIS_Lib_Version\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMPostGIS_Liblwgeom_Version\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4PostGIS_PROJ_Version\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBPostGIS_Scripts_Build_Date\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMPostGIS_Scripts_Installed\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANPostGIS_Scripts_Released\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIPostGIS_Version\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKPostGIS_Wagyu_Version\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tST_3DArea\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ST_3DClosestPoint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIST_3DConvexHull\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIST_3DDifference\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rST_3DDistance\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vST_3DExtent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ST_3DIntersection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vST_3DLength\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMST_3DLineInterpolatePoint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEST_3DLongestLine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fST_3DMakeBox\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEST_3DMaxDistance\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOST_3DPerimeter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ST_3DShortestLine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nST_3DUnion\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rST_AddMeasure\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vST_AddPoint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tST_Affine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rST_AlphaShape\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bST_Angle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANST_ApproximateMedialAxis\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aST_Area\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nST_Azimuth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vST_Boundary\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3ST_BoundingDiagonal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tST_Buffer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fST_BuildArea\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fST_CPAWithin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vST_Centroid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3ST_ChaikinSmoothing\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOST_ClipByBox2D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIST_ClosestPoint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMST_ClosestPointOfApproach\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEST_ClusterDBSCAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNST_ClusterIntersecting\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEST_ClusterKMeans\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEST_ClusterWithin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nST_Collect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4ST_CollectionExtract\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBST_CollectionHomogenize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOST_ConcaveHull\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USST_ConstrainedDelaunayTriangles\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rST_ConvexHull\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vST_CoordDim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOST_CurveToLine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4ST_DelaunayTriangles\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rST_Difference\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fST_Dimension\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vST_Distance\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOST_DistanceCPA\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ST_DistanceSphere\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3ST_DistanceSpheroid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aST_Dump\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rST_DumpPoints\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fST_DumpRings\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIST_DumpSegments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vST_EndPoint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vST_Envelope\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2ST_EstimatedExtent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tST_Expand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tST_Extent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIST_ExteriorRing\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nST_Extrude\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fST_FilterByM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2ST_FlipCoordinates\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nST_Force2D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rST_ForceCurve\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vST_ForceLHR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2ST_ForcePolygonCCW\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ST_ForcePolygonCW\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vST_ForceRHR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vST_ForceSFS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nST_Force3D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vST_Force3DM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vST_Force3DZ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nST_Force4D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2ST_ForceCollection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2ST_FrechetDistance\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ST_GeneratePoints\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2ST_GeometricMedian\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fST_GeometryN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIST_GeometryType\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tST_HasArc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4ST_HausdorffDistance\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nST_Hexagon\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOST_HexagonGrid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEST_InteriorRingN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3ST_InterpolatePoint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIST_Intersection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vST_IsClosed\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIST_IsCollection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nST_IsEmpty\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vST_IsPlanar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIST_IsPolygonCCW\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOST_IsPolygonCW\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tST_IsRing\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vST_IsSimple\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nST_IsSolid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nST_IsValid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEST_IsValidDetail\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEST_IsValidReason\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4ST_IsValidTrajectory\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tST_Length\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vST_Length2D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ST_LengthSpheroid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nST_Letters\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKST_LineFromMultiPoint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBST_LineInterpolatePoint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANST_LineInterpolatePoints\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2ST_LineLocatePoint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fST_LineMerge\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEST_LineSubstring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOST_LineToCurve\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOST_LocateAlong\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEST_LocateBetween\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBST_LocateBetweenElevations\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOST_LongestLine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTST_M\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fST_MakeBox2D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIST_MakeEnvelope\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vST_MakeLine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fST_MakePoint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rST_MakePointM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOST_MakePolygon\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fST_MakeSolid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fST_MakeValid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOST_MaxDistance\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMST_MaximumInscribedCircle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nST_MemSize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vST_MemUnion\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANST_MinimumBoundingCircle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANST_MinimumBoundingRadius\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3ST_MinimumClearance\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBST_MinimumClearanceLine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIST_MinkowskiSum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bST_Multi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bST_NDims\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nST_NPoints\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tST_NRings\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aST_Node\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fST_Normalize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEST_NumGeometries\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2ST_NumInteriorRing\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3ST_NumInteriorRings\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rST_NumPatches\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fST_NumPoints\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOST_OffsetCurve\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4ST_OptimalAlphaShape\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOST_Orientation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3ST_OrientedEnvelope\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tST_PatchN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fST_Perimeter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOST_Perimeter2D\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bST_Point\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tST_PointM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tST_PointN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ST_PointOnSurface\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tST_PointZ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nST_PointZM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tST_Points\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nST_Polygon\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rST_Polygonize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nST_Project\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNST_QuantizeCoordinates\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2ST_ReducePrecision\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOST_RemovePoint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBST_RemoveRepeatedPoints\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nST_Reverse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tST_Rotate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nST_RotateX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nST_RotateY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nST_RotateZ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aST_SRID\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bST_Scale\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tST_Scroll\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rST_Segmentize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3ST_SetEffectiveArea\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vST_SetPoint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nST_SetSRID\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOST_SharedPaths\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ST_ShiftLongitude\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIST_ShortestLine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vST_Simplify\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNST_SimplifyPolygonHull\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCST_SimplifyPreserveTopology\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rST_SimplifyVW\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aST_Snap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rST_SnapToGrid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bST_Split\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tST_Square\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rST_SquareGrid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rST_StartPoint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3ST_StraightSkeleton\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fST_Subdivide\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nST_Summary\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEST_SwapOrdinates\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEST_SymDifference\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fST_Tesselate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIST_TileEnvelope\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rST_TransScale\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fST_Transform\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fST_Translate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKST_TriangulatePolygon\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rST_UnaryUnion\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bST_Union\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tST_Volume\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIST_VoronoiLines\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2ST_VoronoiPolygons\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bST_WrapX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTST_X\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aST_XMax\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aST_XMin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTST_Y\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aST_YMax\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aST_YMin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTST_Z\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aST_ZMax\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aST_ZMin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tST_Zmflag\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCpostgis_sfcgal_full_version\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNpostgis_sfcgal_version\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nST_DWithin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtypes\NUL\NUL\NUL\NUL\NUL\NUL\NUL6\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKBIGINT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tBIGSERIAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXBIT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBOOL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aBOOLEAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXBOX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQBYTEA\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTCHAR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tCHARACTER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTCIDR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKCIRCLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDATE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aDECIMAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKDOUBLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKFLOAT4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKFLOAT8\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTINET\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXINT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTINT2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTINT4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTINT8\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aINTEGER\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bINTERVAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTJSON\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQJSONB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTLINE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTLSEG\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aMACADDR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bMACADDR8\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQMONEY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aNUMERIC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPATH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPG_LSN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQPOINT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aPOLYGON\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTREAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKSERIAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aSERIAL2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aSERIAL4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aSERIAL8\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bSMALLINT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vSMALLSERIAL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTEXT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTIME\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tTIMESTAMP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vTIMESTAMPTZ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKTIMETZ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aTSQUERY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bTSVECTOR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rTXID_SNAPSHOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTUUID\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKVARBIT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aVARCHAR\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXXML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOCreateFunction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOCreateFunction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESQL (PostgreSQL)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE\\$([^\\$\\n\\r]*)\\$\NUL\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESQL (PostgreSQL)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFunctionBody\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESQL (PostgreSQL)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2DollarQuotedString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2DollarQuotedString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESQL (PostgreSQL)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT$%1$\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fEscapeString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fEscapeString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESQL (PostgreSQL)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\SOH''\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\\\\u[0-9a-fA-F]{4}\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\\u\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\\\\U[0-9a-fA-F]{8}\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\\U\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\\\\.\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL'\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFunctionBody\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFunctionBody\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESQL (PostgreSQL)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT$%1$\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESQL (PostgreSQL)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1HighlightFunction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1HighlightFunction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESQL (PostgreSQL)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\189\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKabbrev\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXabs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTacos\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTarea\NUL\NUL\NUL\NUL\NUL\NUL\NUL\farray_append\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tarray_cat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\narray_dims\NUL\NUL\NUL\NUL\NUL\NUL\NUL\varray_lower\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rarray_prepend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIarray_to_string\NUL\NUL\NUL\NUL\NUL\NUL\NUL\varray_upper\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQascii\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTasin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTatan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQatan2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXavg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\abit_and\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nbit_length\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKbit_or\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bbool_and\NUL\NUL\NUL\NUL\NUL\NUL\NUL\abool_or\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXbox\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tbroadcast\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbtrim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcbrt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTceil\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aceiling\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcenter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vchar_length\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEcharacter_length\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXchr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcircle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcoalesce\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIcol_description\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKconcat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tconcat_ws\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aconvert\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcos\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcount\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEcurrent_database\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOcurrent_schema\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIcurrent_schemas\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIcurrent_setting\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fcurrent_user\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acurrval\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdate_part\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ndate_trunc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdecode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adegrees\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdiameter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKencode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQevery\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXexp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aextract\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfamily\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfloor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vformat_type\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIgenerate_series\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aget_bit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bget_byte\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNhas_database_privilege\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNhas_function_privilege\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNhas_language_privilege\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4has_schema_privilege\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3has_table_privilege\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANhas_tablespace_privilege\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKheight\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOThost\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bhostmask\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEinet_client_addr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEinet_client_port\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEinet_server_addr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEinet_server_port\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ainitcap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bisclosed\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bisfinite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKisopen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fjustify_days\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rjustify_hours\NUL\NUL\NUL\NUL\NUL\NUL\NUL\alastval\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlength\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXln\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlower\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlpad\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlseg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQltrim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amasklen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmax\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmd5\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\anetmask\NUL\NUL\NUL\NUL\NUL\NUL\NUL\anetwork\NUL\NUL\NUL\NUL\NUL\NUL\NUL\anextval\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXnow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\anpoints\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKnullif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIobj_description\NUL\NUL\NUL\NUL\NUL\NUL\NUL\foctet_length\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aoverlay\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTpath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpclose\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1pg_cancel_backend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2pg_client_encoding\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOpg_column_size\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANpg_conversion_is_visible\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEpg_database_size\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNpg_function_is_visible\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4pg_get_constraintdef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vpg_get_expr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIpg_get_indexdef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOpg_get_ruledef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNpg_get_serial_sequence\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1pg_get_triggerdef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIpg_get_userbyid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOpg_get_viewdef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vpg_has_role\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tpg_ls_dir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKpg_opclass_is_visible\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNpg_operator_is_visible\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANpg_postmaster_start_time\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fpg_read_file\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEpg_relation_size\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOpg_reload_conf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1pg_rotate_logfile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOpg_size_pretty\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIpg_start_backup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fpg_stat_file\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOpg_stop_backup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3pg_table_is_visible\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBpg_tablespace_databases\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2pg_tablespace_size\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNpg_total_relation_size\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2pg_type_is_visible\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXpi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpoint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apolygon\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpopen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bposition\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXpow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpower\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vquote_ident\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rquote_literal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aradians\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKradius\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrandom\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOregexp_replace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrepeat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\areplace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQround\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTrpad\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrtrim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fsession_user\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aset_bit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nset_config\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vset_masklen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asetseed\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsetval\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsign\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nsplit_part\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsqrt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstddev\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIstring_to_array\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstrpos\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsubstr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tsubstring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXtan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ttimeofday\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ttimestamp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bto_ascii\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ato_char\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ato_date\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKto_hex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tto_number\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fto_timestamp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ttranslate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtrim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtrunc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQupper\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvariance\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aversion\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwidth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fwidth_bucket\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\241\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbox2d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbox3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fgeometrytype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIpostgis_addbbox\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEpostgis_dropbbox\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBpostgis_extensions_upgrade\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4postgis_full_version\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4postgis_geos_version\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIpostgis_hasbbox\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNpostgis_lib_build_date\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3postgis_lib_version\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMpostgis_liblwgeom_version\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNpostgis_libxml_version\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4postgis_proj_version\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBpostgis_scripts_build_date\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMpostgis_scripts_installed\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANpostgis_scripts_released\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCpostgis_sfcgal_full_version\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNpostgis_sfcgal_version\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIpostgis_version\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKpostgis_wagyu_version\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tst_3darea\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1st_3dclosestpoint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIst_3dconvexhull\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIst_3ddifference\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rst_3ddistance\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vst_3dextent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1st_3dintersection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vst_3dlength\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMst_3dlineinterpolatepoint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEst_3dlongestline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fst_3dmakebox\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEst_3dmaxdistance\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOst_3dperimeter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1st_3dshortestline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nst_3dunion\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rst_addmeasure\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vst_addpoint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tst_affine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rst_alphashape\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bst_angle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANst_approximatemedialaxis\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ast_area\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nst_azimuth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vst_boundary\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3st_boundingdiagonal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tst_buffer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fst_buildarea\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vst_centroid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3st_chaikinsmoothing\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOst_clipbybox2d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIst_closestpoint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMst_closestpointofapproach\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEst_clusterdbscan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNst_clusterintersecting\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEst_clusterkmeans\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEst_clusterwithin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nst_collect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4st_collectionextract\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBst_collectionhomogenize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOst_concavehull\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USst_constraineddelaunaytriangles\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rst_convexhull\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vst_coorddim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fst_cpawithin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOst_curvetoline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4st_delaunaytriangles\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rst_difference\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fst_dimension\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vst_distance\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOst_distancecpa\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1st_distancesphere\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3st_distancespheroid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ast_dump\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rst_dumppoints\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fst_dumprings\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIst_dumpsegments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nst_dwithin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vst_endpoint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vst_envelope\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2st_estimatedextent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tst_expand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tst_extent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIst_exteriorring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nst_extrude\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fst_filterbym\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2st_flipcoordinates\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nst_force2d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nst_force3d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vst_force3dm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vst_force3dz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nst_force4d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2st_forcecollection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rst_forcecurve\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vst_forcelhr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2st_forcepolygonccw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1st_forcepolygoncw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vst_forcerhr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vst_forcesfs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2st_frechetdistance\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1st_generatepoints\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2st_geometricmedian\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fst_geometryn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIst_geometrytype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tst_hasarc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4st_hausdorffdistance\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nst_hexagon\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOst_hexagongrid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEst_interiorringn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3st_interpolatepoint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIst_intersection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vst_isclosed\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIst_iscollection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nst_isempty\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vst_isplanar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIst_ispolygonccw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOst_ispolygoncw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tst_isring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vst_issimple\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nst_issolid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nst_isvalid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEst_isvaliddetail\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEst_isvalidreason\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4st_isvalidtrajectory\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tst_length\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vst_length2d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1st_lengthspheroid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nst_letters\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKst_linefrommultipoint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBst_lineinterpolatepoint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANst_lineinterpolatepoints\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2st_linelocatepoint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fst_linemerge\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEst_linesubstring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOst_linetocurve\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOst_locatealong\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEst_locatebetween\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBst_locatebetweenelevations\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOst_longestline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTst_m\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fst_makebox2d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIst_makeenvelope\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vst_makeline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fst_makepoint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rst_makepointm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOst_makepolygon\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fst_makesolid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fst_makevalid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOst_maxdistance\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMst_maximuminscribedcircle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nst_memsize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vst_memunion\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANst_minimumboundingcircle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANst_minimumboundingradius\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3st_minimumclearance\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBst_minimumclearanceline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIst_minkowskisum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bst_multi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bst_ndims\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ast_node\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fst_normalize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nst_npoints\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tst_nrings\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEst_numgeometries\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2st_numinteriorring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3st_numinteriorrings\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rst_numpatches\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fst_numpoints\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOst_offsetcurve\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4st_optimalalphashape\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOst_orientation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3st_orientedenvelope\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tst_patchn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fst_perimeter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOst_perimeter2d\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bst_point\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tst_pointm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tst_pointn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1st_pointonsurface\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tst_points\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tst_pointz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nst_pointzm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nst_polygon\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rst_polygonize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nst_project\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNst_quantizecoordinates\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2st_reduceprecision\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOst_removepoint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBst_removerepeatedpoints\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nst_reverse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tst_rotate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nst_rotatex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nst_rotatey\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nst_rotatez\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bst_scale\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tst_scroll\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rst_segmentize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3st_seteffectivearea\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vst_setpoint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nst_setsrid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOst_sharedpaths\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1st_shiftlongitude\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIst_shortestline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vst_simplify\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNst_simplifypolygonhull\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCst_simplifypreservetopology\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rst_simplifyvw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ast_snap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rst_snaptogrid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bst_split\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tst_square\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rst_squaregrid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ast_srid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rst_startpoint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3st_straightskeleton\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fst_subdivide\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nst_summary\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEst_swapordinates\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEst_symdifference\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fst_tesselate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIst_tileenvelope\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fst_transform\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fst_translate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rst_transscale\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKst_triangulatepolygon\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rst_unaryunion\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bst_union\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tst_volume\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIst_voronoilines\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2st_voronoipolygons\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bst_wrapx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTst_x\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ast_xmax\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ast_xmin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTst_y\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ast_ymax\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ast_ymin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTst_z\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ast_zmax\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tst_zmflag\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ast_zmin\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAK[a-zA-Z][a-zA-Z0-9_]*\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nIdentifier\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nIdentifier\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESQL (PostgreSQL)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SOH\"\"\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSIncludeUnicodeEscapeSequences\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSIncludeUnicodeEscapeSequences\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESQL (PostgreSQL)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL'(\\\\[0-9a-fA-F]{4})|(\\\\\\+[0-9a-fA-F]{6})\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\\\\\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\\\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL%IncludeUnicodeEscapeSequencesModified\NUL\NUL\NUL\NUL\NUL\NUL\NUL%IncludeUnicodeEscapeSequencesModified\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESQL (PostgreSQL)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL'(%1[0-9a-fA-F]{4})|(%1\\+[0-9a-fA-F]{6})\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT%1%1\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL1\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEMultiLineComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEMultiLineComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESQL (PostgreSQL)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\SO\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\DLE\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH*/\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SOH/*\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESQL (PostgreSQL)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEMultiLineComment\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bComments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESQL (PostgreSQL)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\US\SOH--\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESQL (PostgreSQL)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1SingleLineComment\SOH/*\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESQL (PostgreSQL)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEMultiLineComment\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrem\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESQL (PostgreSQL)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1SingleLineComment\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL#create\\s+(or\\s+replace\\s+)?function\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESQL (PostgreSQL)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOCreateFunction\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKdo\\s+\\$([^\\$\\n\\r]*)\\$\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESQL (PostgreSQL)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFunctionBody\SO\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\STX\171\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOHa\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQabort\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKabsent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\babsolute\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKaccess\NUL\NUL\NUL\NUL\NUL\NUL\NUL\taccording\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKaction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXada\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXadd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQadmin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQafter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\taggregate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ballocate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTalso\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQalter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKalways\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aanalyze\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXany\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXare\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQarray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tarray_agg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKarray_max_cardinality\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXas\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXasc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nasensitive\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tassertion\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nassignment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nasymmetric\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKatomic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKattach\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tattribute\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nattributes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rauthorization\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bbackward\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKbase64\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKbefore\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vbegin_frame\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIbegin_partition\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tbernoulli\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKbinary\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTblob\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ablocked\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXbom\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTboth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\abreadth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXby\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOHc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcache\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcalled\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vcardinality\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acascade\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcascaded\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcast\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acatalog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fcatalog_name\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQchain\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKcharacter_set_catalog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2character_set_name\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4character_set_schema\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIcharacteristics\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ncharacters\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcheck\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ncheckpoint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQclass\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fclass_origin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTclob\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQclose\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acluster\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcobol\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acollate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tcollation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1collation_catalog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOcollation_name\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEcollation_schema\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acollect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcolumn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vcolumn_name\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acolumns\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEcommand_function\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKcommand_function_code\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acomment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcomments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcommit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tcommitted\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fconcurrently\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tcondition\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEcondition_number\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rconfiguration\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bconflict\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aconnect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nconnection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIconnection_name\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nconstraint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2constraint_catalog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIconstraint_name\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1constraint_schema\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vconstraints\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vconstructor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcontains\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acontent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcontinue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acontrol\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nconversion\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcopy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcorr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rcorresponding\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcost\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tcovar_pop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ncovar_samp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcreate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcross\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcsv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcube\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tcume_dist\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acurrent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIcurrent_catalog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fcurrent_date\NUL\NUL\NUL\NUL\NUL\NUL\NUL\UScurrent_default_transform_group\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fcurrent_path\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fcurrent_role\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vcurrent_row\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fcurrent_time\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1current_timestamp\NUL\NUL\NUL\NUL\NUL\NUL\NUL current_transform_group_for_type\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcursor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vcursor_name\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcycle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdata\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdatabase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdatalink\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNdatetime_interval_code\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCdatetime_interval_precision\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXday\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ndeallocate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdec\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adeclare\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adefault\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdefaults\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ndeferrable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdeferred\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adefined\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adefiner\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdegree\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdelete\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdelimiter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ndelimiters\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ndense_rank\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adepends\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdepth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQderef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aderived\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdesc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdescribe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ndescriptor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adestroy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ndestructor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdetach\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rdeterministic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vdiagnostics\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ndictionary\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adisable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adiscard\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ndisconnect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdispatch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdistinct\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdlnewcopy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOdlpreviouscopy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rdlurlcomplete\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1dlurlcompleteonly\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2dlurlcompletewrite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdlurlpath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rdlurlpathonly\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOdlurlpathwrite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vdlurlscheme\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vdlurlserver\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adlvalue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdocument\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdomain\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdrop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adynamic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEdynamic_function\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKdynamic_function_code\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTeach\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aelement\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQempty\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKenable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bencoding\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tencrypted\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bend-exec\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tend_frame\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rend_partition\NUL\NUL\NUL\NUL\NUL\NUL\NUL\benforced\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTenum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKequals\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKescape\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQevent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKexcept\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aexclude\NUL\NUL\NUL\NUL\NUL\NUL\NUL\texcluding\NUL\NUL\NUL\NUL\NUL\NUL\NUL\texclusive\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTexec\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aexecute\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKexists\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aexplain\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nexpression\NUL\NUL\NUL\NUL\NUL\NUL\NUL\textension\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bexternal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfalse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfetch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfilter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfinal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfirst\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vfirst_value\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTflag\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfloat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tfollowing\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQforce\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aforeign\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afortran\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aforward\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfound\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tframe_row\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfree\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfreeze\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfrom\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXfs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfull\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bfunction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tfunctions\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfusion\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOHg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ageneral\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tgenerated\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKglobal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXgo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTgoto\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQgrant\NUL\NUL\NUL\NUL\NUL\NUL\NUL\agranted\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bgreatest\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQgroup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bgrouping\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKgroups\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ahandler\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKhaving\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKheader\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXhex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\thierarchy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOThold\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOThour\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bidentity\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKignore\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQilike\NUL\NUL\NUL\NUL\NUL\NUL\NUL\timmediate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vimmediately\NUL\NUL\NUL\NUL\NUL\NUL\NUL\timmutable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOimplementation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bimplicit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKimport\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tincluding\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tincrement\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKindent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQindex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aindexes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tindicator\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ainherit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\binherits\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tinitially\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKinline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQinner\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQinout\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQinput\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vinsensitive\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKinsert\NUL\NUL\NUL\NUL\NUL\NUL\NUL\binstance\NUL\NUL\NUL\NUL\NUL\NUL\NUL\finstantiable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ainstead\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tintegrity\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tintersect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fintersection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTinto\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ainvoker\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKisnull\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tisolation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTjoin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOHk\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXkey\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nkey_member\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bkey_type\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlabel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlag\NUL\NUL\NUL\NUL\NUL\NUL\NUL\blanguage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlarge\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlast\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nlast_value\NUL\NUL\NUL\NUL\NUL\NUL\NUL\alateral\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlead\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aleading\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tleakproof\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQleast\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTleft\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlevel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\alibrary\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nlike_regex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlimit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlink\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlisten\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTload\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlocal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tlocaltime\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOlocaltimestamp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\blocation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\alocator\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlock\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlocked\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlogged\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOHm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amapping\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmatch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amatched\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fmaterialized\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SImax_cardinality\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmaxvalue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmember\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmerge\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOmessage_length\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4message_octet_length\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fmessage_text\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmethod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKminute\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bminvalue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmodifies\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmodule\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmonth\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmore\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmove\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmultiset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmumps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTname\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQnames\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tnamespace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bnational\NUL\NUL\NUL\NUL\NUL\NUL\NUL\anatural\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQnchar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQnclob\NUL\NUL\NUL\NUL\NUL\NUL\NUL\anesting\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXnew\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTnext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXnfc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXnfd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTnfkc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTnfkd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXnil\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXno\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTnone\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tnormalize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nnormalized\NUL\NUL\NUL\NUL\NUL\NUL\NUL\anothing\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKnotify\NUL\NUL\NUL\NUL\NUL\NUL\NUL\anotnull\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKnowait\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tnth_value\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQntile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTnull\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bnullable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQnulls\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKnumber\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKobject\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1occurrences_regex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKoctets\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXof\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXoff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKoffset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOToids\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXold\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXon\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTonly\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTopen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\boperator\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKoption\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aoptions\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQorder\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bordering\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nordinality\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKothers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXout\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQouter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKoutput\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTover\NUL\NUL\NUL\NUL\NUL\NUL\NUL\boverlaps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\noverriding\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQowned\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQowner\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOHp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXpad\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bparallel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tparameter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOparameter_mode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOparameter_name\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBparameter_ordinal_position\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBparameter_specific_catalog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBparameter_specific_name\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMparameter_specific_schema\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKparser\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apartial\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tpartition\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpascal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apassing\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vpassthrough\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpassword\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apercent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fpercent_rank\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIpercentile_cont\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIpercentile_disc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKperiod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\npermission\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aplacing\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQplans\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXpli\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpolicy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aportion\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOposition_regex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bprecedes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tpreceding\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tprecision\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aprepare\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bprepared\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpreserve\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aprimary\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQprior\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nprivileges\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nprocedural\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tprocedure\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aprogram\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpublic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vpublication\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQquote\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrange\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTrank\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTread\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQreads\NUL\NUL\NUL\NUL\NUL\NUL\NUL\breassign\NUL\NUL\NUL\NUL\NUL\NUL\NUL\arecheck\NUL\NUL\NUL\NUL\NUL\NUL\NUL\brecovery\NUL\NUL\NUL\NUL\NUL\NUL\NUL\trecursive\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXref\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nreferences\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vreferencing\NUL\NUL\NUL\NUL\NUL\NUL\NUL\arefresh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tregr_avgx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tregr_avgy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nregr_count\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOregr_intercept\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aregr_r2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nregr_slope\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bregr_sxx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bregr_sxy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bregr_syy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\areindex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\brelative\NUL\NUL\NUL\NUL\NUL\NUL\NUL\arelease\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrename\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nrepeatable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\areplica\NUL\NUL\NUL\NUL\NUL\NUL\NUL\trequiring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQreset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\arespect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\arestart\NUL\NUL\NUL\NUL\NUL\NUL\NUL\arestore\NUL\NUL\NUL\NUL\NUL\NUL\NUL\brestrict\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKresult\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4returned_cardinality\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIreturned_length\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKreturned_octet_length\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1returned_sqlstate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\treturning\NUL\NUL\NUL\NUL\NUL\NUL\NUL\areturns\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrevoke\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQright\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTrole\NUL\NUL\NUL\NUL\NUL\NUL\NUL\brollback\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrollup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aroutine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIroutine_catalog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\froutine_name\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOroutine_schema\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\trow_count\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nrow_number\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTrows\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTrule\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tsavepoint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQscale\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKschema\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vschema_name\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aschemas\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQscope\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rscope_catalog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nscope_name\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fscope_schema\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKscroll\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsearch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsecond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsecurity\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKselect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tselective\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTself\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tsensitive\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsequence\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tsequences\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fserializable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKserver\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vserver_name\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asession\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsetof\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsets\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQshare\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTshow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asimilar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsimple\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTskip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsnapshot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsome\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsource\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQspace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bspecific\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rspecific_name\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fspecifictype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsql\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asqlcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsqlerror\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fsqlexception\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsqlstate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nsqlwarning\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nstandalone\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQstart\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQstate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tstatement\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstatic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nstatistics\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nstddev_pop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vstddev_samp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQstdin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstdout\NUL\NUL\NUL\NUL\NUL\NUL\NUL\astorage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstrict\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQstrip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tstructure\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQstyle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIsubclass_origin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vsubmultiset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fsubscription\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIsubstring_regex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsucceeds\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tsymmetric\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsysid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsystem\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vsystem_time\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vsystem_user\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOHt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ntable_name\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKtables\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vtablesample\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ntablespace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtemp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btemplate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ttemporary\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTties\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rtimezone_hour\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SItimezone_minute\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXto\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtoken\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SItop_level_count\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btrailing\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vtransaction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2transaction_active\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNtransactions_committed\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANtransactions_rolled_back\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ttransform\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ntransforms\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SItranslate_regex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vtranslation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtreat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\atrigger\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SItrigger_catalog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ftrigger_name\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOtrigger_schema\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ntrim_array\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtrue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btruncate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\atrusted\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtypes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\auescape\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tunbounded\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vuncommitted\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQunder\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vunencrypted\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQunion\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKunique\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aunknown\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKunlink\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bunlisten\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bunlogged\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aunnamed\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKunnest\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQuntil\NUL\NUL\NUL\NUL\NUL\NUL\NUL\auntyped\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKupdate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXuri\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQusage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTuser\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMuser_defined_type_catalog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNuser_defined_type_code\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNuser_defined_type_name\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANuser_defined_type_schema\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQusing\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvacuum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQvalid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvalidate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvalidator\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQvalue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvalue_of\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvalues\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avar_pop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvar_samp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvarbinary\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvariadic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avarying\NUL\NUL\NUL\NUL\NUL\NUL\NUL\averbose\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nversioning\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTview\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQviews\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvolatile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bwhenever\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwhere\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nwhitespace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKwindow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTwith\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKwithin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\awithout\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTwork\NUL\NUL\NUL\NUL\NUL\NUL\NUL\awrapper\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwrite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKxmlagg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rxmlattributes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\txmlbinary\NUL\NUL\NUL\NUL\NUL\NUL\NUL\axmlcast\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nxmlcomment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\txmlconcat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOxmldeclaration\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vxmldocument\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nxmlelement\NUL\NUL\NUL\NUL\NUL\NUL\NUL\txmlexists\NUL\NUL\NUL\NUL\NUL\NUL\NUL\txmlforest\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nxmliterate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rxmlnamespaces\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bxmlparse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQxmlpi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bxmlquery\NUL\NUL\NUL\NUL\NUL\NUL\NUL\axmlroot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\txmlschema\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fxmlserialize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bxmltable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\axmltext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vxmlvalidate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTyear\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXyes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTzone\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\abetween\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXis\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlike\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXnot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbegin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTelse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQelsif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\texception\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXfor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTloop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKreturn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTthen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTwhen\DC3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\t\n !%&()*+,-./:;<=>?[\\]^{|}~\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL6\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKbigint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tbigserial\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXbit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbool\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aboolean\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXbox\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbytea\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTchar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tcharacter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcidr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcircle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adecimal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdouble\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfloat4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfloat8\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTinet\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTint2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTint4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTint8\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ainteger\NUL\NUL\NUL\NUL\NUL\NUL\NUL\binterval\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTjson\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQjsonb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlseg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amacaddr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmacaddr8\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmoney\NUL\NUL\NUL\NUL\NUL\NUL\NUL\anumeric\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTpath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpg_lsn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpoint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apolygon\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTreal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKserial\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aserial2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aserial4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aserial8\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsmallint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vsmallserial\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtime\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ttimestamp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vtimestamptz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKtimetz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\atsquery\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btsvector\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rtxid_snapshot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTuuid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvarbit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avarchar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXxml\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NULF%(bulk_(exceptions|rowcount)|(not)?found|isopen|rowcount|(row)?type)\\b\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL((?<=\\b)[a-zA-Z][a-zA-Z0-9_]*(?=[\\t ]*\\()\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESQL (PostgreSQL)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1HighlightFunction\t\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL'\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESQL (PostgreSQL)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2SingleQuotedString\SOHe'\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESQL (PostgreSQL)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fEscapeString\SOHE'\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESQL (PostgreSQL)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fEscapeString\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL=U&'(?=(?:[^']|'')*'[ \\t]*UESCAPE[ \\t]*'([^0-9a-fA-F+'\" \\t])')\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESQL (PostgreSQL)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCUnicodeEscapeStringModified\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXU&'\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESQL (PostgreSQL)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3UnicodeEscapeString\NUL\"\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESQL (PostgreSQL)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nIdentifier\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL=U&\"(?=(?:[^\"]|\"\")*\"[ \\t]*UESCAPE[ \\t]*'([^0-9a-fA-F+'\" \\t])')\NUL\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESQL (PostgreSQL)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USUnicodeEscapeIdentifierModified\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXU&\"\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESQL (PostgreSQL)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBUnicodeEscapeIdentifier\SOH:=\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX&:\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH..\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH?#\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH?-\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH?|\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO@@?[^@ \\t\\r\\n]\NUL\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESQL (PostgreSQL)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fPreprocessor\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE\\$([^\\$\\n\\r]*)\\$\NUL\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESQL (PostgreSQL)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2DollarQuotedString\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI!#%&*+-/<=>@^|~\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fPreprocessor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fPreprocessor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESQL (PostgreSQL)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1SingleLineComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1SingleLineComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESQL (PostgreSQL)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bComments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2SingleQuotedString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2SingleQuotedString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESQL (PostgreSQL)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SOH''\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL'\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBUnicodeEscapeIdentifier\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBUnicodeEscapeIdentifier\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESQL (PostgreSQL)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\SOH\"\"\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESQL (PostgreSQL)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSIncludeUnicodeEscapeSequences\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USUnicodeEscapeIdentifierModified\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USUnicodeEscapeIdentifierModified\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESQL (PostgreSQL)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\SOH\"\"\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESQL (PostgreSQL)\NUL\NUL\NUL\NUL\NUL\NUL\NUL%IncludeUnicodeEscapeSequencesModified\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3UnicodeEscapeString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3UnicodeEscapeString\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESQL (PostgreSQL)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\SOH''\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESQL (PostgreSQL)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSIncludeUnicodeEscapeSequences\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL'\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCUnicodeEscapeStringModified\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCUnicodeEscapeStringModified\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESQL (PostgreSQL)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\SOH''\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESQL (PostgreSQL)\NUL\NUL\NUL\NUL\NUL\NUL\NUL%IncludeUnicodeEscapeSequencesModified\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL'\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL#Shane Wright (me@shanewright.co.uk)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX17\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.sql\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.SQL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.ddl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.DDL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal"
