{-# LANGUAGE OverloadedStrings #-}
-- | Automatically generated syntax definition for LaTeX.
-- DO NOT EDIT THIS FILE MANUALLY.
-- Instead, modify xml/latex.xml and 'make bootstrap'.
module Skylighting.Syntax.Latex (syntax) where

import Skylighting.Types
import Data.Binary

-- | Syntax definition for LaTeX.
syntax :: Syntax
syntax = decode "\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tlatex.xml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLatex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nCommentEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcomment*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acomment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nDefCommand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\\edef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\\gdef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\\xdef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nFancyLabel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\\cites\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\\Cites\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v\\parencites\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v\\Parencites\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\\autocites\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\\Autocites\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v\\supercites\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\\footcites\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\\Footcites\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nFootnoting\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\\footnote*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\\footnote\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLabel\NUL\NUL\NUL\NUL\NUL\NUL\NUL#\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\\Autocite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\\autocite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\\autoref\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\\Cite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\\cite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v\\Citeauthor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v\\citeauthor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\\citep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\\citet\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\\citetitle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\\citeurl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\\citeyear\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\\cref\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\\Cref\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\\cref*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\\Cref*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\\eqref\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\\Footcite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\\footcite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r\\footfullcite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\\fullcite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\\label\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\\nocite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\\pagecite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\\pageref\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\\Parencite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\\parencite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\\ref\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\\subref\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\\subref*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\\supercite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\\Textcite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\\textcite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\\vpageref\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\\vref\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vListingsEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vlstlisting*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nlstlisting\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tLstinline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tlstinline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aMathEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL$\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bBmatrix*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aBmatrix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rIEEEeqnarray*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fIEEEeqnarray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEIEEEeqnarraybox*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIIEEEeqnarraybox\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bVmatrix*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aVmatrix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKalign*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQalign\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bbmatrix*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\abmatrix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcases*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcases\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fdisplaymath*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vdisplaymath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\teqnarray*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\beqnarray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tequation*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bequation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bflalign*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aflalign\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\agather*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKgather\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmath*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tmultline*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmultline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpmatrix*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apmatrix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fsmallmatrix*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vsmallmatrix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fsubeqnarray*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vsubeqnarray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvmatrix*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avmatrix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fMathEnvParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\balignat*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aalignat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\txalignat*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bxalignat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nxxalignat*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\txxalignat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOMathModeEnsure\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v\\ensuremath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fMathModeText\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\\text\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\\textit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\\textbf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\\textmd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\\textsl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\\textsc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\\textrm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\\textsf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\\texttt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\\textup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\\textlf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v\\textnormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\\shortintertext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\\intertext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\\mbox\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\\emph\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tMintParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOMintedCodeLang\NUL\NUL\NUL\NUL\NUL\NUL\SOH\200\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tabapcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\babapcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1actionscriptcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEactionscriptcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aascode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKascode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\badacode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aadacode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tagdacode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bagdacode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIapacheconfcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOapacheconfcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\naconfcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\taconfcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vapachecode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\napachecode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIautohotkeycode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOautohotkeycode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bahkcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aahkcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bawkcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aawkcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tgawkcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bgawkcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tmawkcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmawkcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tnawkcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bnawkcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tbashcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bbashcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ashcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKshcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bkshcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\akshcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bzshcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\azshcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nshellcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tshellcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vbibtexcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nbibtexcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bbibcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\abibcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bboocode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aboocode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKccode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQccode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ncmakecode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tcmakecode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vcsharpcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ncsharpcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acscode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcscode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fclojurecode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vclojurecode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcljcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acljcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vcoffeecode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ncoffeecode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIcommonlispcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOcommonlispcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aclcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKclcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tlispcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\blispcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcppcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acppcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcsscode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acsscode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdartcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdartcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vdelphicode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ndelphicode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpascode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apascode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vpascalcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\npascalcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1objectpascalcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEobjectpascalcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdiffcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdiffcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nudiffcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tudiffcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdtdcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adtdcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\veiffelcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\neiffelcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\velixircode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nelixircode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aexcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKexcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bexscode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aexscode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\belmcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aelmcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nemailcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\temailcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bemlcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aemlcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\verlangcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nerlangcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tfishcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bfishcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOfishshellcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rfishshellcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nforthcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tforthcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1fortranfixedcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEfortranfixedcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ffortrancode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vfortrancode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bgapcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\agapcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rgdscriptcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fgdscriptcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\agdcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKgdcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tglslcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bglslcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ngcodecode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tgcodecode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fgnuplotcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vgnuplotcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\agocode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKgocode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vgolangcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ngolangcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vgroovycode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ngroovycode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\thamlcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bhamlcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fhaskellcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vhaskellcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ahscode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKhscode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\thaxecode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bhaxecode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\thxslcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bhxslcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ahxcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKhxcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\thtmlcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bhtmlcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bidlcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aidlcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nidriscode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tidriscode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bidrcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aidrcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vinformcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ninformcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKicode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQicode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\binicode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ainicode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcfgcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acfgcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vdosinicode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ndosinicode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKjcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQjcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tjavacode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bjavacode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIjavascriptcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOjavascriptcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ajscode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKjscode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bjclcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ajclcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tjsoncode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bjsoncode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIjsonobjectcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOjsonobjectcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\njuliacode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tjuliacode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ajlcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKjlcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fkconfigcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vkconfigcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SImenuconfigcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOmenuconfigcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLElinuxconfigcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIlinuxconfigcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1kernelconfigcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEkernelconfigcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vkotlincode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nkotlincode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\blslcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\alslcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tlesscode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\blesscode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rlilypondcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\flilypondcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4literatehaskellcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3literatehaskellcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rlhaskellcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\flhaskellcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\blhscode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\alhscode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tllvmcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bllvmcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\flogtalkcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vlogtalkcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bluacode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aluacode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tmakecode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmakecode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rmakefilecode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fmakefilecode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amfcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmfcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fbsdmakecode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vbsdmakecode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tmakocode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmakocode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rmarkdowncode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fmarkdowncode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amdcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmdcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nmasoncode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tmasoncode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEmathematicacode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SImathematicacode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmmacode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ammacode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\anbcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKnbcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vmatlabcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nmatlabcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vmaximacode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nmaximacode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fmacsymacode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vmacsymacode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nmesoncode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tmesoncode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SImesonbuildcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOmesonbuildcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rmodelicacode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fmodelicacode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vmodulacode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nmodulacode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nmysqlcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tmysqlcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tnsiscode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bnsiscode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bnsicode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ansicode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bnshcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\anshcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tnasmcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bnasmcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fnemerlecode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vnemerlecode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tnesccode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bnesccode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vnimrodcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nnimrodcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bnimcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\animcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nnixoscode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tnixoscode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bnixcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\anixcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIobjectiveccode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOobjectiveccode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tobjccode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bobjccode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1objectivecppcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEobjectivecppcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vobjcppcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nobjcppcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nocamlcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tocamlcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\voctavecode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\noctavecode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tperlcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bperlcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aplcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKplcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bphpcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aphpcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpigcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apigcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tpikecode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpikecode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tponycode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bponycode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIpostscriptcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOpostscriptcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fpostscrcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vpostscrcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpovcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apovcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIpowershellcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOpowershellcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tpwshcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpwshcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tposhcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bposhcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apscode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpscode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpsmcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apsmcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\npraatcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tpraatcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vprologcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nprologcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rprotobufcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fprotobufcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nprotocode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tprotocode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpugcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apugcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tjadecode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bjadecode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vpuppetcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\npuppetcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vpythoncode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\npythoncode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apycode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpycode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tsagecode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsagecode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bqmlcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aqmlcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bqbscode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aqbscode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIrngcompactcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOrngcompactcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\brnccode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\arnccode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tspeccode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bspeccode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vracketcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nracketcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\brktcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\arktcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\trexxcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\brexxcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\narexxcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tarexxcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nrhtmlcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\trhtmlcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fhtmlerbcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vhtmlerbcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rhtmlrubycode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fhtmlrubycode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\brstcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\arstcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\trestcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\brestcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\trubycode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\brubycode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\arbcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrbcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdubycode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdubycode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\trustcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\brustcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\arscode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrscode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsmlcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asmlcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tsasscode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsasscode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nscalacode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tscalacode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vschemecode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nschemecode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bscmcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ascmcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vscilabcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nscilabcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tscsscode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bscsscode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsedcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asedcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tgsedcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bgsedcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tssedcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bssedcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nsievecode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tsievecode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nsmalicode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tsmalicode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rsoliditycode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fsoliditycode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nspicecode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tspicecode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOspicelangcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rspicelangcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsqlcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asqlcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tstancode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bstancode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nstatacode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tstatacode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adocode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdocode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nswiftcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tswiftcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2systemverilogcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1systemverilogcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asvcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsvcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ttomlcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btomlcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ttadscode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btadscode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btclcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\atclcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ttcshcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btcshcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcshcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acshcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOterraformcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rterraformcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\atfcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKtfcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btexcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\atexcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nlatexcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tlatexcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ftodotxtcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vtodotxtcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SItypescriptcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOtypescriptcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\atscode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKtscode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvalacode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvalacode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvapicode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvapicode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rvelocitycode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvelocitycode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fverilogcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vverilogcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQvcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvhdlcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvhdlcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bxmlcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\axmlcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rxorgconfcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fxorgconfcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\txsltcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bxsltcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tyamlcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\byamlcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tyangcode*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\byangcode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tMintedEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aminted*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKminted\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nNewCommand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\renewcommand*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r\\renewcommand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE\\providecommand*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\\providecommand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\\newcommand*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v\\newcommand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aResetHL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\\KileResetHL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\\KateResetHL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nSectioning\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\\part*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\\part\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\\chapter*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\\chapter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\\section*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\\section\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\\subsection*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v\\subsection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\\subsubsection*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\subsubsection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v\\paragraph*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\\paragraph\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\subparagraph*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r\\subparagraph\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOSpecialCommand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\\column\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\\definecolor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\\geometry\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\\hspace*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\\hspace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\\input\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v\\newboolean\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\\rule\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v\\setboolean\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v\\setcounter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\\setlength\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\\special\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\\textcolor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\\vspace*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\\vspace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKTabEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ttabularx*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btabularx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btabular*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\atabular\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rsupertabular*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fsupertabular\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SImpsupertabular*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOmpsupertabular\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\txtabular*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bxtabular\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vmpxtabular*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nmpxtabular\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nlongtable*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tlongtable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aTabuEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtabu*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtabu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tlongtabu*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\blongtabu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTVerb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQverb*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTverb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTVerb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVerbatimEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tVerbatim*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bVerbatim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nBVerbatim*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tBVerbatim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nLVerbatim*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tLVerbatim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tverbatim*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bverbatim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOboxedverbatim*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rboxedverbatim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bbeginEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\\begin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKendEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\\end\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aiffalse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\\iffalse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\niffalseend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\\fi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\\else\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SImacroFancyLabel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\documentclass\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE\\includegraphics\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\\include\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v\\usepackage\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r\\bibliography\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2\\bibliographystyle\NUL\NUL\NUL\NUL\NUL\NUL\ETX\180\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEBackslashComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEBackslashComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t\n !$%&()+,-./:;<=>?[]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\\KateResetHL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\\KileResetHL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vNormal Text\NUL\\\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBBackslashMathModeCommon\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBBackslashMathModeCommon\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\\begin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIMathEnvironment\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\\end\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2MathEnvironmentEnd\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t\n !$%&()+,-./:;<=>?[]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\\emph\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\\intertext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\\mbox\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\\shortintertext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\\text\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\\textbf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\\textit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\\textlf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\\textmd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v\\textnormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\\textrm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\\textsc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\\textsf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\\textsl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\\texttt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\\textup\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fMathModeText\NUL\\\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fMathContrSeq\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4BackslashMathModeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4BackslashMathModeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\\begin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4FindBeginEnvironment\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\\end\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vMathFindEnd\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t\n !$%&()+,-./:;<=>?[]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\\emph\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\\intertext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\\mbox\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\\shortintertext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\\text\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\\textbf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\\textit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\\textlf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\\textmd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v\\textnormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\\textrm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\\textsc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\\textsf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\\textsl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\\texttt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\\textup\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fMathModeText\SOH\\(\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SOH\\)\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SOH\\[\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SOH\\]\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\\\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fMathContrSeq\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMBackslashMultilineComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMBackslashMultilineComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t\n !$%&()+,-./:;<=>?[]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\\else\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\\fi\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\\\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEBeginEnvironment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEBeginEnvironment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t\n !$%&()+,-./:;<=>?[]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nlstlisting\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vlstlisting*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vListingsEnv\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t\n !$%&()+,-./:;<=>?[]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKminted\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aminted*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tMintedEnv\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t\n !$%&()+,-./:;<=>?[]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tBVerbatim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nBVerbatim*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tLVerbatim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nLVerbatim*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bVerbatim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tVerbatim*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rboxedverbatim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOboxedverbatim*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bverbatim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tverbatim*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVerbatimEnv\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t\n !$%&()+,-./:;<=>?[]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acomment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcomment*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nCommentEnv\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t\n !$%&()+,-./:;<=>?[]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aalignat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\balignat*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bxalignat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\txalignat*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\txxalignat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nxxalignat*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEMathEnvWithParam\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t\n !$%&()+,-./:;<=>?[]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL$\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aBmatrix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bBmatrix*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fIEEEeqnarray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rIEEEeqnarray*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIIEEEeqnarraybox\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEIEEEeqnarraybox*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aVmatrix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bVmatrix*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQalign\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKalign*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\abmatrix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bbmatrix*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcases\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcases*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vdisplaymath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fdisplaymath*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\beqnarray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\teqnarray*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bequation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tequation*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aflalign\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bflalign*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKgather\NUL\NUL\NUL\NUL\NUL\NUL\NUL\agather*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmath*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmultline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tmultline*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apmatrix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpmatrix*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vsmallmatrix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fsmallmatrix*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vsubeqnarray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fsubeqnarray*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avmatrix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvmatrix*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aMathEnv\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t\n !$%&()+,-./:;<=>?[]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tlongtable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nlongtable*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOmpsupertabular\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SImpsupertabular*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nmpxtabular\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vmpxtabular*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fsupertabular\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rsupertabular*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\atabular\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btabular*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btabularx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ttabularx*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bxtabular\NUL\NUL\NUL\NUL\NUL\NUL\NUL\txtabular*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKTabEnv\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t\n !$%&()+,-./:;<=>?[]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\blongtabu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tlongtabu*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtabu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtabu*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aTabuEnv\NUL\195\151\SUB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v(\\w+)code\\b\SOH\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rMintedCodeEnv\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f[a-zA-Z]+\\*?\SOH\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLatexEnv\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH.\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fBlockComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fBlockComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUB\\\\end(?=\\s*\\{comment\\*?\\})\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCommFindEnd\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEColumn Separator\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEColumn Separator\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL{\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEColumn Separator\NUL}\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCommFindEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCommFindEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t\n !$%&()+,-./:;<=>?[]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acomment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcomment*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLECommandParameter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLECommandParameter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLECommandParameter\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\\\\.\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\DLE\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bComments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\\\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEBackslashComment\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nCommentEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nCommentEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fBlockComment\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bContrSeq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bContrSeq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t\n !$%&()+,-./:;<=>?[]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTVerb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTverb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQverb*\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTVerb\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t\n !$%&()+,-./:;<=>?[]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tlstinline\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tLstinline\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t\n !$%&()+,-./:;<=>?[]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmint\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tMintParam\NUL\195\151\SUB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC[a-zA-Z@]+(?:\\+?|\\*{0,3})|.\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nDefCommand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nDefCommand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3\\\\[a-zA-Z]+[^\\{]*\\{\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLECommandParameter\NUL}\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOEndEnvironment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOEndEnvironment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f[a-zA-Z]+\\*?\SOH\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vLatexEnvEnd\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH.\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nFancyLabel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nFancyLabel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3FancyLabelParameter\NUL[\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEFancyLabelOption\NUL(\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBFancyLabelRoundBrackets\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEFancyLabelOption\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEFancyLabelOption\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vLabelOption\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3FancyLabelParameter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3FancyLabelParameter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\DLE\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\\(\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rMathModeLatex\NUL\\\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bContrSeq\NUL$\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vMathModeTex\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\195\151\SUB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3FancyLabelParameter\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBFancyLabelRoundBrackets\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBFancyLabelRoundBrackets\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\\(\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rMathModeLatex\NUL\\\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bContrSeq\NUL$\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vMathModeTex\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\195\151\SUB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL)\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4FindBeginEnvironment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4FindBeginEnvironment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEBeginEnvironment\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH.\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f%+\\s*BEGIN\\b\SOH\EM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rRegionComment\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n%+\\s*END\\b\SOH\EM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rRegionComment\NUL%\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aComment\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2FindEndEnvironment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2FindEndEnvironment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOEndEnvironment\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\\S\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nFootnoting\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nFootnoting\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX[]\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEFootnotingInside\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEFootnotingInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEFootnotingInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEFootnotingInside\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vNormal Text\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingABAP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingABAP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingABAPCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingABAPCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginABAP\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingABAPCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingABAPCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingABAPCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingABAPCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingABAPCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingABAPCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingABAPCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingABAPCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginABAP\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingANS-Forth94\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingANS-Forth94\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingANS-Forth94CodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingANS-Forth94CodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingBeginANS-Forth94\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USHighlightingANS-Forth94CodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USHighlightingANS-Forth94CodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL$HighlightingANS-Forth94CodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL$HighlightingANS-Forth94CodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL$HighlightingANS-Forth94CodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL*HighlightingANS-Forth94CodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL*HighlightingANS-Forth94CodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL*HighlightingANS-Forth94CodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingBeginANS-Forth94\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIHighlightingAWK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIHighlightingAWK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAWK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingAWKCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingAWKCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingBeginAWK\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingAWKCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingAWKCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingAWKCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingAWKCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingAWKCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"HighlightingAWKCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"HighlightingAWKCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"HighlightingAWKCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingBeginAWK\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingActionScript 2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingActionScript 2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEActionScript 2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingActionScript 2.0CodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingActionScript 2.0CodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL!HighlightingBeginActionScript 2.0\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL$HighlightingActionScript 2.0CodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL$HighlightingActionScript 2.0CodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL)HighlightingActionScript 2.0CodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL)HighlightingActionScript 2.0CodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL)HighlightingActionScript 2.0CodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL/HighlightingActionScript 2.0CodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL/HighlightingActionScript 2.0CodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL/HighlightingActionScript 2.0CodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL!HighlightingBeginActionScript 2.0\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIHighlightingAda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIHighlightingAda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXAda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingAdaCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingAdaCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingBeginAda\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingAdaCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingAdaCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingAdaCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingAdaCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingAdaCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"HighlightingAdaCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"HighlightingAdaCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"HighlightingAdaCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingBeginAda\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingAgda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingAgda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTAgda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingAgdaCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingAgdaCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginAgda\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingAgdaCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingAgdaCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingAgdaCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingAgdaCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingAgdaCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingAgdaCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingAgdaCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingAgdaCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginAgda\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL HighlightingApache Configuration\NUL\NUL\NUL\NUL\NUL\NUL\NUL HighlightingApache Configuration\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4Apache Configuration\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL'HighlightingApache ConfigurationCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL'HighlightingApache ConfigurationCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL%HighlightingBeginApache Configuration\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL(HighlightingApache ConfigurationCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL(HighlightingApache ConfigurationCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL-HighlightingApache ConfigurationCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL-HighlightingApache ConfigurationCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL-HighlightingApache ConfigurationCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL3HighlightingApache ConfigurationCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL3HighlightingApache ConfigurationCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL3HighlightingApache ConfigurationCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL%HighlightingBeginApache Configuration\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingAutoHotKey\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingAutoHotKey\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingAutoHotKeyCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingAutoHotKeyCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingBeginAutoHotKey\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingAutoHotKeyCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingAutoHotKeyCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingAutoHotKeyCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingAutoHotKeyCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingAutoHotKeyCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL)HighlightingAutoHotKeyCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL)HighlightingAutoHotKeyCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL)HighlightingAutoHotKeyCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingBeginAutoHotKey\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCommand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBashCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBashCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginBash\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingBashCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingBashCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingBashCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingBashCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingBashCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingBashCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingBashCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingBashCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginBash\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginABAP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginABAP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingABAP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingBeginANS-Forth94\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingBeginANS-Forth94\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingANS-Forth94\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingBeginAWK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingBeginAWK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIHighlightingAWK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL!HighlightingBeginActionScript 2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL!HighlightingBeginActionScript 2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingActionScript 2.0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingBeginAda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingBeginAda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIHighlightingAda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginAgda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginAgda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingAgda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL%HighlightingBeginApache Configuration\NUL\NUL\NUL\NUL\NUL\NUL\NUL%HighlightingBeginApache Configuration\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL HighlightingApache Configuration\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingBeginAutoHotKey\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingBeginAutoHotKey\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingAutoHotKey\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBeginBibTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBeginBibTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingBibTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingBeginBoo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingBeginBoo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIHighlightingBoo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingBeginC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingBeginC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rHighlightingC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3HighlightingBeginC#\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3HighlightingBeginC#\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\&HighlightingC#\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingBeginC++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingBeginC++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIHighlightingC++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingBeginCMake\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingBeginCMake\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1HighlightingCMake\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingBeginCSS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingBeginCSS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIHighlightingCSS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingBeginClojure\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingBeginClojure\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3HighlightingClojure\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingBeginCoffeeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingBeginCoffeeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingCoffeeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingBeginCommon Lisp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingBeginCommon Lisp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingCommon Lisp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingBeginD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingBeginD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rHighlightingD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingBeginDTD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingBeginDTD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIHighlightingDTD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginDart\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginDart\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingDart\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginDiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginDiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingDiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBeginEiffel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBeginEiffel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingEiffel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBeginElixir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBeginElixir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingElixir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingBeginElm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingBeginElm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIHighlightingElm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingBeginEmail\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingBeginEmail\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1HighlightingEmail\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBeginErlang\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBeginErlang\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingErlang\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginFish\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginFish\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingFish\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL'HighlightingBeginFortran (Fixed Format)\NUL\NUL\NUL\NUL\NUL\NUL\NUL'HighlightingBeginFortran (Fixed Format)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"HighlightingFortran (Fixed Format)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL&HighlightingBeginFortran (Free Format)\NUL\NUL\NUL\NUL\NUL\NUL\NUL&HighlightingBeginFortran (Free Format)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL!HighlightingFortran (Free Format)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBeginG-Code\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBeginG-Code\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingG-Code\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingBeginGAP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingBeginGAP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIHighlightingGAP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginGLSL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginGLSL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingGLSL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingBeginGnuplot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingBeginGnuplot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3HighlightingGnuplot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3HighlightingBeginGo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3HighlightingBeginGo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\&HighlightingGo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingBeginGodot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingBeginGodot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1HighlightingGodot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBeginGroovy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBeginGroovy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingGroovy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginHTML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginHTML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingHTML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginHaml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginHaml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingHaml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingBeginHaskell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingBeginHaskell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3HighlightingHaskell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginHaxe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginHaxe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingHaxe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingBeginIDL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingBeginIDL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIHighlightingIDL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingBeginINI Files\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingBeginINI Files\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingINI Files\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingBeginIdris\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingBeginIdris\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1HighlightingIdris\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBeginInform\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBeginInform\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingInform\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL!HighlightingBeginIntel x86 (NASM)\NUL\NUL\NUL\NUL\NUL\NUL\NUL!HighlightingBeginIntel x86 (NASM)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingIntel x86 (NASM)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingBeginJ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingBeginJ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rHighlightingJ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingBeginJCL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingBeginJCL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIHighlightingJCL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginJSON\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginJSON\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingJSON\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginJava\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginJava\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingJava\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingBeginJavaScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingBeginJavaScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingJavaScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingBeginJulia\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingBeginJulia\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1HighlightingJulia\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingBeginKconfig\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingBeginKconfig\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3HighlightingKconfig\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBeginKotlin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBeginKotlin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingKotlin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingBeginLESSCSS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingBeginLESSCSS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3HighlightingLESSCSS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginLLVM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginLLVM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingLLVM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingBeginLSL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingBeginLSL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIHighlightingLSL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingBeginLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingBeginLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1HighlightingLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingBeginLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingBeginLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL!HighlightingBeginLiterate Haskell\NUL\NUL\NUL\NUL\NUL\NUL\NUL!HighlightingBeginLiterate Haskell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingLiterate Haskell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingBeginLogtalk\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingBeginLogtalk\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3HighlightingLogtalk\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingBeginLua\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingBeginLua\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIHighlightingLua\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingBeginMakefile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingBeginMakefile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingMakefile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginMako\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginMako\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingMako\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingBeginMarkdown\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingBeginMarkdown\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingMarkdown\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingBeginMason\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingBeginMason\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1HighlightingMason\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingBeginMathematica\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingBeginMathematica\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingMathematica\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBeginMatlab\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBeginMatlab\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingMatlab\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBeginMaxima\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBeginMaxima\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingMaxima\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingBeginMeson\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingBeginMeson\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1HighlightingMeson\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingBeginModelica\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingBeginModelica\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingModelica\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingBeginModula-2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingBeginModula-2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingModula-2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginNSIS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginNSIS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingNSIS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingBeginNemerle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingBeginNemerle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3HighlightingNemerle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingBeginNim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingBeginNim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIHighlightingNim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingBeginNix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingBeginNix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIHighlightingNix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USHighlightingBeginObjective Caml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USHighlightingBeginObjective Caml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingObjective Caml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingBeginObjective-C\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingBeginObjective-C\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingObjective-C\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingBeginObjective-C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingBeginObjective-C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingObjective-C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBeginOctave\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBeginOctave\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingOctave\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingBeginPHP/PHP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingBeginPHP/PHP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3HighlightingPHP/PHP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingBeginPOV-Ray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingBeginPOV-Ray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3HighlightingPOV-Ray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBeginPascal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBeginPascal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingPascal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingBeginPig\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingBeginPig\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIHighlightingPig\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginPike\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginPike\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingPike\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginPony\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginPony\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingPony\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingBeginPostScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingBeginPostScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingPostScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingBeginPowerShell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingBeginPowerShell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingPowerShell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingBeginPraat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingBeginPraat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1HighlightingPraat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBeginProlog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBeginProlog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingProlog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingBeginProtobuf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingBeginProtobuf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingProtobuf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingBeginPug\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingBeginPug\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIHighlightingPug\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBeginPuppet\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBeginPuppet\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingPuppet\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBeginPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBeginPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingBeginQML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingBeginQML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIHighlightingQML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginREXX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginREXX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingREXX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingBeginRPM Spec\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingBeginRPM Spec\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingRPM Spec\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBeginRacket\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBeginRacket\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingRacket\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL HighlightingBeginRelaxNG-Compact\NUL\NUL\NUL\NUL\NUL\NUL\NUL HighlightingBeginRelaxNG-Compact\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingRelaxNG-Compact\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginRuby\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginRuby\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingRuby\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL!HighlightingBeginRuby/Rails/RHTML\NUL\NUL\NUL\NUL\NUL\NUL\NUL!HighlightingBeginRuby/Rails/RHTML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingRuby/Rails/RHTML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginRust\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginRust\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingRust\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginSASS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginSASS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingSASS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginSCSS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginSCSS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingSCSS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingBeginSML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingBeginSML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIHighlightingSML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingBeginSQL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingBeginSQL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIHighlightingSQL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingBeginSQL (MySQL)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingBeginSQL (MySQL)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingSQL (MySQL)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingBeginScala\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingBeginScala\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1HighlightingScala\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBeginScheme\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBeginScheme\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingScheme\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingBeginSieve\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingBeginSieve\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1HighlightingSieve\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingBeginSmali\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingBeginSmali\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1HighlightingSmali\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingBeginSolidity\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingBeginSolidity\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingSolidity\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingBeginSpice\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingBeginSpice\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1HighlightingSpice\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginStan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginStan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingStan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingBeginStata\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingBeginStata\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1HighlightingStata\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingBeginSwift\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingBeginSwift\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1HighlightingSwift\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingBeginSystemVerilog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingBeginSystemVerilog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingSystemVerilog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBeginTADS 3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBeginTADS 3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingTADS 3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginTOML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginTOML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingTOML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBeginTcl/Tk\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBeginTcl/Tk\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingTcl/Tk\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingBeginTerraform\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingBeginTerraform\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingTerraform\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingBeginTodo.txt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingBeginTodo.txt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingTodo.txt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingBeginTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingBeginTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginVHDL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginVHDL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingVHDL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginVala\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginVala\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingVala\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingBeginVelocity\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingBeginVelocity\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingVelocity\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingBeginVerilog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingBeginVerilog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3HighlightingVerilog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingBeginXML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingBeginXML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIHighlightingXML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginYANG\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginYANG\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingYANG\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginnesC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginnesC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingnesC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL!HighlightingBeginreStructuredText\NUL\NUL\NUL\NUL\NUL\NUL\NUL!HighlightingBeginreStructuredText\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingreStructuredText\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBeginscilab\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBeginscilab\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2Highlightingscilab\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingBeginsed\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingBeginsed\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIHighlightingsed\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL$HighlightingBeginx.org Configuration\NUL\NUL\NUL\NUL\NUL\NUL\NUL$HighlightingBeginx.org Configuration\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USHighlightingx.org Configuration\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginxslt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginxslt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingxslt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingBibTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingBibTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKBibTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingBibTeXCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingBibTeXCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBeginBibTeX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingBibTeXCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingBibTeXCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USHighlightingBibTeXCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USHighlightingBibTeXCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USHighlightingBibTeXCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL%HighlightingBibTeXCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL%HighlightingBibTeXCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL%HighlightingBibTeXCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBeginBibTeX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIHighlightingBoo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIHighlightingBoo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXBoo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingBooCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingBooCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingBeginBoo\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBooCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBooCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingBooCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingBooCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingBooCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"HighlightingBooCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"HighlightingBooCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"HighlightingBooCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingBeginBoo\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rHighlightingC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rHighlightingC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOHC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\&HighlightingC#\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\&HighlightingC#\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXC#\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingC#CodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingC#CodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3HighlightingBeginC#\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingC#CodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingC#CodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingC#CodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingC#CodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingC#CodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL!HighlightingC#CodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL!HighlightingC#CodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL!HighlightingC#CodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3HighlightingBeginC#\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIHighlightingC++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIHighlightingC++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXC++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingC++CodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingC++CodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingBeginC++\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingC++CodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingC++CodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingC++CodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingC++CodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingC++CodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"HighlightingC++CodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"HighlightingC++CodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"HighlightingC++CodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingBeginC++\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingCCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingCCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingBeginC\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingCCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingCCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingCCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingCCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingCCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL HighlightingCCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL HighlightingCCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL HighlightingCCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingBeginC\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1HighlightingCMake\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1HighlightingCMake\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQCMake\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingCMakeCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingCMakeCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingBeginCMake\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingCMakeCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingCMakeCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingCMakeCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingCMakeCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingCMakeCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL$HighlightingCMakeCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL$HighlightingCMakeCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL$HighlightingCMakeCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingBeginCMake\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIHighlightingCSS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIHighlightingCSS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXCSS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingCSSCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingCSSCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingBeginCSS\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingCSSCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingCSSCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingCSSCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingCSSCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingCSSCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"HighlightingCSSCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"HighlightingCSSCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"HighlightingCSSCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingBeginCSS\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3HighlightingClojure\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3HighlightingClojure\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aClojure\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingClojureCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingClojureCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingBeginClojure\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingClojureCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingClojureCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL HighlightingClojureCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL HighlightingClojureCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL HighlightingClojureCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL&HighlightingClojureCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL&HighlightingClojureCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL&HighlightingClojureCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingBeginClojure\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingCoffeeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingCoffeeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCoffeeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USHighlightingCoffeeScriptCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USHighlightingCoffeeScriptCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingBeginCoffeeScript\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL HighlightingCoffeeScriptCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL HighlightingCoffeeScriptCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL%HighlightingCoffeeScriptCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL%HighlightingCoffeeScriptCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL%HighlightingCoffeeScriptCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL+HighlightingCoffeeScriptCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL+HighlightingCoffeeScriptCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL+HighlightingCoffeeScriptCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingBeginCoffeeScript\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL2\\\\end\\s*\\{(?:lstlisting|minted|[a-zA-Z]+code)\\*?\\}\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingCommon Lisp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingCommon Lisp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCommon Lisp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingCommon LispCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingCommon LispCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingBeginCommon Lisp\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USHighlightingCommon LispCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USHighlightingCommon LispCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL$HighlightingCommon LispCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL$HighlightingCommon LispCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL$HighlightingCommon LispCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL*HighlightingCommon LispCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL*HighlightingCommon LispCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL*HighlightingCommon LispCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingBeginCommon Lisp\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rHighlightingD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rHighlightingD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOHD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingDCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingDCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingBeginD\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingDCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingDCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingDCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingDCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingDCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL HighlightingDCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL HighlightingDCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL HighlightingDCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingBeginD\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIHighlightingDTD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIHighlightingDTD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXDTD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingDTDCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingDTDCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingBeginDTD\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingDTDCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingDTDCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingDTDCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingDTDCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingDTDCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"HighlightingDTDCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"HighlightingDTDCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"HighlightingDTDCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingBeginDTD\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingDart\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingDart\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDart\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingDartCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingDartCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginDart\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingDartCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingDartCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingDartCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingDartCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingDartCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingDartCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingDartCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingDartCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginDart\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingDiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingDiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingDiffCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingDiffCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginDiff\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingDiffCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingDiffCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingDiffCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingDiffCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingDiffCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingDiffCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingDiffCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingDiffCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginDiff\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingEiffel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingEiffel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKEiffel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingEiffelCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingEiffelCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBeginEiffel\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingEiffelCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingEiffelCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USHighlightingEiffelCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USHighlightingEiffelCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USHighlightingEiffelCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL%HighlightingEiffelCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL%HighlightingEiffelCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL%HighlightingEiffelCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBeginEiffel\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingElixir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingElixir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKElixir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingElixirCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingElixirCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBeginElixir\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingElixirCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingElixirCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USHighlightingElixirCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USHighlightingElixirCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USHighlightingElixirCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL%HighlightingElixirCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL%HighlightingElixirCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL%HighlightingElixirCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBeginElixir\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIHighlightingElm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIHighlightingElm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXElm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingElmCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingElmCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingBeginElm\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingElmCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingElmCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingElmCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingElmCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingElmCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"HighlightingElmCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"HighlightingElmCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"HighlightingElmCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingBeginElm\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1HighlightingEmail\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1HighlightingEmail\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQEmail\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingEmailCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingEmailCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingBeginEmail\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingEmailCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingEmailCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingEmailCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingEmailCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingEmailCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL$HighlightingEmailCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL$HighlightingEmailCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL$HighlightingEmailCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingBeginEmail\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingErlang\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingErlang\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKErlang\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingErlangCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingErlangCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBeginErlang\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingErlangCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingErlangCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USHighlightingErlangCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USHighlightingErlangCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USHighlightingErlangCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL%HighlightingErlangCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL%HighlightingErlangCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL%HighlightingErlangCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBeginErlang\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingFish\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingFish\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingFishCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingFishCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginFish\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingFishCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingFishCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingFishCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingFishCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingFishCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingFishCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingFishCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingFishCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginFish\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"HighlightingFortran (Fixed Format)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"HighlightingFortran (Fixed Format)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNFortran (Fixed Format)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL)HighlightingFortran (Fixed Format)CodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL)HighlightingFortran (Fixed Format)CodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL'HighlightingBeginFortran (Fixed Format)\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL*HighlightingFortran (Fixed Format)CodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL*HighlightingFortran (Fixed Format)CodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL/HighlightingFortran (Fixed Format)CodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL/HighlightingFortran (Fixed Format)CodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL/HighlightingFortran (Fixed Format)CodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL5HighlightingFortran (Fixed Format)CodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL5HighlightingFortran (Fixed Format)CodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL5HighlightingFortran (Fixed Format)CodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL'HighlightingBeginFortran (Fixed Format)\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL!HighlightingFortran (Free Format)\NUL\NUL\NUL\NUL\NUL\NUL\NUL!HighlightingFortran (Free Format)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKFortran (Free Format)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL(HighlightingFortran (Free Format)CodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL(HighlightingFortran (Free Format)CodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL&HighlightingBeginFortran (Free Format)\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL)HighlightingFortran (Free Format)CodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL)HighlightingFortran (Free Format)CodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL.HighlightingFortran (Free Format)CodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL.HighlightingFortran (Free Format)CodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL.HighlightingFortran (Free Format)CodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL4HighlightingFortran (Free Format)CodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL4HighlightingFortran (Free Format)CodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL4HighlightingFortran (Free Format)CodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL&HighlightingBeginFortran (Free Format)\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingG-Code\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingG-Code\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingG-CodeCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingG-CodeCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBeginG-Code\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingG-CodeCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingG-CodeCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USHighlightingG-CodeCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USHighlightingG-CodeCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USHighlightingG-CodeCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL%HighlightingG-CodeCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL%HighlightingG-CodeCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL%HighlightingG-CodeCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBeginG-Code\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIHighlightingGAP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIHighlightingGAP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingGAPCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingGAPCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingBeginGAP\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingGAPCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingGAPCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingGAPCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingGAPCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingGAPCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"HighlightingGAPCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"HighlightingGAPCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"HighlightingGAPCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingBeginGAP\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingGLSL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingGLSL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTGLSL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingGLSLCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingGLSLCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginGLSL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingGLSLCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingGLSLCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingGLSLCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingGLSLCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingGLSLCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingGLSLCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingGLSLCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingGLSLCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginGLSL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3HighlightingGnuplot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3HighlightingGnuplot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingGnuplotCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingGnuplotCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingBeginGnuplot\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingGnuplotCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingGnuplotCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL HighlightingGnuplotCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL HighlightingGnuplotCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL HighlightingGnuplotCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL&HighlightingGnuplotCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL&HighlightingGnuplotCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL&HighlightingGnuplotCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingBeginGnuplot\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\&HighlightingGo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\&HighlightingGo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXGo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingGoCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingGoCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3HighlightingBeginGo\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingGoCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingGoCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingGoCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingGoCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingGoCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL!HighlightingGoCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL!HighlightingGoCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL!HighlightingGoCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3HighlightingBeginGo\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1HighlightingGodot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1HighlightingGodot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingGodotCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingGodotCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingBeginGodot\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingGodotCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingGodotCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingGodotCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingGodotCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingGodotCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL$HighlightingGodotCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL$HighlightingGodotCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL$HighlightingGodotCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingBeginGodot\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingGroovy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingGroovy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKGroovy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingGroovyCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingGroovyCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBeginGroovy\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingGroovyCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingGroovyCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USHighlightingGroovyCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USHighlightingGroovyCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USHighlightingGroovyCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL%HighlightingGroovyCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL%HighlightingGroovyCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL%HighlightingGroovyCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBeginGroovy\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingHTML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingHTML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTHTML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingHTMLCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingHTMLCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginHTML\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingHTMLCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingHTMLCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingHTMLCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingHTMLCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingHTMLCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingHTMLCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingHTMLCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingHTMLCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginHTML\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingHaml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingHaml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingHamlCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingHamlCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginHaml\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingHamlCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingHamlCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingHamlCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingHamlCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingHamlCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingHamlCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingHamlCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingHamlCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginHaml\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3HighlightingHaskell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3HighlightingHaskell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aHaskell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingHaskellCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingHaskellCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingBeginHaskell\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingHaskellCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingHaskellCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL HighlightingHaskellCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL HighlightingHaskellCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL HighlightingHaskellCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL&HighlightingHaskellCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL&HighlightingHaskellCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL&HighlightingHaskellCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingBeginHaskell\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingHaxe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingHaxe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTHaxe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingHaxeCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingHaxeCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginHaxe\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingHaxeCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingHaxeCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingHaxeCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingHaxeCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingHaxeCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingHaxeCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingHaxeCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingHaxeCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginHaxe\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIHighlightingIDL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIHighlightingIDL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingIDLCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingIDLCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingBeginIDL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingIDLCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingIDLCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingIDLCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingIDLCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingIDLCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"HighlightingIDLCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"HighlightingIDLCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"HighlightingIDLCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingBeginIDL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingINI Files\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingINI Files\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tINI Files\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingINI FilesCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingINI FilesCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingBeginINI Files\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingINI FilesCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingINI FilesCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"HighlightingINI FilesCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"HighlightingINI FilesCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"HighlightingINI FilesCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL(HighlightingINI FilesCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL(HighlightingINI FilesCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL(HighlightingINI FilesCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingBeginINI Files\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1HighlightingIdris\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1HighlightingIdris\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQIdris\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingIdrisCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingIdrisCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingBeginIdris\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingIdrisCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingIdrisCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingIdrisCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingIdrisCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingIdrisCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL$HighlightingIdrisCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL$HighlightingIdrisCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL$HighlightingIdrisCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingBeginIdris\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingInform\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingInform\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingInformCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingInformCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBeginInform\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingInformCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingInformCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USHighlightingInformCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USHighlightingInformCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USHighlightingInformCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL%HighlightingInformCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL%HighlightingInformCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL%HighlightingInformCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBeginInform\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingIntel x86 (NASM)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingIntel x86 (NASM)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEIntel x86 (NASM)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingIntel x86 (NASM)CodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingIntel x86 (NASM)CodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL!HighlightingBeginIntel x86 (NASM)\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL$HighlightingIntel x86 (NASM)CodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL$HighlightingIntel x86 (NASM)CodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL)HighlightingIntel x86 (NASM)CodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL)HighlightingIntel x86 (NASM)CodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL)HighlightingIntel x86 (NASM)CodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL/HighlightingIntel x86 (NASM)CodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL/HighlightingIntel x86 (NASM)CodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL/HighlightingIntel x86 (NASM)CodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL!HighlightingBeginIntel x86 (NASM)\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rHighlightingJ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rHighlightingJ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOHJ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIHighlightingJCL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIHighlightingJCL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingJCLCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingJCLCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingBeginJCL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingJCLCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingJCLCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingJCLCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingJCLCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingJCLCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"HighlightingJCLCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"HighlightingJCLCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"HighlightingJCLCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingBeginJCL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingJCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingJCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingBeginJ\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingJCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingJCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingJCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingJCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingJCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL HighlightingJCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL HighlightingJCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL HighlightingJCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingBeginJ\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingJSON\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingJSON\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTJSON\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingJSONCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingJSONCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginJSON\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingJSONCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingJSONCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingJSONCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingJSONCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingJSONCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingJSONCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingJSONCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingJSONCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginJSON\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingJava\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingJava\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTJava\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingJavaCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingJavaCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginJava\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingJavaCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingJavaCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingJavaCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingJavaCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingJavaCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingJavaCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingJavaCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingJavaCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginJava\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingJavaScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingJavaScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nJavaScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingJavaScriptCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingJavaScriptCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingBeginJavaScript\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingJavaScriptCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingJavaScriptCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingJavaScriptCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingJavaScriptCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingJavaScriptCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL)HighlightingJavaScriptCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL)HighlightingJavaScriptCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL)HighlightingJavaScriptCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingBeginJavaScript\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1HighlightingJulia\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1HighlightingJulia\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQJulia\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingJuliaCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingJuliaCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingBeginJulia\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingJuliaCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingJuliaCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingJuliaCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingJuliaCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingJuliaCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL$HighlightingJuliaCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL$HighlightingJuliaCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL$HighlightingJuliaCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingBeginJulia\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3HighlightingKconfig\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3HighlightingKconfig\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingKconfigCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingKconfigCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingBeginKconfig\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingKconfigCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingKconfigCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL HighlightingKconfigCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL HighlightingKconfigCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL HighlightingKconfigCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL&HighlightingKconfigCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL&HighlightingKconfigCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL&HighlightingKconfigCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingBeginKconfig\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingKotlin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingKotlin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKKotlin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingKotlinCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingKotlinCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBeginKotlin\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingKotlinCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingKotlinCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USHighlightingKotlinCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USHighlightingKotlinCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USHighlightingKotlinCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL%HighlightingKotlinCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL%HighlightingKotlinCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL%HighlightingKotlinCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBeginKotlin\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3HighlightingLESSCSS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3HighlightingLESSCSS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingLESSCSSCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingLESSCSSCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingBeginLESSCSS\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingLESSCSSCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingLESSCSSCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL HighlightingLESSCSSCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL HighlightingLESSCSSCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL HighlightingLESSCSSCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL&HighlightingLESSCSSCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL&HighlightingLESSCSSCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL&HighlightingLESSCSSCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingBeginLESSCSS\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingLLVM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingLLVM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTLLVM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingLLVMCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingLLVMCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginLLVM\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingLLVMCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingLLVMCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingLLVMCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingLLVMCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingLLVMCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingLLVMCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingLLVMCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingLLVMCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginLLVM\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIHighlightingLSL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIHighlightingLSL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingLSLCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingLSLCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingBeginLSL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingLSLCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingLSLCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingLSLCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingLSLCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingLSLCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"HighlightingLSLCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"HighlightingLSLCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"HighlightingLSLCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingBeginLSL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1HighlightingLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1HighlightingLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingLaTeXCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingLaTeXCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingBeginLaTeX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingLaTeXCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingLaTeXCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingLaTeXCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingLaTeXCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingLaTeXCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL$HighlightingLaTeXCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL$HighlightingLaTeXCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL$HighlightingLaTeXCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingBeginLaTeX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingLilyPondCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingLilyPondCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingBeginLilyPond\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingLilyPondCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingLilyPondCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL!HighlightingLilyPondCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL!HighlightingLilyPondCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL!HighlightingLilyPondCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL'HighlightingLilyPondCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL'HighlightingLilyPondCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL'HighlightingLilyPondCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingBeginLilyPond\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingLiterate Haskell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingLiterate Haskell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLELiterate Haskell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingLiterate HaskellCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingLiterate HaskellCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL!HighlightingBeginLiterate Haskell\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL$HighlightingLiterate HaskellCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL$HighlightingLiterate HaskellCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL)HighlightingLiterate HaskellCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL)HighlightingLiterate HaskellCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL)HighlightingLiterate HaskellCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL/HighlightingLiterate HaskellCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL/HighlightingLiterate HaskellCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL/HighlightingLiterate HaskellCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL!HighlightingBeginLiterate Haskell\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3HighlightingLogtalk\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3HighlightingLogtalk\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingLogtalkCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingLogtalkCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingBeginLogtalk\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingLogtalkCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingLogtalkCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL HighlightingLogtalkCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL HighlightingLogtalkCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL HighlightingLogtalkCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL&HighlightingLogtalkCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL&HighlightingLogtalkCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL&HighlightingLogtalkCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingBeginLogtalk\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIHighlightingLua\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIHighlightingLua\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXLua\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingLuaCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingLuaCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingBeginLua\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingLuaCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingLuaCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingLuaCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingLuaCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingLuaCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"HighlightingLuaCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"HighlightingLuaCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"HighlightingLuaCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingBeginLua\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingMakefile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingMakefile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bMakefile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bMakefile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEstrings_and_vars\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingMakefileCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingMakefileCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingBeginMakefile\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingMakefileCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingMakefileCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL!HighlightingMakefileCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL!HighlightingMakefileCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL!HighlightingMakefileCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL'HighlightingMakefileCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL'HighlightingMakefileCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL'HighlightingMakefileCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingBeginMakefile\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingMako\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingMako\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingMakoCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingMakoCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginMako\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingMakoCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingMakoCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingMakoCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingMakoCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingMakoCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingMakoCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingMakoCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingMakoCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginMako\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingMarkdown\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingMarkdown\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bMarkdown\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingMarkdownCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingMarkdownCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingBeginMarkdown\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingMarkdownCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingMarkdownCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL!HighlightingMarkdownCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL!HighlightingMarkdownCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL!HighlightingMarkdownCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL'HighlightingMarkdownCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL'HighlightingMarkdownCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL'HighlightingMarkdownCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingBeginMarkdown\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1HighlightingMason\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1HighlightingMason\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingMasonCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingMasonCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingBeginMason\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingMasonCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingMasonCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingMasonCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingMasonCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingMasonCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL$HighlightingMasonCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL$HighlightingMasonCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL$HighlightingMasonCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingBeginMason\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingMathematica\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingMathematica\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vMathematica\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingMathematicaCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingMathematicaCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingBeginMathematica\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USHighlightingMathematicaCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USHighlightingMathematicaCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL$HighlightingMathematicaCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL$HighlightingMathematicaCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL$HighlightingMathematicaCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL*HighlightingMathematicaCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL*HighlightingMathematicaCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL*HighlightingMathematicaCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingBeginMathematica\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingMatlab\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingMatlab\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKMatlab\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingMatlabCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingMatlabCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBeginMatlab\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingMatlabCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingMatlabCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USHighlightingMatlabCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USHighlightingMatlabCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USHighlightingMatlabCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL%HighlightingMatlabCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL%HighlightingMatlabCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL%HighlightingMatlabCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBeginMatlab\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingMaxima\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingMaxima\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKMaxima\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingMaximaCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingMaximaCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBeginMaxima\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingMaximaCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingMaximaCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USHighlightingMaximaCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USHighlightingMaximaCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USHighlightingMaximaCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL%HighlightingMaximaCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL%HighlightingMaximaCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL%HighlightingMaximaCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBeginMaxima\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1HighlightingMeson\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1HighlightingMeson\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingMesonCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingMesonCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingBeginMeson\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingMesonCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingMesonCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingMesonCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingMesonCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingMesonCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL$HighlightingMesonCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL$HighlightingMesonCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL$HighlightingMesonCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingBeginMeson\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingModelica\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingModelica\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingModelicaCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingModelicaCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingBeginModelica\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingModelicaCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingModelicaCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL!HighlightingModelicaCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL!HighlightingModelicaCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL!HighlightingModelicaCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL'HighlightingModelicaCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL'HighlightingModelicaCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL'HighlightingModelicaCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingBeginModelica\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingModula-2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingModula-2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bModula-2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingModula-2CodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingModula-2CodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingBeginModula-2\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingModula-2CodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingModula-2CodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL!HighlightingModula-2CodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL!HighlightingModula-2CodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL!HighlightingModula-2CodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL'HighlightingModula-2CodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL'HighlightingModula-2CodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL'HighlightingModula-2CodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingBeginModula-2\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingNSIS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingNSIS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingNSISCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingNSISCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginNSIS\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingNSISCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingNSISCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingNSISCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingNSISCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingNSISCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingNSISCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingNSISCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingNSISCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginNSIS\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3HighlightingNemerle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3HighlightingNemerle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingNemerleCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingNemerleCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingBeginNemerle\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingNemerleCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingNemerleCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL HighlightingNemerleCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL HighlightingNemerleCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL HighlightingNemerleCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL&HighlightingNemerleCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL&HighlightingNemerleCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL&HighlightingNemerleCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingBeginNemerle\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIHighlightingNim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIHighlightingNim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXNim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingNimCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingNimCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingBeginNim\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingNimCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingNimCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingNimCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingNimCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingNimCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"HighlightingNimCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"HighlightingNimCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"HighlightingNimCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingBeginNim\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIHighlightingNix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIHighlightingNix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXNix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingNixCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingNixCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingBeginNix\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingNixCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingNixCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingNixCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingNixCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingNixCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"HighlightingNixCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"HighlightingNixCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"HighlightingNixCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingBeginNix\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingObjective Caml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingObjective Caml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOObjective Caml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL!HighlightingObjective CamlCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL!HighlightingObjective CamlCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USHighlightingBeginObjective Caml\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"HighlightingObjective CamlCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"HighlightingObjective CamlCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL'HighlightingObjective CamlCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL'HighlightingObjective CamlCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL'HighlightingObjective CamlCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL-HighlightingObjective CamlCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL-HighlightingObjective CamlCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL-HighlightingObjective CamlCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USHighlightingBeginObjective Caml\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingObjective-C\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingObjective-C\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vObjective-C\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingObjective-C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingObjective-C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rObjective-C++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL HighlightingObjective-C++CodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL HighlightingObjective-C++CodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingBeginObjective-C++\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL!HighlightingObjective-C++CodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL!HighlightingObjective-C++CodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL&HighlightingObjective-C++CodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL&HighlightingObjective-C++CodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL&HighlightingObjective-C++CodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL,HighlightingObjective-C++CodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL,HighlightingObjective-C++CodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL,HighlightingObjective-C++CodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingBeginObjective-C++\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingObjective-CCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingObjective-CCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingBeginObjective-C\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USHighlightingObjective-CCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USHighlightingObjective-CCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL$HighlightingObjective-CCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL$HighlightingObjective-CCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL$HighlightingObjective-CCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL*HighlightingObjective-CCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL*HighlightingObjective-CCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL*HighlightingObjective-CCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingBeginObjective-C\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingOctave\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingOctave\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKOctave\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingOctaveCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingOctaveCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBeginOctave\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingOctaveCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingOctaveCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USHighlightingOctaveCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USHighlightingOctaveCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USHighlightingOctaveCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL%HighlightingOctaveCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL%HighlightingOctaveCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL%HighlightingOctaveCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBeginOctave\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3HighlightingPHP/PHP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3HighlightingPHP/PHP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aPHP/PHP\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingPHP/PHPCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingPHP/PHPCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingBeginPHP/PHP\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingPHP/PHPCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingPHP/PHPCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL HighlightingPHP/PHPCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL HighlightingPHP/PHPCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL HighlightingPHP/PHPCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL&HighlightingPHP/PHPCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL&HighlightingPHP/PHPCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL&HighlightingPHP/PHPCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingBeginPHP/PHP\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3HighlightingPOV-Ray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3HighlightingPOV-Ray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aPOV-Ray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingPOV-RayCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingPOV-RayCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingBeginPOV-Ray\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingPOV-RayCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingPOV-RayCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL HighlightingPOV-RayCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL HighlightingPOV-RayCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL HighlightingPOV-RayCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL&HighlightingPOV-RayCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL&HighlightingPOV-RayCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL&HighlightingPOV-RayCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingBeginPOV-Ray\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingPascal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingPascal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPascal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingPascalCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingPascalCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBeginPascal\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingPascalCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingPascalCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USHighlightingPascalCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USHighlightingPascalCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USHighlightingPascalCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL%HighlightingPascalCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL%HighlightingPascalCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL%HighlightingPascalCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBeginPascal\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPerl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingPerlCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingPerlCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginPerl\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingPerlCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingPerlCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingPerlCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingPerlCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingPerlCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingPerlCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingPerlCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingPerlCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginPerl\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIHighlightingPig\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIHighlightingPig\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingPigCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingPigCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingBeginPig\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingPigCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingPigCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingPigCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingPigCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingPigCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"HighlightingPigCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"HighlightingPigCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"HighlightingPigCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingBeginPig\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingPike\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingPike\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTPike\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingPikeCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingPikeCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginPike\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingPikeCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingPikeCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingPikeCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingPikeCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingPikeCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingPikeCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingPikeCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingPikeCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginPike\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingPony\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingPony\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingPonyCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingPonyCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginPony\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingPonyCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingPonyCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingPonyCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingPonyCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingPonyCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingPonyCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingPonyCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingPonyCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginPony\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingPostScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingPostScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nPostScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingPostScriptCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingPostScriptCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingBeginPostScript\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingPostScriptCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingPostScriptCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingPostScriptCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingPostScriptCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingPostScriptCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL)HighlightingPostScriptCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL)HighlightingPostScriptCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL)HighlightingPostScriptCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingBeginPostScript\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingPowerShell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingPowerShell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nPowerShell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingPowerShellCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingPowerShellCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingBeginPowerShell\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingPowerShellCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingPowerShellCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingPowerShellCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingPowerShellCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingPowerShellCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL)HighlightingPowerShellCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL)HighlightingPowerShellCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL)HighlightingPowerShellCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingBeginPowerShell\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1HighlightingPraat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1HighlightingPraat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingPraatCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingPraatCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingBeginPraat\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingPraatCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingPraatCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingPraatCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingPraatCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingPraatCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL$HighlightingPraatCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL$HighlightingPraatCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL$HighlightingPraatCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingBeginPraat\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingProlog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingProlog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKProlog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingPrologCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingPrologCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBeginProlog\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingPrologCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingPrologCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USHighlightingPrologCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USHighlightingPrologCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USHighlightingPrologCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL%HighlightingPrologCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL%HighlightingPrologCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL%HighlightingPrologCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBeginProlog\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingProtobuf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingProtobuf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bProtobuf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingProtobufCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingProtobufCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingBeginProtobuf\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingProtobufCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingProtobufCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL!HighlightingProtobufCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL!HighlightingProtobufCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL!HighlightingProtobufCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL'HighlightingProtobufCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL'HighlightingProtobufCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL'HighlightingProtobufCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingBeginProtobuf\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIHighlightingPug\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIHighlightingPug\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingPugCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingPugCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingBeginPug\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingPugCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingPugCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingPugCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingPugCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingPugCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"HighlightingPugCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"HighlightingPugCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"HighlightingPugCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingBeginPug\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingPuppet\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingPuppet\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingPuppetCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingPuppetCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBeginPuppet\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingPuppetCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingPuppetCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USHighlightingPuppetCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USHighlightingPuppetCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USHighlightingPuppetCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL%HighlightingPuppetCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL%HighlightingPuppetCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL%HighlightingPuppetCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBeginPuppet\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKPython\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingPythonCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingPythonCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBeginPython\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingPythonCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingPythonCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USHighlightingPythonCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USHighlightingPythonCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USHighlightingPythonCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL%HighlightingPythonCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL%HighlightingPythonCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL%HighlightingPythonCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBeginPython\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIHighlightingQML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIHighlightingQML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXQML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingQMLCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingQMLCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingBeginQML\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingQMLCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingQMLCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingQMLCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingQMLCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingQMLCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"HighlightingQMLCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"HighlightingQMLCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"HighlightingQMLCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingBeginQML\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingREXX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingREXX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingREXXCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingREXXCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginREXX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingREXXCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingREXXCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingREXXCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingREXXCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingREXXCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingREXXCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingREXXCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingREXXCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginREXX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingRPM Spec\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingRPM Spec\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingRPM SpecCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingRPM SpecCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingBeginRPM Spec\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingRPM SpecCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingRPM SpecCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL!HighlightingRPM SpecCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL!HighlightingRPM SpecCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL!HighlightingRPM SpecCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL'HighlightingRPM SpecCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL'HighlightingRPM SpecCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL'HighlightingRPM SpecCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingBeginRPM Spec\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingRacket\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingRacket\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingRacketCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingRacketCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBeginRacket\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingRacketCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingRacketCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USHighlightingRacketCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USHighlightingRacketCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USHighlightingRacketCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL%HighlightingRacketCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL%HighlightingRacketCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL%HighlightingRacketCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBeginRacket\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingRelaxNG-Compact\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingRelaxNG-Compact\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIRelaxNG-Compact\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"HighlightingRelaxNG-CompactCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"HighlightingRelaxNG-CompactCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL HighlightingBeginRelaxNG-Compact\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingRelaxNG-CompactCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingRelaxNG-CompactCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL(HighlightingRelaxNG-CompactCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL(HighlightingRelaxNG-CompactCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL(HighlightingRelaxNG-CompactCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL.HighlightingRelaxNG-CompactCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL.HighlightingRelaxNG-CompactCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL.HighlightingRelaxNG-CompactCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL HighlightingBeginRelaxNG-Compact\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingRuby\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingRuby\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTRuby\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTRuby\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTRuby\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTExpr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingRuby/Rails/RHTML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingRuby/Rails/RHTML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLERuby/Rails/RHTML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingRuby/Rails/RHTMLCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingRuby/Rails/RHTMLCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL!HighlightingBeginRuby/Rails/RHTML\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL$HighlightingRuby/Rails/RHTMLCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL$HighlightingRuby/Rails/RHTMLCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL)HighlightingRuby/Rails/RHTMLCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL)HighlightingRuby/Rails/RHTMLCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL)HighlightingRuby/Rails/RHTMLCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL/HighlightingRuby/Rails/RHTMLCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL/HighlightingRuby/Rails/RHTMLCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL/HighlightingRuby/Rails/RHTMLCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL!HighlightingBeginRuby/Rails/RHTML\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingRubyCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingRubyCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginRuby\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingRubyCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingRubyCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingRubyCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingRubyCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingRubyCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingRubyCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingRubyCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingRubyCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginRuby\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingRust\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingRust\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTRust\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingRustCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingRustCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginRust\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingRustCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingRustCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingRustCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingRustCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingRustCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingRustCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingRustCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingRustCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginRust\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingSASS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingSASS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTSASS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingSASSCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingSASSCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginSASS\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingSASSCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingSASSCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingSASSCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingSASSCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingSASSCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingSASSCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingSASSCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingSASSCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginSASS\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingSCSS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingSCSS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTSCSS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTSCSS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bSelector\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingSCSSCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingSCSSCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginSCSS\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingSCSSCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingSCSSCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingSCSSCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingSCSSCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingSCSSCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingSCSSCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingSCSSCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingSCSSCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginSCSS\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIHighlightingSML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIHighlightingSML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXSML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingSMLCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingSMLCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingBeginSML\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingSMLCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingSMLCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingSMLCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingSMLCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingSMLCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"HighlightingSMLCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"HighlightingSMLCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"HighlightingSMLCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingBeginSML\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIHighlightingSQL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIHighlightingSQL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXSQL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingSQL (MySQL)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingSQL (MySQL)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vSQL (MySQL)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingSQL (MySQL)CodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingSQL (MySQL)CodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingBeginSQL (MySQL)\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USHighlightingSQL (MySQL)CodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USHighlightingSQL (MySQL)CodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL$HighlightingSQL (MySQL)CodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL$HighlightingSQL (MySQL)CodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL$HighlightingSQL (MySQL)CodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL*HighlightingSQL (MySQL)CodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL*HighlightingSQL (MySQL)CodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL*HighlightingSQL (MySQL)CodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingBeginSQL (MySQL)\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingSQLCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingSQLCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingBeginSQL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingSQLCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingSQLCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingSQLCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingSQLCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingSQLCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"HighlightingSQLCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"HighlightingSQLCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"HighlightingSQLCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingBeginSQL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1HighlightingScala\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1HighlightingScala\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQScala\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingScalaCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingScalaCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingBeginScala\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingScalaCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingScalaCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingScalaCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingScalaCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingScalaCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL$HighlightingScalaCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL$HighlightingScalaCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL$HighlightingScalaCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingBeginScala\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingScheme\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingScheme\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKScheme\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingSchemeCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingSchemeCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBeginScheme\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingSchemeCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingSchemeCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USHighlightingSchemeCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USHighlightingSchemeCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USHighlightingSchemeCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL%HighlightingSchemeCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL%HighlightingSchemeCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL%HighlightingSchemeCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBeginScheme\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingSelector\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingSelector\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\230\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTabap\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingABAPCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\factionscript\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingActionScript 2.0CodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXas\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingActionScript 2.0CodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXada\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingAdaCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTagda\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingAgdaCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\napacheconf\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL'HighlightingApache ConfigurationCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQaconf\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL'HighlightingApache ConfigurationCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKapache\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL'HighlightingApache ConfigurationCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nautohotkey\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingAutoHotKeyCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXahk\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingAutoHotKeyCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXawk\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingAWKCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTgawk\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingAWKCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmawk\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingAWKCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTnawk\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingAWKCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbash\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBashCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXsh\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBashCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXksh\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBashCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXzsh\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBashCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQshell\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBashCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKbibtex\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingBibTeXCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXbib\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingBibTeXCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXboo\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingBooCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOHc\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingCCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcmake\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingCMakeCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcsharp\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingC#CodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXcs\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingC#CodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aclojure\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingClojureCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXclj\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingClojureCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcoffee\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USHighlightingCoffeeScriptCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ncommonlisp\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingCommon LispCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXcl\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingCommon LispCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlisp\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingCommon LispCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcpp\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingC++CodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcss\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingCSSCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOHd\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingDCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdart\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingDartCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdelphi\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingPascalCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXpas\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingPascalCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpascal\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingPascalCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fobjectpascal\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingPascalCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdiff\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingDiffCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQudiff\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingDiffCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdtd\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingDTDCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKeiffel\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingEiffelCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKelixir\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingElixirCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXex\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingElixirCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXexs\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingElixirCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXelm\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingElmCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQemail\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingEmailCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXeml\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingEmailCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKerlang\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingErlangCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfish\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingFishCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tfishshell\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingFishCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQforth\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingANS-Forth94CodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ffortranfixed\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL)HighlightingFortran (Fixed Format)CodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\afortran\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL(HighlightingFortran (Free Format)CodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOHf\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL(HighlightingFortran (Free Format)CodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXgap\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingGAPCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bgdscript\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingGodotCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXgd\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingGodotCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTglsl\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingGLSLCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQgcode\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingG-CodeCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\agnuplot\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingGnuplotCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXgo\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingGoCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKgolang\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingGoCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKgroovy\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingGroovyCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOThaml\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingHamlCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ahaskell\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingHaskellCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXhs\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingHaskellCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOThaxe\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingHaxeCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOThxsl\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingHaxeCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXhx\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingHaxeCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOThtml\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingHTMLCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXidl\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingIDLCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQidris\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingIdrisCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXidr\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingIdrisCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKinform\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingInformCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOHi\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingInformCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXini\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingINI FilesCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcfg\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingINI FilesCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdosini\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingINI FilesCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOHj\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingJCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTjava\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingJavaCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\njavascript\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingJavaScriptCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXjs\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingJavaScriptCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXjcl\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingJCLCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTjson\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingJSONCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\njsonobject\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingJSONCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQjulia\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingJuliaCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXjl\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingJuliaCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\akconfig\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingKconfigCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nmenuconfig\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingKconfigCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vlinuxconfig\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingKconfigCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fkernelconfig\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingKconfigCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKkotlin\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingKotlinCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlsl\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingLSLCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTless\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingLESSCSSCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\blilypond\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingLilyPondCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIliteratehaskell\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingLiterate HaskellCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\blhaskell\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingLiterate HaskellCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlhs\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingLiterate HaskellCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTllvm\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingLLVMCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\alogtalk\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingLogtalkCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlua\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingLuaCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmake\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingMakefileCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmakefile\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingMakefileCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXmf\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingMakefileCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\absdmake\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingMakefileCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmako\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingMakoCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmarkdown\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingMarkdownCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXmd\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingMarkdownCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmason\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingMasonCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vmathematica\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingMathematicaCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmma\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingMathematicaCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXnb\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingMathematicaCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmatlab\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingMatlabCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmaxima\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingMaximaCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amacsyma\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingMaximaCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmeson\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingMesonCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nmesonbuild\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingMesonCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmodelica\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingModelicaCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmodula\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingModula-2CodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOHm\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingModula-2CodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmysql\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingSQL (MySQL)CodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTnsis\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingNSISCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXnsi\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingNSISCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXnsh\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingNSISCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTnasm\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingIntel x86 (NASM)CodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\anemerle\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingNemerleCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTnesc\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingnesCCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKnimrod\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingNimCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXnim\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingNimCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQnixos\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingNixCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXnix\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingNixCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nobjectivec\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingObjective-CCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTobjc\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingObjective-CCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fobjectivecpp\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL HighlightingObjective-C++CodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKobjcpp\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL HighlightingObjective-C++CodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQocaml\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL!HighlightingObjective CamlCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKoctave\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingOctaveCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTperl\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingPerlCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXpl\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingPerlCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXphp\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingPHP/PHPCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXpig\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingPigCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTpike\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingPikeCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTpony\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingPonyCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\npostscript\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingPostScriptCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apostscr\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingPostScriptCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXpov\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingPOV-RayCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\npowershell\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingPowerShellCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTpwsh\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingPowerShellCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTposh\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingPowerShellCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXps\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingPowerShellCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXpsm\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingPowerShellCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpraat\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingPraatCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKprolog\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingPrologCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bprotobuf\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingProtobufCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQproto\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingProtobufCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXpug\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingPugCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTjade\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingPugCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpuppet\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingPuppetCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpython\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingPythonCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXpy\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingPythonCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsage\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingPythonCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXqml\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingQMLCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXqbs\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingQMLCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nrngcompact\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"HighlightingRelaxNG-CompactCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrnc\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"HighlightingRelaxNG-CompactCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTspec\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingRPM SpecCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKracket\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingRacketCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrkt\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingRacketCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTrexx\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingREXXCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQarexx\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingREXXCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrhtml\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingRuby/Rails/RHTMLCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ahtmlerb\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingRuby/Rails/RHTMLCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bhtmlruby\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingRuby/Rails/RHTMLCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrst\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingreStructuredTextCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTrest\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingreStructuredTextCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTruby\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingRubyCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXrb\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingRubyCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTduby\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingRubyCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTrust\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingRustCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXrs\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingRustCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsml\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingSMLCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsass\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingSASSCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQscala\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingScalaCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKscheme\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingSchemeCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXscm\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingSchemeCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKscilab\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingscilabCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTscss\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingSCSSCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsed\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingsedCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTgsed\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingsedCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTssed\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingsedCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsieve\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingSieveCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsmali\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingSmaliCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsolidity\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingSolidityCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQspice\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingSpiceCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tspicelang\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingSpiceCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsql\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingSQLCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTstan\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingStanCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQstata\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingStataCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdo\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingStataCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQswift\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingSwiftCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rsystemverilog\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL HighlightingSystemVerilogCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXsv\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL HighlightingSystemVerilogCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtoml\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingTOMLCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtads\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingTADS 3CodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXtcl\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingTcl/TkCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtcsh\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingTcshCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcsh\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingTcshCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tterraform\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingTerraformCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXtf\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingTerraformCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXtex\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingLaTeXCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlatex\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingLaTeXCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\atodotxt\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingTodo.txtCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ntypescript\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingTypeScriptCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXts\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingTypeScriptCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTvala\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingValaCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTvapi\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingValaCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvelocity\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingVelocityCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\averilog\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingVerilogCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOHv\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingVerilogCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTvhdl\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingVHDLCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXxml\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingXMLCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bxorgconf\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL&Highlightingx.org ConfigurationCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTxslt\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingxsltCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTyaml\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingYAMLCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTyang\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingYANGCodeEnv\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX]}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANUnknownHighlightingBegin\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK[^]}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1HighlightingSieve\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1HighlightingSieve\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingSieveCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingSieveCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingBeginSieve\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingSieveCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingSieveCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingSieveCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingSieveCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingSieveCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL$HighlightingSieveCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL$HighlightingSieveCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL$HighlightingSieveCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingBeginSieve\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1HighlightingSmali\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1HighlightingSmali\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingSmaliCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingSmaliCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingBeginSmali\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingSmaliCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingSmaliCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingSmaliCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingSmaliCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingSmaliCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL$HighlightingSmaliCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL$HighlightingSmaliCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL$HighlightingSmaliCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingBeginSmali\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingSolidity\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingSolidity\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingSolidityCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingSolidityCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingBeginSolidity\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingSolidityCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingSolidityCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL!HighlightingSolidityCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL!HighlightingSolidityCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL!HighlightingSolidityCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL'HighlightingSolidityCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL'HighlightingSolidityCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL'HighlightingSolidityCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingBeginSolidity\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1HighlightingSpice\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1HighlightingSpice\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingSpiceCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingSpiceCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingBeginSpice\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingSpiceCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingSpiceCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingSpiceCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingSpiceCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingSpiceCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL$HighlightingSpiceCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL$HighlightingSpiceCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL$HighlightingSpiceCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingBeginSpice\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingStan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingStan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTStan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingStanCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingStanCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginStan\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingStanCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingStanCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingStanCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingStanCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingStanCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingStanCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingStanCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingStanCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginStan\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1HighlightingStata\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1HighlightingStata\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQStata\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingStataCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingStataCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingBeginStata\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingStataCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingStataCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingStataCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingStataCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingStataCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL$HighlightingStataCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL$HighlightingStataCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL$HighlightingStataCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingBeginStata\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1HighlightingSwift\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1HighlightingSwift\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQSwift\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingSwiftCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingSwiftCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingBeginSwift\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingSwiftCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingSwiftCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingSwiftCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingSwiftCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingSwiftCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL$HighlightingSwiftCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL$HighlightingSwiftCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL$HighlightingSwiftCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingBeginSwift\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingSystemVerilog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingSystemVerilog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rSystemVerilog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL HighlightingSystemVerilogCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL HighlightingSystemVerilogCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingBeginSystemVerilog\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL!HighlightingSystemVerilogCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL!HighlightingSystemVerilogCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL&HighlightingSystemVerilogCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL&HighlightingSystemVerilogCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL&HighlightingSystemVerilogCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL,HighlightingSystemVerilogCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL,HighlightingSystemVerilogCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL,HighlightingSystemVerilogCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingBeginSystemVerilog\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingTADS 3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingTADS 3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingTADS 3CodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingTADS 3CodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBeginTADS 3\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingTADS 3CodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingTADS 3CodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USHighlightingTADS 3CodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USHighlightingTADS 3CodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USHighlightingTADS 3CodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL%HighlightingTADS 3CodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL%HighlightingTADS 3CodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL%HighlightingTADS 3CodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBeginTADS 3\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingTOML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingTOML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTOML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingTOMLCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingTOMLCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginTOML\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingTOMLCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingTOMLCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingTOMLCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingTOMLCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingTOMLCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingTOMLCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingTOMLCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingTOMLCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginTOML\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingTcl/Tk\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingTcl/Tk\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKTcl/Tk\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingTcl/TkCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingTcl/TkCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBeginTcl/Tk\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingTcl/TkCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingTcl/TkCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USHighlightingTcl/TkCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USHighlightingTcl/TkCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USHighlightingTcl/TkCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL%HighlightingTcl/TkCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL%HighlightingTcl/TkCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL%HighlightingTcl/TkCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBeginTcl/Tk\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTcsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingTcshCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingTcshCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginTcsh\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingTcshCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingTcshCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingTcshCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingTcshCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingTcshCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingTcshCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingTcshCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingTcshCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginTcsh\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingTerraform\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingTerraform\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingTerraformCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingTerraformCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingBeginTerraform\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingTerraformCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingTerraformCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"HighlightingTerraformCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"HighlightingTerraformCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"HighlightingTerraformCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL(HighlightingTerraformCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL(HighlightingTerraformCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL(HighlightingTerraformCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingBeginTerraform\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingTodo.txt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingTodo.txt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingTodo.txtCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingTodo.txtCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingBeginTodo.txt\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingTodo.txtCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingTodo.txtCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL!HighlightingTodo.txtCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL!HighlightingTodo.txtCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL!HighlightingTodo.txtCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL'HighlightingTodo.txtCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL'HighlightingTodo.txtCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL'HighlightingTodo.txtCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingBeginTodo.txt\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTypeScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNormal\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingTypeScriptCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingTypeScriptCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingBeginTypeScript\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingTypeScriptCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingTypeScriptCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingTypeScriptCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingTypeScriptCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingTypeScriptCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL)HighlightingTypeScriptCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL)HighlightingTypeScriptCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL)HighlightingTypeScriptCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingBeginTypeScript\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingVHDL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingVHDL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTVHDL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingVHDLCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingVHDLCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginVHDL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingVHDLCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingVHDLCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingVHDLCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingVHDLCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingVHDLCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingVHDLCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingVHDLCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingVHDLCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginVHDL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingVala\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingVala\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingValaCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingValaCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginVala\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingValaCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingValaCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingValaCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingValaCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingValaCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingValaCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingValaCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingValaCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginVala\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingVelocity\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingVelocity\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingVelocityCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingVelocityCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingBeginVelocity\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingVelocityCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingVelocityCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL!HighlightingVelocityCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL!HighlightingVelocityCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL!HighlightingVelocityCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL'HighlightingVelocityCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL'HighlightingVelocityCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL'HighlightingVelocityCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingBeginVelocity\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3HighlightingVerilog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3HighlightingVerilog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aVerilog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingVerilogCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingVerilogCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingBeginVerilog\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingVerilogCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingVerilogCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL HighlightingVerilogCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL HighlightingVerilogCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL HighlightingVerilogCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL&HighlightingVerilogCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL&HighlightingVerilogCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL&HighlightingVerilogCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingBeginVerilog\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIHighlightingXML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIHighlightingXML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXXML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingXMLCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingXMLCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingBeginXML\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingXMLCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingXMLCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingXMLCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingXMLCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingXMLCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"HighlightingXMLCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"HighlightingXMLCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"HighlightingXMLCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingBeginXML\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTYAML\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingYAMLCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingYAMLCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginYAML\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingYAMLCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingYAMLCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingYAMLCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingYAMLCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingYAMLCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingYAMLCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingYAMLCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingYAMLCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginYAML\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingYANG\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingYANG\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingYANGCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingYANGCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginYANG\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingYANGCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingYANGCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingYANGCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingYANGCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingYANGCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingYANGCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingYANGCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingYANGCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginYANG\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingnesC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingnesC\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingnesCCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingnesCCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginnesC\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingnesCCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingnesCCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingnesCCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingnesCCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingnesCCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingnesCCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingnesCCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingnesCCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginnesC\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingreStructuredText\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingreStructuredText\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEreStructuredText\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingreStructuredTextCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingreStructuredTextCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL!HighlightingBeginreStructuredText\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL$HighlightingreStructuredTextCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL$HighlightingreStructuredTextCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL)HighlightingreStructuredTextCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL)HighlightingreStructuredTextCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL)HighlightingreStructuredTextCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL/HighlightingreStructuredTextCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL/HighlightingreStructuredTextCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL/HighlightingreStructuredTextCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL!HighlightingBeginreStructuredText\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2Highlightingscilab\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2Highlightingscilab\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKscilab\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingscilabCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingscilabCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBeginscilab\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingscilabCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingscilabCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USHighlightingscilabCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USHighlightingscilabCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USHighlightingscilabCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL%HighlightingscilabCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL%HighlightingscilabCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL%HighlightingscilabCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBeginscilab\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIHighlightingsed\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIHighlightingsed\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsed\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQStart\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsed\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCommand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingsedCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingsedCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingBeginsed\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingsedCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingsedCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingsedCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingsedCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingsedCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"HighlightingsedCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"HighlightingsedCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"HighlightingsedCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingBeginsed\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USHighlightingx.org Configuration\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USHighlightingx.org Configuration\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3x.org Configuration\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL&Highlightingx.org ConfigurationCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL&Highlightingx.org ConfigurationCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL$HighlightingBeginx.org Configuration\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL'Highlightingx.org ConfigurationCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL'Highlightingx.org ConfigurationCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL,Highlightingx.org ConfigurationCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL,Highlightingx.org ConfigurationCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL,Highlightingx.org ConfigurationCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL2Highlightingx.org ConfigurationCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL2Highlightingx.org ConfigurationCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL2Highlightingx.org ConfigurationCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL$HighlightingBeginx.org Configuration\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingxslt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHighlightingxslt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2HighlightingCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTxslt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingxsltCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingxsltCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginxslt\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingxsltCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingxsltCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingxsltCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingxsltCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingxsltCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingxsltCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingxsltCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingxsltCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingBeginxslt\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLabel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLabel\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOLabelParameter\NUL[\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vLabelOption\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vLabelOption\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vLabelOption\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\\(\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rMathModeLatex\NUL\\\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bContrSeq\NUL$\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vMathModeTex\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\195\151\SUB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL]\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOLabelParameter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOLabelParameter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\195\151\SUB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLatexEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLatexEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vLatexEnvEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vLatexEnvEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nLatexMacro\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nLatexMacro\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\\begin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4FindBeginEnvironment\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\\end\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2FindEndEnvironment\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t\n !$%&()+,-./:;<=>?[]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL#\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\\Autocite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\\Cite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v\\Citeauthor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\\Cref\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\\Cref*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\\Footcite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\\Parencite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\\Textcite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\\autocite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\\autoref\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\\cite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v\\citeauthor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\\citep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\\citet\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\\citetitle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\\citeurl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\\citeyear\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\\cref\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\\cref*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\\eqref\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\\footcite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r\\footfullcite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\\fullcite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\\label\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\\nocite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\\pagecite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\\pageref\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\\parencite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\\ref\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\\subref\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\\subref*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\\supercite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\\textcite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\\vpageref\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\\vref\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLabel\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t\n !$%&()+,-./:;<=>?[]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r\\bibliography\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2\\bibliographystyle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\documentclass\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\\include\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE\\includegraphics\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v\\usepackage\NAK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nFancyLabel\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t\n !$%&()+,-./:;<=>?[]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\\Autocites\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\\Cites\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\\Footcites\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v\\Parencites\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\\autocites\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\\cites\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\\footcites\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v\\parencites\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v\\supercites\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nFancyLabel\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t\n !$%&()+,-./:;<=>?[]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\\chapter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\\chapter*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\\paragraph\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v\\paragraph*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\\part\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\\part*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\\section\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\\section*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r\\subparagraph\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\subparagraph*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v\\subsection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\\subsection*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\subsubsection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\\subsubsection*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nSectioning\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t\n !$%&()+,-./:;<=>?[]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\\column\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\\definecolor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\\geometry\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\\hspace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\\hspace*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\\input\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v\\newboolean\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\\rule\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v\\setboolean\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v\\setcounter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\\setlength\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\\special\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\\textcolor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\\vspace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\\vspace*\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOSpecialCommand\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t\n !$%&()+,-./:;<=>?[]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\\footnote\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\\footnote*\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nFootnoting\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t\n !$%&()+,-./:;<=>?[]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v\\newcommand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\\newcommand*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\\providecommand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE\\providecommand*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r\\renewcommand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\renewcommand*\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nNewCommand\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t\n !$%&()+,-./:;<=>?[]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\\edef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\\gdef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\\xdef\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nDefCommand\SOH\\(\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rMathModeLatex\SOH\\[\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKMathModeLatexEquation\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t\n !$%&()+,-./:;<=>?[]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v\\ensuremath\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOMathModeEnsure\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t\n !$%&()+,-./:;<=>?[]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\\iffalse\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Multiline Comment\NUL\\\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bContrSeq\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vListingsEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vListingsEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEListingsEnvParam\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEListingsEnvParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEListingsEnvParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL[\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNListingsEnvParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3UnknownHighlighting\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3UnknownHighlighting\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3ListingsEnvParamEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3ListingsEnvParamEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3UnknownHighlighting\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3UnknownHighlighting\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNListingsEnvParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNListingsEnvParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\\s*language\\s*=\\s*(?=[^],])\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingSelector\NUL]\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3ListingsEnvParamEnd\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tLstinline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tLstinline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\DLE\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL[\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEFancyLabelOption\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2LstinlineParameter\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX(.)\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fLstinlineEnd\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fLstinlineEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fLstinlineEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX%1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\195\151\SUB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n[^%1\\xd7]*\SOH\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2LstinlineParameter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2LstinlineParameter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fMathContrSeq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fMathContrSeq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\195\151\SUB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO[a-zA-Z]+\\*?|.\SOH\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aMathEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aMathEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vMathModeEnv\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2MathEnvParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2MathEnvParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vMathModeEnv\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEMathEnvWithParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEMathEnvWithParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNMathEnvWithParamInside\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNMathEnvWithParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNMathEnvWithParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX[]\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2MathEnvParamInside\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIMathEnvironment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIMathEnvironment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKMathEnvironmentInside\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH.\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2MathEnvironmentEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2MathEnvironmentEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANMathEnvironmentEndInside\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH.\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANMathEnvironmentEndInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANMathEnvironmentEndInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nensuremath\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vLatexEnvEnd\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f[a-zA-Z]+\\*?\SOH\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r[^}a-zA-Z]+|.\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKMathEnvironmentInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKMathEnvironmentInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t\n !$%&()+,-./:;<=>?[]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\blongtabu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tlongtabu*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtabu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtabu*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vMathTabuEnv\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f[a-zA-Z]+\\*?\SOH\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r[^}a-zA-Z]+|.\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vMathFindEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vMathFindEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t\n !$%&()+,-./:;<=>?[]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aalignat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\balignat*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bxalignat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\txalignat*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\txxalignat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nxxalignat*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1MathFindEndInside\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t\n !$%&()+,-./:;<=>?[]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL$\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aBmatrix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bBmatrix*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fIEEEeqnarray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rIEEEeqnarray*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIIEEEeqnarraybox\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEIEEEeqnarraybox*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aVmatrix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bVmatrix*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQalign\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKalign*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\abmatrix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bbmatrix*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcases\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcases*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vdisplaymath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fdisplaymath*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\beqnarray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\teqnarray*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bequation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tequation*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aflalign\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bflalign*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKgather\NUL\NUL\NUL\NUL\NUL\NUL\NUL\agather*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmath*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmultline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tmultline*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apmatrix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpmatrix*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vsmallmatrix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fsmallmatrix*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vsubeqnarray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fsubeqnarray*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\avmatrix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvmatrix*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1MathFindEndInside\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f[a-zA-Z]+\\*?\SOH\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3NoMathFindEndInside\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH.\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1MathFindEndInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1MathFindEndInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bMathMode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bMathMode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL$\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOMathModeCommon\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOMathModeCommon\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOMathModeCommon\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\\\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBBackslashMathModeCommon\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\195\151\SUB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIMathModeDisplay\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIMathModeDisplay\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\SOH$$\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL$\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOMathModeCommon\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOMathModeEnsure\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOMathModeEnsure\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4MathModeEnsureInside\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH.\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4MathModeEnsureInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4MathModeEnsureInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL{\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4MathModeEnsureInside\NUL}\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOMathModeCommon\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vMathModeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vMathModeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\DLE\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\\\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4BackslashMathModeEnv\NUL$\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\195\151\SUB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rMathModeLatex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rMathModeLatex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SOH\\)\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOMathModeCommon\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKMathModeLatexEquation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKMathModeLatexEquation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SOH\\]\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOMathModeCommon\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vMathModeTex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vMathModeTex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL$\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIMathModeDisplay\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bMathMode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fMathModeText\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fMathModeText\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBMathModeTextParameterStart\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fMathContrSeq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2MathModeTextInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2MathModeTextInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBMathModeTextParameterStart\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBMathModeTextParameterStart\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBMathModeTextParameterStart\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\195\151\SUB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX$$\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2MathModeTextInside\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\\\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fMathContrSeq\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bMathTabu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bMathTabu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1MathTabuPreambule\NUL\\\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vMathTabuEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vMathTabuEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bMathTabu\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1MathTabuPreambule\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1MathTabuPreambule\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1MathTabuPreambule\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tMintParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tMintParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SOH}[\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX]}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTVerb\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rMintedCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rMintedCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\SOH\202\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tabapcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingABAPCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\babapcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingABAPCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1actionscriptcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL$HighlightingActionScript 2.0CodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEactionscriptcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingActionScript 2.0CodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aascode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL$HighlightingActionScript 2.0CodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKascode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingActionScript 2.0CodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\badacode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingAdaCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aadacode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingAdaCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tagdacode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingAgdaCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bagdacode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingAgdaCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIapacheconfcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL(HighlightingApache ConfigurationCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOapacheconfcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL'HighlightingApache ConfigurationCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\naconfcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL(HighlightingApache ConfigurationCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\taconfcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL'HighlightingApache ConfigurationCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vapachecode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL(HighlightingApache ConfigurationCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\napachecode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL'HighlightingApache ConfigurationCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIautohotkeycode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingAutoHotKeyCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOautohotkeycode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingAutoHotKeyCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bahkcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingAutoHotKeyCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aahkcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingAutoHotKeyCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bawkcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingAWKCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aawkcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingAWKCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tgawkcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingAWKCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bgawkcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingAWKCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tmawkcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingAWKCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmawkcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingAWKCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tnawkcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingAWKCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bnawkcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingAWKCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tbashcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingBashCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bbashcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBashCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ashcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingBashCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKshcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBashCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bkshcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingBashCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\akshcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBashCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bzshcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingBashCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\azshcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBashCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nshellcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingBashCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tshellcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBashCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vbibtexcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingBibTeXCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nbibtexcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingBibTeXCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bbibcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingBibTeXCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\abibcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingBibTeXCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bboocode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingBooCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aboocode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingBooCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKccode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingCCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQccode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingCCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ncmakecode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingCMakeCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tcmakecode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingCMakeCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vcsharpcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingC#CodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ncsharpcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingC#CodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acscode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingC#CodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcscode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingC#CodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fclojurecode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingClojureCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vclojurecode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingClojureCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcljcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingClojureCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acljcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingClojureCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vcoffeecode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL HighlightingCoffeeScriptCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ncoffeecode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USHighlightingCoffeeScriptCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIcommonlispcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USHighlightingCommon LispCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOcommonlispcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingCommon LispCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aclcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USHighlightingCommon LispCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKclcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingCommon LispCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tlispcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USHighlightingCommon LispCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\blispcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingCommon LispCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcppcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingC++CodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acppcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingC++CodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcsscode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingCSSCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acsscode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingCSSCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingDCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingDCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdartcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingDartCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdartcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingDartCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vdelphicode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingPascalCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ndelphicode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingPascalCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpascode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingPascalCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apascode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingPascalCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vpascalcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingPascalCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\npascalcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingPascalCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1objectpascalcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingPascalCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEobjectpascalcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingPascalCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdiffcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingDiffCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdiffcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingDiffCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nudiffcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingDiffCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tudiffcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingDiffCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdtdcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingDTDCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adtdcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingDTDCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\veiffelcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingEiffelCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\neiffelcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingEiffelCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\velixircode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingElixirCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nelixircode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingElixirCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aexcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingElixirCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKexcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingElixirCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bexscode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingElixirCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aexscode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingElixirCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\belmcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingElmCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aelmcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingElmCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nemailcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingEmailCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\temailcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingEmailCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bemlcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingEmailCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aemlcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingEmailCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\verlangcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingErlangCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nerlangcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingErlangCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tfishcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingFishCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bfishcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingFishCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOfishshellcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingFishCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rfishshellcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingFishCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nforthcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USHighlightingANS-Forth94CodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tforthcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingANS-Forth94CodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1fortranfixedcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL*HighlightingFortran (Fixed Format)CodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEfortranfixedcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL)HighlightingFortran (Fixed Format)CodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ffortrancode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL)HighlightingFortran (Free Format)CodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vfortrancode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL(HighlightingFortran (Free Format)CodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL)HighlightingFortran (Free Format)CodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL(HighlightingFortran (Free Format)CodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bgapcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingGAPCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\agapcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingGAPCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rgdscriptcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingGodotCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fgdscriptcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingGodotCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\agdcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingGodotCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKgdcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingGodotCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tglslcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingGLSLCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bglslcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingGLSLCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ngcodecode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingG-CodeCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tgcodecode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingG-CodeCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fgnuplotcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingGnuplotCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vgnuplotcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingGnuplotCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\agocode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingGoCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKgocode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingGoCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vgolangcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingGoCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ngolangcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingGoCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vgroovycode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingGroovyCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ngroovycode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingGroovyCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\thamlcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingHamlCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bhamlcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingHamlCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fhaskellcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingHaskellCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vhaskellcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingHaskellCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ahscode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingHaskellCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKhscode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingHaskellCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\thaxecode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingHaxeCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bhaxecode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingHaxeCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\thxslcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingHaxeCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bhxslcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingHaxeCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ahxcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingHaxeCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKhxcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingHaxeCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\thtmlcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingHTMLCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bhtmlcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingHTMLCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bidlcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingIDLCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aidlcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingIDLCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nidriscode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingIdrisCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tidriscode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingIdrisCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bidrcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingIdrisCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aidrcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingIdrisCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vinformcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingInformCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ninformcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingInformCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKicode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingInformCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQicode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingInformCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\binicode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingINI FilesCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ainicode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingINI FilesCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcfgcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingINI FilesCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acfgcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingINI FilesCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vdosinicode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingINI FilesCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ndosinicode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingINI FilesCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKjcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKHighlightingJCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQjcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingJCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tjavacode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingJavaCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bjavacode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingJavaCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIjavascriptcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingJavaScriptCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOjavascriptcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingJavaScriptCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ajscode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingJavaScriptCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKjscode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingJavaScriptCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bjclcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingJCLCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ajclcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingJCLCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tjsoncode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingJSONCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bjsoncode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingJSONCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIjsonobjectcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingJSONCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOjsonobjectcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingJSONCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\njuliacode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingJuliaCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tjuliacode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingJuliaCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ajlcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingJuliaCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKjlcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingJuliaCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fkconfigcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingKconfigCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vkconfigcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingKconfigCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SImenuconfigcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingKconfigCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOmenuconfigcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingKconfigCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLElinuxconfigcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingKconfigCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIlinuxconfigcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingKconfigCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1kernelconfigcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingKconfigCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEkernelconfigcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingKconfigCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vkotlincode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingKotlinCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nkotlincode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingKotlinCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\blslcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingLSLCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\alslcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingLSLCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tlesscode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingLESSCSSCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\blesscode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingLESSCSSCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rlilypondcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingLilyPondCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\flilypondcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingLilyPondCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4literatehaskellcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL$HighlightingLiterate HaskellCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3literatehaskellcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingLiterate HaskellCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rlhaskellcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL$HighlightingLiterate HaskellCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\flhaskellcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingLiterate HaskellCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\blhscode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL$HighlightingLiterate HaskellCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\alhscode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingLiterate HaskellCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tllvmcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingLLVMCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bllvmcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingLLVMCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\flogtalkcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingLogtalkCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vlogtalkcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingLogtalkCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bluacode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingLuaCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aluacode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingLuaCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tmakecode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingMakefileCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmakecode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingMakefileCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rmakefilecode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingMakefileCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fmakefilecode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingMakefileCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amfcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingMakefileCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmfcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingMakefileCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fbsdmakecode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingMakefileCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vbsdmakecode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingMakefileCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tmakocode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingMakoCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmakocode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingMakoCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rmarkdowncode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingMarkdownCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fmarkdowncode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingMarkdownCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amdcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingMarkdownCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmdcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingMarkdownCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nmasoncode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingMasonCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tmasoncode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingMasonCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEmathematicacode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USHighlightingMathematicaCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SImathematicacode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingMathematicaCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bmmacode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USHighlightingMathematicaCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ammacode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingMathematicaCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\anbcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USHighlightingMathematicaCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKnbcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingMathematicaCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vmatlabcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingMatlabCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nmatlabcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingMatlabCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vmaximacode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingMaximaCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nmaximacode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingMaximaCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fmacsymacode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingMaximaCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vmacsymacode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingMaximaCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nmesoncode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingMesonCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tmesoncode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingMesonCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SImesonbuildcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingMesonCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOmesonbuildcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingMesonCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rmodelicacode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingModelicaCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fmodelicacode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingModelicaCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vmodulacode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingModula-2CodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nmodulacode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingModula-2CodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingModula-2CodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingModula-2CodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nmysqlcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USHighlightingSQL (MySQL)CodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tmysqlcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingSQL (MySQL)CodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tnsiscode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingNSISCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bnsiscode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingNSISCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bnsicode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingNSISCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ansicode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingNSISCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bnshcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingNSISCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\anshcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingNSISCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tnasmcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL$HighlightingIntel x86 (NASM)CodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bnasmcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingIntel x86 (NASM)CodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fnemerlecode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingNemerleCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vnemerlecode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingNemerleCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tnesccode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingnesCCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bnesccode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingnesCCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vnimrodcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingNimCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nnimrodcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingNimCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bnimcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingNimCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\animcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingNimCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nnixoscode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingNixCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tnixoscode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingNixCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bnixcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingNixCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\anixcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingNixCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIobjectiveccode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USHighlightingObjective-CCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOobjectiveccode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingObjective-CCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tobjccode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USHighlightingObjective-CCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bobjccode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingObjective-CCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1objectivecppcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL!HighlightingObjective-C++CodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEobjectivecppcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL HighlightingObjective-C++CodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vobjcppcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL!HighlightingObjective-C++CodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nobjcppcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL HighlightingObjective-C++CodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nocamlcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"HighlightingObjective CamlCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tocamlcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL!HighlightingObjective CamlCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\voctavecode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingOctaveCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\noctavecode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingOctaveCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tperlcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingPerlCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bperlcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingPerlCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aplcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingPerlCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKplcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingPerlCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bphpcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingPHP/PHPCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aphpcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingPHP/PHPCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpigcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingPigCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apigcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingPigCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tpikecode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingPikeCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpikecode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingPikeCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tponycode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingPonyCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bponycode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingPonyCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIpostscriptcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingPostScriptCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOpostscriptcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingPostScriptCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fpostscrcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingPostScriptCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vpostscrcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingPostScriptCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpovcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingPOV-RayCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apovcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingPOV-RayCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIpowershellcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingPowerShellCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOpowershellcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingPowerShellCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tpwshcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingPowerShellCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpwshcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingPowerShellCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tposhcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingPowerShellCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bposhcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingPowerShellCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apscode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingPowerShellCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpscode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingPowerShellCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpsmcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingPowerShellCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apsmcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingPowerShellCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\npraatcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingPraatCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tpraatcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingPraatCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vprologcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingPrologCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nprologcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingPrologCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rprotobufcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingProtobufCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fprotobufcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingProtobufCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nprotocode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingProtobufCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tprotocode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingProtobufCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpugcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingPugCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apugcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingPugCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tjadecode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingPugCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bjadecode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingPugCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vpuppetcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingPuppetCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\npuppetcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingPuppetCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vpythoncode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingPythonCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\npythoncode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingPythonCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apycode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingPythonCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpycode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingPythonCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tsagecode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingPythonCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsagecode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingPythonCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bqmlcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingQMLCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aqmlcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingQMLCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bqbscode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingQMLCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aqbscode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingQMLCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIrngcompactcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingRelaxNG-CompactCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOrngcompactcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"HighlightingRelaxNG-CompactCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\brnccode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingRelaxNG-CompactCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\arnccode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"HighlightingRelaxNG-CompactCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tspeccode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingRPM SpecCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bspeccode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingRPM SpecCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vracketcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingRacketCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nracketcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingRacketCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\brktcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingRacketCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\arktcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingRacketCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\trexxcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingREXXCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\brexxcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingREXXCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\narexxcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingREXXCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tarexxcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingREXXCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nrhtmlcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL$HighlightingRuby/Rails/RHTMLCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\trhtmlcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingRuby/Rails/RHTMLCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fhtmlerbcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL$HighlightingRuby/Rails/RHTMLCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vhtmlerbcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingRuby/Rails/RHTMLCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rhtmlrubycode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL$HighlightingRuby/Rails/RHTMLCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fhtmlrubycode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingRuby/Rails/RHTMLCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\brstcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL$HighlightingreStructuredTextCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\arstcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingreStructuredTextCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\trestcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL$HighlightingreStructuredTextCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\brestcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL#HighlightingreStructuredTextCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\trubycode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingRubyCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\brubycode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingRubyCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\arbcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingRubyCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrbcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingRubyCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdubycode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingRubyCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdubycode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingRubyCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\trustcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingRustCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\brustcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingRustCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\arscode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingRustCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKrscode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingRustCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsmlcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingSMLCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asmlcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingSMLCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tsasscode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingSASSCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsasscode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingSASSCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nscalacode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingScalaCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tscalacode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingScalaCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vschemecode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingSchemeCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nschemecode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingSchemeCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bscmcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingSchemeCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ascmcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingSchemeCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vscilabcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingscilabCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nscilabcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingscilabCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tscsscode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingSCSSCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bscsscode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingSCSSCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsedcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingsedCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asedcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingsedCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tgsedcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingsedCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bgsedcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingsedCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tssedcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingsedCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bssedcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingsedCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nsievecode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingSieveCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tsievecode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingSieveCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nsmalicode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingSmaliCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tsmalicode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingSmaliCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rsoliditycode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingSolidityCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fsoliditycode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingSolidityCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nspicecode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingSpiceCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tspicecode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingSpiceCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOspicelangcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingSpiceCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rspicelangcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingSpiceCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsqlcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingSQLCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asqlcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingSQLCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tstancode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingStanCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bstancode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingStanCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nstatacode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingStataCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tstatacode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingStataCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adocode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingStataCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdocode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingStataCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nswiftcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingSwiftCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tswiftcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingSwiftCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2systemverilogcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL!HighlightingSystemVerilogCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1systemverilogcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL HighlightingSystemVerilogCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asvcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL!HighlightingSystemVerilogCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsvcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL HighlightingSystemVerilogCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ttomlcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingTOMLCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btomlcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingTOMLCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ttadscode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingTADS 3CodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btadscode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingTADS 3CodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btclcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingTcl/TkCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\atclcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingTcl/TkCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ttcshcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingTcshCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btcshcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingTcshCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcshcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingTcshCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acshcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingTcshCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOterraformcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingTerraformCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rterraformcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingTerraformCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\atfcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingTerraformCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKtfcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingTerraformCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btexcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingLaTeXCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\atexcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingLaTeXCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nlatexcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMHighlightingLaTeXCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tlatexcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingLaTeXCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ftodotxtcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingTodo.txtCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vtodotxtcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingTodo.txtCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SItypescriptcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingTypeScriptCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOtypescriptcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingTypeScriptCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\atscode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSHighlightingTypeScriptCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKtscode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSHighlightingTypeScriptCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvalacode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingValaCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvalacode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingValaCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvapicode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingValaCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvapicode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingValaCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rvelocitycode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSHighlightingVelocityCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fvelocitycode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingVelocityCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fverilogcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingVerilogCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vverilogcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingVerilogCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCHighlightingVerilogCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQvcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBHighlightingVerilogCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvhdlcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingVHDLCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvhdlcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingVHDLCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bxmlcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingXMLCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\axmlcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNHighlightingXMLCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rxorgconfcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL'Highlightingx.org ConfigurationCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fxorgconfcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL&Highlightingx.org ConfigurationCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\txsltcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingxsltCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bxsltcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingxsltCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tyamlcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingYAMLCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\byamlcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingYAMLCodeEnv\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tyangcode*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANHighlightingYANGCodeEnvS\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\byangcode\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHighlightingYANGCodeEnv\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b.+code\\*\SOH\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCUnknownHighlightingCodeEnvS\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK.+code\SOH\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBUnknownHighlightingCodeEnv\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tMintedEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tMintedEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOMintedEnvParam\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rMintedEnvLang\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rMintedEnvLang\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingSelector\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOMintedEnvParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOMintedEnvParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL[\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4MintedEnvParamInside\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HighlightingSelector\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4MintedEnvParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4MintedEnvParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL]\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rMintedEnvLang\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Multiline Comment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1Multiline Comment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\\\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMBackslashMultilineComment\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nNewCommand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nNewCommand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOLabelParameter\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS(?:\\[\\d\\](?:\\[[^\\]]*\\])?)?\\{\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOLabelParameter\NUL}\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3NoMathFindEndInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3NoMathFindEndInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQNoWeb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQNoWeb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ@\\s*$\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vNormal Text\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vNormal Text\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\\\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nLatexMacro\NUL$\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vMathModeTex\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a<<.*>>=\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQNoWeb\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\195\151\SUB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rRegionComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rRegionComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nSectioning\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nSectioning\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX[]\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESectioningInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2SectioningContrSeq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2SectioningContrSeq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\195\151\SUB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUB[a-zA-Z]+(?:\\+?|\\*{0,3})|.\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESectioningInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESectioningInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESectioningInside\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SOH\\(\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2SectioningMathMode\NUL\\\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2SectioningContrSeq\NUL$\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2SectioningMathMode\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\195\151\SUB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNSectioningMathContrSeq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNSectioningMathContrSeq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\195\151\SUB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO[a-zA-Z]+\\*?|.\SOH\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2SectioningMathMode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2SectioningMathMode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH$$\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL$\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SOH\\)\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SOH\\]\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\\\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNSectioningMathContrSeq\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\195\151\SUB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOSpecialCommand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOSpecialCommand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSSpecialCommandParameterOption\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSSpecialCommandParameterOption\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSSpecialCommandParameterOption\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\\(\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rMathModeLatex\NUL\\\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bContrSeq\NUL$\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vMathModeTex\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\195\151\SUB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSSpecialCommandParameterOption\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXTab\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXTab\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL&\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH@{\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEColumn Separator\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\\\\end\\b\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTabFindEnd\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vNormal Text\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKTabEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKTabEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXTab\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTabFindEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTabFindEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t\n !$%&()+,-./:;<=>?[]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tlongtable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nlongtable*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOmpsupertabular\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SImpsupertabular*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nmpxtabular\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vmpxtabular*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fsupertabular\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rsupertabular*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\atabular\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btabular*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btabularx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ttabularx*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bxtabular\NUL\NUL\NUL\NUL\NUL\NUL\NUL\txtabular*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t\n !$%&()+,-./:;<=>?[]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\blongtabu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tlongtabu*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtabu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtabu*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTabu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTabu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rTabuPreambule\NUL\\\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXTab\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXTab\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aTabuEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aTabuEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTTabu\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rTabuPreambule\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rTabuPreambule\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXTab\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3TabuPreambuleInside\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3TabuPreambuleInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3TabuPreambuleInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3TabuPreambuleInside\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3UnknownHighlighting\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3UnknownHighlighting\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\DLE\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\195\151\SUB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL6\\\\end(?=\\s*\\{(?:lstlisting|minted|[a-zA-Z]+code)\\*?\\})\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNUnknownHighlightingEnd\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANUnknownHighlightingBegin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANUnknownHighlightingBegin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3UnknownHighlighting\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBUnknownHighlightingCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBUnknownHighlightingCodeEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANUnknownHighlightingBegin\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ[^}]*\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCUnknownHighlightingCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCUnknownHighlightingCodeEnvS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL UnknownHighlightingCodeEnvSParam\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL UnknownHighlightingCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL UnknownHighlightingCodeEnvSParam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL&UnknownHighlightingCodeEnvSParamInside\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL&UnknownHighlightingCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL&UnknownHighlightingCodeEnvSParamInside\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANUnknownHighlightingBegin\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fFindComments\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[a-zA-Z]+\\*?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNUnknownHighlightingEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNUnknownHighlightingEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\DLE\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTVerb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTVerb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX(.)\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aVerbEnd\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aVerbEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aVerbEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX%1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\195\151\SUB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n[^%1\\xd7]*\SOH\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVerbFindEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVerbFindEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\t\n !$%&()+,-./:;<=>?[]^{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tBVerbatim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nBVerbatim*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tLVerbatim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nLVerbatim*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bVerbatim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tVerbatim*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rboxedverbatim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOboxedverbatim*\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bverbatim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tverbatim*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tVerbatim1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tVerbatim1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\DLE\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\195\151\SUB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\\\\end(?=\\s*\\{verbatim\\*?\\})\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVerbFindEnd\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tVerbatim2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tVerbatim2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\DLE\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\195\151\SUB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL \\\\end(?=\\s*\\{boxedverbatim\\*?\\})\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVerbFindEnd\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tVerbatim3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tVerbatim3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\DLE\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\195\151\SUB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\\\\end(?=\\s*\\{Verbatim\\*?\\})\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVerbFindEnd\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tVerbatim4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tVerbatim4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\DLE\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\195\151\SUB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\\\\end(?=\\s*\\{BVerbatim\\*?\\})\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVerbFindEnd\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tVerbatim5\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tVerbatim5\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\DLE\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\195\151\SUB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\\\\end(?=\\s*\\{LVerbatim\\*?\\})\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVerbFindEnd\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVerbatimEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVerbatimEnv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tverbatim*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fVerbatimEnv1\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bverbatim\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fVerbatimEnv1\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOboxedverbatim*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fVerbatimEnv2\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rboxedverbatim\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fVerbatimEnv2\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tVerbatim*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fVerbatimEnv3\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bVerbatim\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fVerbatimEnv3\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nBVerbatim*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fVerbatimEnv4\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tBVerbatim\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fVerbatimEnv4\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nLVerbatim*\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fVerbatimEnv5\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tLVerbatim\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fVerbatimEnv5\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fVerbatimEnv1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fVerbatimEnv1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tVerbatim1\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fVerbatimEnv2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fVerbatimEnv2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tVerbatim2\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fVerbatimEnv3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fVerbatimEnv3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1VerbatimEnv3Param\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1VerbatimEnv3Param\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1VerbatimEnv3Param\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX[]\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tVerbatim3\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tVerbatim3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fVerbatimEnv4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fVerbatimEnv4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1VerbatimEnv4Param\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1VerbatimEnv4Param\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1VerbatimEnv4Param\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX[]\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tVerbatim4\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tVerbatim4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fVerbatimEnv5\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fVerbatimEnv5\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1VerbatimEnv5Param\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1VerbatimEnv5Param\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1VerbatimEnv5Param\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX[]\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tVerbatim5\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQLaTeX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tVerbatim5\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\185Jeroen Wijnhout (Jeroen.Wijnhout@kdemail.net)+Holger Danielsson (holger.danielsson@versanet.de)+Michel Ludwig (michel.ludwig@kdemail.net)+Thomas Braun (thomas.braun@virtuell-zuhause.de)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX25\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTLGPL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.tex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.ltx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.dtx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.sty\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.cls\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.bbx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.cbx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.lbx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK*.tikz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.pgf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vNormal Text"
