{-# LANGUAGE OverloadedStrings #-}
-- | Automatically generated syntax definition for LilyPond.
-- DO NOT EDIT THIS FILE MANUALLY.
-- Instead, modify xml/lilypond.xml and 'make bootstrap'.
module Skylighting.Syntax.Lilypond (syntax) where

import Skylighting.Types
import Data.Binary

-- | Syntax definition for LilyPond.
syntax :: Syntax
syntax = decode "\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\flilypond.xml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilypond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcontexts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nChoirStaff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nChordNames\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bCueVoice\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aDevnull\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tDrumStaff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tDrumVoice\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bDynamics\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFiguredBass\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nFretBoards\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKGlobal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nGrandStaff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCGregorianTranscriptionStaff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCGregorianTranscriptionVoice\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKLyrics\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rMensuralStaff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rMensuralVoice\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tNoteNames\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nPianoStaff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rRhythmicStaff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQScore\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQStaff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nStaffGroup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bTabStaff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bTabVoice\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKTiming\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rVaticanaStaff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rVaticanaVoice\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQVoice\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2deprecatedcontexts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIInnerChoirStaff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIInnerStaffGroup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4deprecatedproperties\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4barNumberAlignSymbol\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEcentralCPosition\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3extraVerticalExtent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMfingerHorizontalDirection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQinstr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ninstrument\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2keyAccidentalOrder\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKminimumVerticalExtent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANrehearsalMarkAlignSymbol\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsoloADue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBtupletNumberFormatFunction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvocNam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOdrumpitchnames\NUL\NUL\NUL\NUL\NUL\NUL\NUL\148\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEacousticbassdrum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\racousticsnare\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXagh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXagl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bbassdrum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXbd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXbda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXboh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbohm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTboho\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXbol\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbolm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbolo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcab\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcabasa\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXcb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcgh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcghm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcgho\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcgl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcglm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcglo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rchinesecymbal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXcl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKclaves\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vclosedhihat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acowbell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vcrashcymbal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fcrashcymbala\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fcrashcymbalb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcuim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcuio\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcymc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcymca\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcymcb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcymch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcymr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcymra\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcymrb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcyms\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXde\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\relectricsnare\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bfivedown\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfiveup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bfourdown\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfourup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXgui\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTguil\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQguiro\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTguis\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rhalfopenhihat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bhandclap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXhc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXhh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXhhc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOThhho\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXhho\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXhhp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ahiagogo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ahibongo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ahiconga\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fhighfloortom\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ahightom\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQhihat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bhimidtom\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vhisidestick\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\thitimbale\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vhiwoodblock\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aloagogo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\alobongo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aloconga\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tlongguiro\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vlongwhistle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vlosidestick\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tlotimbale\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vlowfloortom\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tlowmidtom\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vlowoodblock\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlowtom\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amaracas\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tmutecuica\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vmutehibongo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vmutehiconga\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vmutelobongo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vmuteloconga\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fmutetriangle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aonedown\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQoneup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\topencuica\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vopenhibongo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vopenhiconga\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\topenhihat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vopenlobongo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vopenloconga\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fopentriangle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\npedalhihat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXrb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bridebell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nridecymbal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vridecymbala\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vridecymbalb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nshortguiro\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fshortwhistle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tsidestick\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXsn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsna\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsnare\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsne\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fsplashcymbal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXssh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXssl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtamb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ntambourine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKtamtam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tthreedown\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\athreeup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtimh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtiml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtomfh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtomfl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtomh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtoml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtommh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtomml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXtri\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btriangle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtrim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtrio\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXtt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\atwodown\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtwoup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXua\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXuc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXud\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvibraslap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTvibs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXwbh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXwbl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXwhl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXwhs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rlayoutobjects\NUL\NUL\NUL\NUL\NUL\NUL\NUL\130\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nAccidental\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4AccidentalCautionary\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3AccidentalPlacement\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4AccidentalSuggestion\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aAmbitus\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1AmbitusAccidental\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vAmbitusLine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIAmbitusNoteHead\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bArpeggio\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIBalloonTextItem\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aBarLine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tBarNumber\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nBassFigure\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3BassFigureAlignment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSBassFigureAlignmentPositioning\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1BassFigureBracket\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNBassFigureContinuation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOBassFigureLine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBeam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tBendAfter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIBreakAlignGroup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOBreakAlignment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rBreathingSign\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tChordName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTClef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOClusterSpanner\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4ClusterSpannerBeacon\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1CombineTextScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKCustos\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tDotColumn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDots\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3DoublePercentRepeat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBDoublePercentRepeatCounter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2DynamicLineSpanner\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vDynamicText\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2DynamicTextSpanner\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aEpisema\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tFingering\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tFretBoard\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tGlissando\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fGraceSpacing\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bGridLine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tGridPoint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aHairpin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHarmonicParenthesesItem\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1HorizontalBracket\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOInstrumentName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEInstrumentSwitch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIKeyCancellation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fKeySignature\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLELaissezVibrerTie\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNLaissezVibrerTieColumn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1LedgerLineSpanner\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLeftEdge\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SILigatureBracket\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rLyricExtender\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vLyricHyphen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nLyricSpace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tLyricText\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIMeasureGrouping\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nMelodyItem\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEMensuralLigature\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rMetronomeMark\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEMultiMeasureRest\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNMultiMeasureRestNumber\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4MultiMeasureRestText\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKNonMusicalPaperColumn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rNoteCollision\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nNoteColumn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNoteHead\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNoteName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vNoteSpacing\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rOctavateEight\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rOttavaBracket\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vPaperColumn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIParenthesesItem\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rPercentRepeat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4PercentRepeatCounter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fPhrasingSlur\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1PianoPedalBracket\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rRehearsalMark\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vRepeatSlash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tRepeatTie\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIRepeatTieColumn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTRest\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rRestCollision\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fScriptColumn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tScriptRow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOSeparationItem\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTSlur\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOSostenutoPedal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMSostenutoPedalLineSpanner\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOSpacingSpanner\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aSpanBar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fStaffGrouper\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fStaffSpacing\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vStaffSymbol\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fStanzaNumber\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTStem\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vStemTremolo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fStringNumber\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fStrokeFinger\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSustainPedal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBSustainPedalLineSpanner\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKSystem\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOSystemStartBar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESystemStartBrace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2SystemStartBracket\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1SystemStartSquare\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vTabNoteHead\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTextScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vTextSpanner\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXTie\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tTieColumn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rTimeSignature\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4TrillPitchAccidental\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SITrillPitchGroup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOTrillPitchHead\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fTrillSpanner\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rTupletBracket\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fTupletNumber\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rUnaCordaPedal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANUnaCordaPedalLineSpanner\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEVaticanaLigature\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1VerticalAlignment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1VerticalAxisGroup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rVoiceFollower\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fVoltaBracket\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3VoltaBracketSpanner\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEmusicexpressions\NUL\NUL\NUL\NUL\NUL\NUL\NULX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4AbsoluteDynamicEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3AnnotateOutputEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fApplyContext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEApplyOutputEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rArpeggioEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ArticulationEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIAutoChangeMusic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bBarCheck\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIBassFigureEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tBeamEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIBeamForbidEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOBendAfterEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOBreathingEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEClusterNoteEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rContextChange\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3ContextSpeccedMusic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOCrescendoEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEDecrescendoEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nEventChord\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rExtenderEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOFingeringEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOGlissandoEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nGraceMusic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rHarmonicEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vHyphenEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOKeyChangeEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nLabelEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2LaissezVibrerEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rLigatureEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOLineBreakEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1LyricCombineMusic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nLyricEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tMarkEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKMultiMeasureRestEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKMultiMeasureRestMusic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKMultiMeasureTextEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQMusic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tNoteEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1NoteGroupingEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEOverrideProperty\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOPageBreakEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rPageTurnEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEPartCombineMusic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fPercentEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4PercentRepeatedMusic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIPesOrFlexaEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1PhrasingSlurEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vPropertySet\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rPropertyUnset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nQuoteMusic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3RelativeOctaveCheck\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3RelativeOctaveMusic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SORepeatTieEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rRepeatedMusic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tRestEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SORevertProperty\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vScriptEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SISequentialMusic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1SimultaneousMusic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tSkipEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tSkipMusic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tSlurEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSoloOneEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSoloTwoEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOSostenutoEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3SpacingSectionEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tSpanEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOStaffSpanEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1StringNumberEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1StrokeFingerEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSustainEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SITextScriptEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rTextSpanEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bTieEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SITimeScaledMusic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SITransposedMusic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fTremoloEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4TremoloRepeatedMusic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLETremoloSpanEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOTrillSpanEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SITupletSpanEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rUnaCordaEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKUnfoldedRepeatedMusic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fUnisonoEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2UnrelativableMusic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOVoiceSeparator\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2VoltaRepeatedMusic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nproperties\NUL\NUL\NUL\NUL\NUL\NUL\NUL\155\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\baDueText\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1alignAboveContext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBalignBassFigureAccidentals\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1alignBelowContext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOallowBeamBreak\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIassociatedVoice\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIautoAccidentals\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rautoBeamCheck\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEautoBeamSettings\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vautoBeaming\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEautoCautionaries\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rautomaticBars\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tbarAlways\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3barCheckSynchronize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3barNumberVisibility\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nbaseMoment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANbassFigureFormatFunction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3bassStaffProperties\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SObeamExceptions\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fbeatGrouping\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nbeatLength\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rbeatStructure\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fchordChanges\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3chordNameExceptions\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBchordNameExceptionsFull\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBchordNameExceptionsPartial\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1chordNameFunction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2chordNameSeparator\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOchordNoteNamer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1chordPrefixSpacer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOchordRootNamer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tclefGlyph\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOclefOctavation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fclefPosition\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEconnectArpeggios\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3countPercentRepeats\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKcreateKeyOnClefChange\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rcreateSpacing\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEcrescendoSpanner\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rcrescendoText\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEcurrentBarNumber\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2decrescendoSpanner\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIdecrescendoText\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOdefaultBarType\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vdoubleSlurs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEdoubleRepeatType\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOdrumPitchTable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOdrumStyleTable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSdynamicAbsoluteVolumeFunction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNexplicitClefVisibility\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSexplicitKeySignatureVisibility\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2extendersOverRests\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fextraNatural\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSfiguredBassAlterationDirection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSfiguredBassCenterContinuations\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4figuredBassFormatter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANfiguredBassPlusDirection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKfingeringOrientations\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tfirstClef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vfollowVoice\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bfontSize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vforbidBreak\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tforceClef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fgridInterval\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEhairpinToBarline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3harmonicAccidentals\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rhighStringOne\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIignoreBarChecks\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKignoreFiguredBassRest\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIignoreMelismata\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3implicitBassFigures\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USimplicitTimeSignatureVisibility\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1instrumentCueName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3instrumentEqualizer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOinstrumentName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBinstrumentTransposition\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1internalBarNumber\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3keepAliveInterfaces\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2keyAlterationOrder\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fkeySignature\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKlyricMelismaAlignment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEmajorSevenSymbol\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rmarkFormatter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2maximumFretStretch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rmeasureLength\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SImeasurePosition\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKmelismaBusyProperties\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNmetronomeMarkFormatter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3middleCClefPosition\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rmiddleCOffset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SImiddleCPosition\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOmidiInstrument\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1midiMaximumVolume\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1midiMinimumVolume\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vminimumFret\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKminimumPageTurnLength\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSminimumRepeatLengthForPageTurn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2noteToFretFunction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nottavation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKoutput\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKpedalSostenutoStrings\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3pedalSostenutoStyle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3pedalSustainStrings\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1pedalSustainStyle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4pedalUnaCordaStrings\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2pedalUnaCordaStyle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4printKeyCancellation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEprintOctaveNames\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKprintPartCombineTexts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSproportionalNotationDuration\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3recordEventSequence\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rrehearsalMark\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOrepeatCommands\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3restNumberThreshold\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1scriptDefinitions\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIshapeNoteStyles\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3shortInstrumentName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOshortVocalName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bskipBars\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIskipTypesetting\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nsoloIIText\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsoloText\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEsquashedPosition\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBstaffLineLayoutFunction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstanza\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1stemLeftBeamCount\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2stemRightBeamCount\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANstringNumberOrientations\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEstringOneTopmost\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rstringTunings\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANstrokeFingerOrientations\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOsubdivideBeams\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2suggestAccidentals\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4systemStartDelimiter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSsystemStartDelimiterHierarchy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SItablatureFormat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOtempoUnitCount\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1tempoUnitDuration\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4tempoWholesPerMinute\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOtieWaitForNote\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKtimeSignatureFraction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKtiming\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtonic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1topLevelAlignment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKtrebleStaffProperties\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ftremoloFlags\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEtupletFullLength\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4tupletFullLengthNote\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKtupletSpannerDuration\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNuseBassFigureExtenders\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANverticallySpacedContexts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvocalName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEvoltaOnThisStaff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4voltaSpannerDuration\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bwhichBar\NUL\NUL\NUL\NUL\NUL\NUL\NUL9\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nassignment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nassignment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL[\\b(dash(Hat|Plus|Dash|Bar|Larger|Dot|Underscore)|fermataMarkup|pipeSymbol|slashSeparator)\\b\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK[a-z]+\NUL\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbasic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbasic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\SOH%{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fcommentblock\NUL%\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vcommentline\NUL\"\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstring\NUL#\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKscheme\NUL$\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tschemesub\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQchord\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQchord\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL>\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bchordend\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\150\\b([a-h]((iss){1,2}|(ess){1,2}|(is){1,2}|(es){1,2}|(sharp){1,2}|(flat){1,2}|ss?|ff?)?|(do|re|mi|fa|sol|la|si)(dd?|bb?|ss?|kk?)?|q)('+|,+|(?![A-Za-z]))\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nchordpitch\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK<Rrs{}\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmusic\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bchordend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bchordend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL`(\\\\(longa|breve)\\b|(1|2|4|8|16|32|64|128|256|512|1024|2048)(?!\\d))(\\s*\\.+)?(\\s*\\*\\s*\\d+(/\\d+)?)*\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tchordmode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tchordmode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL{\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nchordmode2\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nchordmode2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nchordmode2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nchordrules\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nchordpitch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nchordpitch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f=\\s*('+|,+)?\SOH\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NULd(\\\\(longa|breve)\\b|(1|2|4|8|16|32|64|128|256|512|1024|2048)(?!\\d))(\\s*\\.+)?(\\s*\\*\\s*\\d+(/\\d+)?)*|\\d+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nchordrules\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nchordrules\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL{\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nchordrules\NUL}\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\208:?([\\.^]?\\d+[-+]?|(m|dim|aug|maj|sus)(?![A-Za-z]))*(/\\+?\\b([a-h]((iss){1,2}|(ess){1,2}|(is){1,2}|(es){1,2}|(sharp){1,2}|(flat){1,2}|ss?|ff?)?|(do|re|mi|fa|sol|la|si)(dd?|bb?|ss?|kk?)?|q)('+|,+|(?![A-Za-z])))?\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmusic\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acommand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acommand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETB\SOH\\\\\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUB\\\\note(mode|s)(?![A-Za-z])\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bnotemode\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUB\\\\drum(mode|s)(?![A-Za-z])\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdrummode\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\\\\chord(mode|s)(?![A-Za-z])\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tchordmode\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\\\\figure(mode|s)(?![A-Za-z])\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nfiguremode\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL'\\\\(lyric(mode|s)|addlyrics)(?![A-Za-z])\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tlyricmode\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYN\\\\lyricsto(?![A-Za-z])\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\blyricsto\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\\\\markup(lines)?(?![A-Za-z])\SOH\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmarkup\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL#\\\\(header|paper|layout|midi|with)\\b\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asection\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN\\\\(new|context|change)\\b\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acontext\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\\\\(un)?set\\b\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXset\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL*\\\\(override(Property)?|revert)(?![A-Za-z])\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\boverride\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2\\\\skip(?![A-Za-z])\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bduration\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3\\\\tempo(?![A-Za-z])\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtempo\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\195\\\\(accepts|alias|consists|defaultchild|denies|description|grobdescriptions|include|invalid|language|name|objectid|once|remove|sequential|simultaneous|type|version|score|book|bookpart)(?![A-Za-z])\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\n\180\\\\((aiken|funk|sacredHarp|southernHarmony|walker)Heads(Minor)?|acciaccatura|addQuote|afterGrace|allowPageTurn|alternative|apply(Context|Music|Output)|appoggiatura|arpeggio(Arrow(Down|Up)|Bracket|Normal|Parenthesis)?|(a|de)scendens|auctum|augmentum|autoBeamO(ff|n)|autochange|balloon(Grob)?Text|bar|barNumberCheck|bendAfter|breathe|break|cadenzaO(ff|n)|cavum|clef(\\s+(treble|violin|G|alto|C|tenor|(sub)?bass|F|french|(mezzo)?soprano|(var)?baritone|percussion|tab))?|(end)?(de)?cr|cresc(TextCresc|Hairpin)|(cue|transposedCue)During|default|deminutum|dim(Text(Decresc|Decr|Dim)|Hairpin)|display(Lily)?Music|divisio(Maior|Maxima|Minima)|(dynamic|dots|phrasingSlur|slur|stem|tie|tuplet)(Down|Neutral|Up)|(balloon|text)LengthO(ff|n)|featherDurations|figure(mode|s)|finalis|flexa|(french|german|italian|semiGerman)Chords|glissando|grace|harmonic|(unH|h)ideNotes|(hide|show)StaffSwitch|inclinatum|(keep|remove)WithTag|key(\\s+\\b([a-h]((iss){1,2}|(ess){1,2}|(is){1,2}|(es){1,2}|(sharp){1,2}|(flat){1,2}|ss?|ff?)?|(do|re|mi|fa|sol|la|si)(dd?|bb?|ss?|kk?)?|q)('+|,+|(?![A-Za-z])))?|killCues|label|laissezVibrer|linea|makeClusters|mark|maxima|melisma(End)?|mergeDifferently(Head|Dott)edO(ff|n)|newSpacingSection|no(Beam|Break|PageBreak|PageTurn)|normalsize|numericTimeSignature|octaveCheck|oneVoice|oriscus|ottava|page(-ref|Break|Turn)|parallelMusic|parenthesize|partcombine|partial(\\s*(\\\\(longa|breve)\\b|(1|2|4|8|16|32|64|128|256|512|1024|2048)(?!\\d))(\\s*\\.+)?(\\s*\\*\\s*\\d+(/\\d+)?)*)?|pes|pitchedTrill|pointAndClickO(ff|n)|quilisma|quoteDuring|relative(\\s+\\b([a-h]((iss){1,2}|(ess){1,2}|(is){1,2}|(es){1,2}|(sharp){1,2}|(flat){1,2}|ss?|ff?)?|(do|re|mi|fa|sol|la|si)(dd?|bb?|ss?|kk?)?|q)('+|,+|(?![A-Za-z])))?|RemoveEmptyStaffContext|repeat(\\s+(unfold|volta|tremolo|percent)(\\s+\\d+)?)?|repeatTie|resetRelativeOctave|rest|scaleDurations|scoreTweak|easyHeadsO(ff|n)|shift(Durations|Off|On{1,3})|(slur|tie)(Both|Dashed|Dotted|Solid)|small|spacingTweaks|(start|stop)(Group|(Text|Trill)Span|Staff)|stemBoth|stropha|super|(sustain|sostenuto)O(ff|n)|table-of-contents|tag|times?(\\s*\\d+/\\d+)?|tiny|tocItem|transpose(\\s+\\b([a-h]((iss){1,2}|(ess){1,2}|(is){1,2}|(es){1,2}|(sharp){1,2}|(flat){1,2}|ss?|ff?)?|(do|re|mi|fa|sol|la|si)(dd?|bb?|ss?|kk?)?|q)('+|,+|(?![A-Za-z]))\\s*\\b([a-h]((iss){1,2}|(ess){1,2}|(is){1,2}|(es){1,2}|(sharp){1,2}|(flat){1,2}|ss?|ff?)?|(do|re|mi|fa|sol|la|si)(dd?|bb?|ss?|kk?)?|q)('+|,+|(?![A-Za-z])))?|transposition(\\s+\\b([a-h]((iss){1,2}|(ess){1,2}|(is){1,2}|(es){1,2}|(sharp){1,2}|(flat){1,2}|ss?|ff?)?|(do|re|mi|fa|sol|la|si)(dd?|bb?|ss?|kk?)?|q)('+|,+|(?![A-Za-z])))|tweak|unfoldRepeats|virg(ul)?a|voice(One|Two|Three|Four)|withMusicProperty|cm|mm|in|pt|major|minor|ionian|locrian|aeolian|mixolydian|lydian|phrygian|dorian)(?![A-Za-z])\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NULe\\\\(dash(Hat|Plus|Dash|Bar|Larger|Dot|Underscore)|fermataMarkup|pipeSymbol|slashSeparator)(?![A-Za-z])\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\\\\(consistsend)(?![A-Za-z])\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\SOH(\\\\(arpeggio(Up|Down|Neutral)|newpage|script(Up|Down|Both)|(empty|fat)Text|setEasyHeads|(default|voice|modernVoice|piano|forget)Accidentals|(modern(Voice)?|piano)Cautionaries|noResetKey|compressMusic|octave|(sustain|sostenuto)(Down|Up)|set(Hairpin|Text)(Cresc|Decresc|Dim)|setTextDecr)(?![A-Za-z])\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESC\\\\(translator|newcontext)\\b\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acontext\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYN\\\\property(?![A-Za-z])\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\boverride\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v\\\\[A-Za-z]+\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\\\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fcommentblock\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fcommentblock\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\SOH%}\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\DLE\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bComments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vcommentline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vcommentline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bComments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aconnect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aconnect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f+-.12345>^_|\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acontext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acontext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL(\t\n !%&'()*+,-./0123456789:;<=>?[\\]^_{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nChoirStaff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nChordNames\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bCueVoice\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aDevnull\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tDrumStaff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tDrumVoice\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bDynamics\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFiguredBass\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nFretBoards\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKGlobal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nGrandStaff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCGregorianTranscriptionStaff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCGregorianTranscriptionVoice\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKLyrics\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rMensuralStaff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rMensuralVoice\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tNoteNames\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nPianoStaff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rRhythmicStaff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQScore\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQStaff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nStaffGroup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bTabStaff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bTabVoice\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKTiming\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rVaticanaStaff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rVaticanaVoice\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQVoice\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcontext2\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL(\t\n !%&'()*+,-./0123456789:;<=>?[\\]^_{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIInnerChoirStaff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIInnerStaffGroup\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcontext2\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t[A-Za-z]+\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcontext2\NUL{\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsection2\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcontext2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcontext2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE=(\\s*[A-Za-z]+)?\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adefault\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adefault\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH<<\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH>>\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL|\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\\\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acommand\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbasic\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdrumchord\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdrumchord\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL(\t\n !%&'()*+,-./0123456789:;<=>?[\\]^_{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\148\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEacousticbassdrum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\racousticsnare\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXagh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXagl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bbassdrum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXbd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXbda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXboh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbohm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTboho\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXbol\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbolm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbolo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcab\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcabasa\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXcb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcgh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcghm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcgho\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcgl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcglm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcglo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rchinesecymbal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXcl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKclaves\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vclosedhihat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acowbell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vcrashcymbal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fcrashcymbala\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fcrashcymbalb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcuim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcuio\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcymc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcymca\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcymcb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcymch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcymr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcymra\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcymrb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcyms\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXde\NUL\NUL\NUL\NUL\NUL\NUL\NUL\relectricsnare\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bfivedown\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfiveup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bfourdown\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfourup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXgui\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTguil\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQguiro\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTguis\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rhalfopenhihat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bhandclap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXhc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXhh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXhhc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOThhho\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXhho\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXhhp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ahiagogo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ahibongo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ahiconga\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fhighfloortom\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ahightom\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQhihat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bhimidtom\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vhisidestick\NUL\NUL\NUL\NUL\NUL\NUL\NUL\thitimbale\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vhiwoodblock\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aloagogo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\alobongo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aloconga\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tlongguiro\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vlongwhistle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vlosidestick\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tlotimbale\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vlowfloortom\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tlowmidtom\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vlowoodblock\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlowtom\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amaracas\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tmutecuica\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vmutehibongo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vmutehiconga\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vmutelobongo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vmuteloconga\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fmutetriangle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aonedown\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQoneup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\topencuica\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vopenhibongo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vopenhiconga\NUL\NUL\NUL\NUL\NUL\NUL\NUL\topenhihat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vopenlobongo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vopenloconga\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fopentriangle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\npedalhihat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXrb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bridebell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nridecymbal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vridecymbala\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vridecymbalb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nshortguiro\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fshortwhistle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tsidestick\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXsn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsna\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsnare\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsne\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fsplashcymbal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXssh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXssl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtamb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ntambourine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKtamtam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tthreedown\NUL\NUL\NUL\NUL\NUL\NUL\NUL\athreeup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtimh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtiml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtomfh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtomfl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtomh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtoml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtommh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtomml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXtri\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btriangle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtrim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtrio\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXtt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\atwodown\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtwoup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXua\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXuc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXud\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvibraslap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTvibs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXwbh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXwbl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXwhl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXwhs\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQchord\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdrummode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdrummode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL{\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdrummode2\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdrummode2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdrummode2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdrumrules\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdrumrules\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdrumrules\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL{\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdrumrules\NUL}\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK<(?!<)\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdrumchord\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL(\t\n !%&'()*+,-./0123456789:;<=>?[\\]^_{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\148\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEacousticbassdrum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\racousticsnare\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXagh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXagl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bbassdrum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXbd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXbda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXboh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbohm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTboho\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXbol\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbolm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbolo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcab\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcabasa\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXcb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcgh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcghm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcgho\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcgl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcglm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcglo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rchinesecymbal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXcl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKclaves\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vclosedhihat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acowbell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vcrashcymbal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fcrashcymbala\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fcrashcymbalb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcuim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcuio\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcymc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcymca\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcymcb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcymch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcymr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcymra\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcymrb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcyms\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXda\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXde\NUL\NUL\NUL\NUL\NUL\NUL\NUL\relectricsnare\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bfivedown\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfiveup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bfourdown\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfourup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXgui\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTguil\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQguiro\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTguis\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rhalfopenhihat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bhandclap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXhc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXhh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXhhc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOThhho\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXhho\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXhhp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ahiagogo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ahibongo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ahiconga\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fhighfloortom\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ahightom\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQhihat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bhimidtom\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vhisidestick\NUL\NUL\NUL\NUL\NUL\NUL\NUL\thitimbale\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vhiwoodblock\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aloagogo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\alobongo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aloconga\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tlongguiro\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vlongwhistle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vlosidestick\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tlotimbale\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vlowfloortom\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tlowmidtom\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vlowoodblock\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlowtom\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXmar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amaracas\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tmutecuica\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vmutehibongo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vmutehiconga\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vmutelobongo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vmuteloconga\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fmutetriangle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aonedown\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQoneup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\topencuica\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vopenhibongo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vopenhiconga\NUL\NUL\NUL\NUL\NUL\NUL\NUL\topenhihat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vopenlobongo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vopenloconga\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fopentriangle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\npedalhihat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXrb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bridebell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nridecymbal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vridecymbala\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vridecymbalb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nshortguiro\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fshortwhistle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tsidestick\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXsn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsna\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsnare\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsne\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fsplashcymbal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXss\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXssh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXssl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtamb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ntambourine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKtamtam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tthreedown\NUL\NUL\NUL\NUL\NUL\NUL\NUL\athreeup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtimh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtiml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtomfh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtomfl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtomh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtoml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtommh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtomml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXtri\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btriangle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtrim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtrio\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXtt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\atwodown\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtwoup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXua\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXuc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXud\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvibraslap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTvibs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXwbh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXwbl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXwhl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXwhs\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bduration\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmusic\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bduration\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bduration\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL`(\\\\(longa|breve)\\b|(1|2|4|8|16|32|64|128|256|512|1024|2048)(?!\\d))(\\s*\\.+)?(\\s*\\*\\s*\\d+(/\\d+)?)*\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\\d+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfigure\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfigure\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL>\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bchordend\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbasic\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\\\\markup(lines)?(?![A-Za-z])\SOH\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmarkup\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2\\\\skip(?![A-Za-z])\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bduration\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nfiguremode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nfiguremode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL{\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vfiguremode2\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vfiguremode2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vfiguremode2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vfigurerules\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vfigurerules\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vfigurerules\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL{\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vfigurerules\NUL}\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL<\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfigure\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3\\b[srR](?![A-Za-z])\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bduration\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adefault\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\blilypond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\blilypond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmusic\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\\b[a-z]+\\s*=\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nassignment\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tlyricmode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tlyricmode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL{\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nlyricmode2\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nlyricmode2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nlyricmode2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nlyricrules\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nlyricrules\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nlyricrules\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL{\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nlyricrules\NUL}\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL%(\\w+-{2,}|\\w+_{2,}|-{2,}\\w+|_{2,}\\w+)\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL`(\\\\(longa|breve)\\b|(1|2|4|8|16|32|64|128|256|512|1024|2048)(?!\\d))(\\s*\\.+)?(\\s*\\*\\s*\\d+(/\\d+)?)*\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t(--|__|_)\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adefault\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\\S+\\}\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\blyricsto\NUL\NUL\NUL\NUL\NUL\NUL\NUL\blyricsto\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3\"(\\\\[\"\\\\]|[^\"\\\\])+\"\SOH\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tlyricsto2\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t[A-Za-z]+\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tlyricsto2\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tlyricsto2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tlyricsto2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL{\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tlyricsto3\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tlyricsto3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tlyricsto3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nlyricrules\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmarkup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmarkup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL{\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amarkup2\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\\\\score\\b\SOH\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bnotemode\ACK\NUL\NUL\NUL\NUL\NUL\NUL\STX\191\\\\(markup|bold|(rounded-)?box|bracket|caps|(center|general|left|right)-align|circle|((center|dir|left|right)-)?column|combine|concat|dynamic|fill-line|finger|fontCaps|(abs-)?fontsize|fraction|halign|hbracket|hcenter-in|hcenter|hspace|huge|italic|justify|larger?|line|lower|magnify|medium|normal-size-(sub|super)|normal-text|normalsize|number|on-the-fly|override|pad-(around|markup|to-box|x)|page-ref|postscript|put-adjacent|raise|roman|rotate|sans|small(er)?|smallCaps|sub|super|teeny|text|tiny|translate(-scaled)?|transparent|typewriter|underline|upright|vcenter|whiteout|with-(color|dimensions|url)|wordwrap|(markup|column-|justified-|override-|wordwrap-)lines|wordwrap-(string-)?internal)(?![A-Za-z])\SOH\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\SOH\131\\\\(arrow-head|beam|char|(semi|sesqui|double)?(flat|sharp)|draw-(circle|line)|epsfile|eyeglasses|filled-box|fret-diagram(-terse|-verbose)?|fromproperty|harp-pedal|(justify|wordwrap)-(field|string)|left-brace|lookup|markalphabet|markletter|musicglyph|natural|note-by-number|note|null|path|right-brace|simple|(back)?slashed-digit|stencil|strut|tied-lyric|triangle|verbatim-file)(?![A-Za-z])\SOH\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL#\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKscheme\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO[^\"\\s\\\\#%{}$]+\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amarkup2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amarkup2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vmarkuprules\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vmarkuprules\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vmarkuprules\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL}\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL{\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vmarkuprules\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\\\\score\\b\SOH\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bnotemode\ACK\NUL\NUL\NUL\NUL\NUL\NUL\EOT3\\\\(arrow-head|beam|char|(semi|sesqui|double)?(flat|sharp)|draw-(circle|line)|epsfile|eyeglasses|filled-box|fret-diagram(-terse|-verbose)?|fromproperty|harp-pedal|(justify|wordwrap)-(field|string)|left-brace|lookup|markalphabet|markletter|musicglyph|natural|note-by-number|note|null|path|right-brace|simple|(back)?slashed-digit|stencil|strut|tied-lyric|triangle|verbatim-file|markup|bold|(rounded-)?box|bracket|caps|(center|general|left|right)-align|circle|((center|dir|left|right)-)?column|combine|concat|dynamic|fill-line|finger|fontCaps|(abs-)?fontsize|fraction|halign|hbracket|hcenter-in|hcenter|hspace|huge|italic|justify|larger?|line|lower|magnify|medium|normal-size-(sub|super)|normal-text|normalsize|number|on-the-fly|override|pad-(around|markup|to-box|x)|page-ref|postscript|put-adjacent|raise|roman|rotate|sans|small(er)?|smallCaps|sub|super|teeny|text|tiny|translate(-scaled)?|transparent|typewriter|underline|upright|vcenter|whiteout|with-(color|dimensions|url)|wordwrap|(markup|column-|justified-|override-|wordwrap-)lines|wordwrap-(string-)?internal)(?![A-Za-z])\SOH\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\US\\\\(bigger|h?center)(?![A-Za-z])\SOH\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN\\\\[A-Za-z]+(-[A-Za-z]+)*\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbasic\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmusic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmusic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX()~\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX[]\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX-^_\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aconnect\NUL\\\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fmusiccommand\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adefault\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL<\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQchord\NUL>\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1[a-z]+\\d+\\.*[,']+\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\172(\\b[srR](?![A-Za-z])|\\b([a-h]((iss){1,2}|(ess){1,2}|(is){1,2}|(es){1,2}|(sharp){1,2}|(flat){1,2}|ss?|ff?)?|(do|re|mi|fa|sol|la|si)(dd?|bb?|ss?|kk?)?|q)('+|,+|(?![A-Za-z])))\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpitch\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT:\\d*\SOH\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fmusiccommand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fmusiccommand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NULT\\\\((p{1,5}|mp|mf|f{1,5}|s?fp|sff?|spp?|[sr]?fz|cresc|decresc|dim)(?![A-Za-z])|[<!>])\SOH\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\SOH6\\\\(\\d+|accent|marcato|staccat(issim)?o|espressivo|tenuto|portato|(up|down)(bow|mordent|prall)|flageolet|thumb|[lr](heel|toe)|open|stopped|turn|reverseturn|trill|mordent|prall(prall|mordent|down|up)?|lineprall|signumcongruentiae|(short|long|verylong)?fermata|segno|(var)?coda|snappizzicato|halfopen)(?![A-Za-z])\SOH\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\\\\[()]\SOH\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\\\\[][]\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acommand\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bnotemode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bnotemode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL{\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tnotemode2\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tnotemode2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tnotemode2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tnoterules\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tnoterules\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tnoterules\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL{\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tnoterules\NUL}\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmusic\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\boverride\NUL\NUL\NUL\NUL\NUL\NUL\NUL\boverride\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL(\t\n !%&'()*+,-./0123456789:;<=>?[\\]^_{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nChoirStaff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nChordNames\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bCueVoice\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aDevnull\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tDrumStaff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tDrumVoice\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bDynamics\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFiguredBass\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nFretBoards\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKGlobal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nGrandStaff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCGregorianTranscriptionStaff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCGregorianTranscriptionVoice\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKLyrics\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rMensuralStaff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rMensuralVoice\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tNoteNames\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nPianoStaff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rRhythmicStaff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQScore\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQStaff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nStaffGroup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bTabStaff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bTabVoice\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKTiming\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rVaticanaStaff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rVaticanaVoice\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQVoice\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL(\t\n !%&'()*+,-./0123456789:;<=>?[\\]^_{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIInnerChoirStaff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIInnerStaffGroup\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL.\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL(\t\n !%&'()*+,-./0123456789:;<=>?[\\]^_{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\130\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nAccidental\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4AccidentalCautionary\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3AccidentalPlacement\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4AccidentalSuggestion\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aAmbitus\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1AmbitusAccidental\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vAmbitusLine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIAmbitusNoteHead\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bArpeggio\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIBalloonTextItem\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aBarLine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tBarNumber\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nBassFigure\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3BassFigureAlignment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSBassFigureAlignmentPositioning\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1BassFigureBracket\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNBassFigureContinuation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOBassFigureLine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBeam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tBendAfter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIBreakAlignGroup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOBreakAlignment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rBreathingSign\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tChordName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTClef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOClusterSpanner\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4ClusterSpannerBeacon\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1CombineTextScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKCustos\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tDotColumn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDots\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3DoublePercentRepeat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBDoublePercentRepeatCounter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2DynamicLineSpanner\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vDynamicText\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2DynamicTextSpanner\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aEpisema\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tFingering\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tFretBoard\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tGlissando\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fGraceSpacing\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bGridLine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tGridPoint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aHairpin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHarmonicParenthesesItem\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1HorizontalBracket\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOInstrumentName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEInstrumentSwitch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIKeyCancellation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fKeySignature\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLELaissezVibrerTie\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNLaissezVibrerTieColumn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1LedgerLineSpanner\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLeftEdge\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SILigatureBracket\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rLyricExtender\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vLyricHyphen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nLyricSpace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tLyricText\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIMeasureGrouping\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nMelodyItem\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEMensuralLigature\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rMetronomeMark\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEMultiMeasureRest\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNMultiMeasureRestNumber\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4MultiMeasureRestText\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKNonMusicalPaperColumn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rNoteCollision\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nNoteColumn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNoteHead\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNoteName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vNoteSpacing\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rOctavateEight\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rOttavaBracket\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vPaperColumn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIParenthesesItem\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rPercentRepeat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4PercentRepeatCounter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fPhrasingSlur\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1PianoPedalBracket\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rRehearsalMark\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vRepeatSlash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tRepeatTie\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIRepeatTieColumn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTRest\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rRestCollision\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fScriptColumn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tScriptRow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOSeparationItem\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTSlur\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOSostenutoPedal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMSostenutoPedalLineSpanner\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOSpacingSpanner\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aSpanBar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fStaffGrouper\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fStaffSpacing\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vStaffSymbol\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fStanzaNumber\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTStem\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vStemTremolo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fStringNumber\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fStrokeFinger\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSustainPedal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBSustainPedalLineSpanner\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKSystem\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOSystemStartBar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESystemStartBrace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2SystemStartBracket\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1SystemStartSquare\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vTabNoteHead\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTextScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vTextSpanner\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXTie\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tTieColumn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rTimeSignature\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4TrillPitchAccidental\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SITrillPitchGroup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOTrillPitchHead\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fTrillSpanner\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rTupletBracket\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fTupletNumber\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rUnaCordaPedal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANUnaCordaPedalLineSpanner\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEVaticanaLigature\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1VerticalAlignment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1VerticalAxisGroup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rVoiceFollower\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fVoltaBracket\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3VoltaBracketSpanner\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2[A-Za-z]+(?=\\s*\\.)\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t[A-Za-z]+\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpitch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpitch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f=\\s*('+|,+)?\SOH\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX!?\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bduration\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKscheme\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKscheme\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\DLE\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ascheme2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ascheme2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ascheme2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL(\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ascheme3\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vschemerules\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ascheme3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ascheme3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL)\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vschemerules\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2schemecommentblock\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2schemecommentblock\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\SOH!#\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\DLE\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bComments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1schemecommentline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1schemecommentline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bComments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nschemelily\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nschemelily\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SOH#}\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\blilypond\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vschemequote\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vschemequote\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\ACK\NUL\NUL\NUL\NUL\NUL\NUL\a\\\\b(define|defined\\?|define\\*(-public)?|define-(\\*|builtin-markup-(list-)?command|class|(extra-)?display-method|fonts?|grob-property|ly-syntax(-loc|-simple)?|macro(-public)?|markup-(list-)command|method|module|music-function|post-event-display-method|public(-macro|-toplevel)?|safe-public|span-event-display-method)|defmacro(\\*(-public)?)?|lambda\\*?|and|or|if|cond|case|let\\*?|letrec|begin|do|delay|set!|else|(quasi)?quote|unquote(-splicing)?|(define|let|letrec)-syntax|syntax-rules)(?=($|\\s|\\)))|\\b(not|boolean\\?|eq\\?|eqv\\?|equal\\?|pair\\?|cons|set-c[ad]r!|c[ad]{1,4}r|null\\?|list\\?|list|length|append|reverse|list-ref|mem[qv]|member|ass[qv]|assoc|symbol\\?|symbol->string|string->symbol|number\\?|complex\\?|real\\?|rational\\?|integer\\?|exact\\?|inexact\\?|zero\\?|positive\\?|negative\\?|odd\\?|even\\?|max|min|abs|quotient|remainder|modulo|gcd|lcm|numerator|denominator|floor|ceiling|truncate|round|rationalize|exp|log|sin|cos|tan|asin|acos|atan|sqrt|expt|make-rectangular|make-polar|real-part|imag-part|magnitude|angle|exact->inexact|inexact->exact|number->string|string->number)(?=($|\\s|\\)))|\\b(char((-ci)?(=\\?|<\\?|>\\?|<=\\?|>=\\?)|-alphabetic\\?|\\?|-numeric\\?|-whitespace\\?|-upper-case\\?|-lower-case\\?|->integer|-upcase|-downcase|-ready\\?)|integer->char|make-string|string(\\?|-copy|-fill!|-length|-ref|-set!|(-ci)?(=\\?|<\\?|>\\?|<=\\?|>=\\?)|-append)|substring|make-vector|vector(\\?|-length|-ref|-set!|-fill!)?|procedure\\?|apply|map|for-each|force|call-with-(current-continuation|(in|out)put-file)|(in|out)put-port\\?|current-(in|out)put-port|open-(in|out)put-file|close-(in|out)put-port|eof-object\\?|read|(read|peek)-char|write(-char)?|display|newline|call/cc|list-tail|string->list|list->string|vector->list|list->vector|with-input-from-file|with-output-to-file|load|transcript-(on|off)|eval|dynamic-wind|port\\?|values|call-with-values|(scheme-report-|null-|interaction-)environment)(?=($|\\s|\\)))\SOH\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vschemerules\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vschemerules\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\NUL(\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vschemerules\NUL)\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\"\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fschemestring\NUL;\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1schemecommentline\NUL$\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tschemesub\NUL'\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vschemequote\SOH#!\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2schemecommentblock\SOH#{\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nschemelily\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL(\t\n !%&'()*+,-./0123456789:;<=>?[\\]^_{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NULX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4AbsoluteDynamicEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3AnnotateOutputEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fApplyContext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEApplyOutputEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rArpeggioEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ArticulationEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIAutoChangeMusic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bBarCheck\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIBassFigureEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tBeamEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIBeamForbidEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOBendAfterEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOBreathingEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEClusterNoteEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rContextChange\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3ContextSpeccedMusic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOCrescendoEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEDecrescendoEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nEventChord\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rExtenderEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOFingeringEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOGlissandoEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nGraceMusic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rHarmonicEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vHyphenEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOKeyChangeEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nLabelEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2LaissezVibrerEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rLigatureEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOLineBreakEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1LyricCombineMusic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nLyricEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tMarkEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKMultiMeasureRestEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKMultiMeasureRestMusic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKMultiMeasureTextEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQMusic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tNoteEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1NoteGroupingEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEOverrideProperty\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOPageBreakEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rPageTurnEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEPartCombineMusic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fPercentEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4PercentRepeatedMusic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIPesOrFlexaEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1PhrasingSlurEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vPropertySet\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rPropertyUnset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nQuoteMusic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3RelativeOctaveCheck\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3RelativeOctaveMusic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SORepeatTieEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rRepeatedMusic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tRestEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SORevertProperty\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vScriptEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SISequentialMusic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1SimultaneousMusic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tSkipEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tSkipMusic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tSlurEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSoloOneEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSoloTwoEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOSostenutoEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3SpacingSectionEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tSpanEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOStaffSpanEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1StringNumberEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1StrokeFingerEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSustainEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SITextScriptEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rTextSpanEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bTieEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SITimeScaledMusic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SITransposedMusic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fTremoloEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4TremoloRepeatedMusic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLETremoloSpanEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOTrillSpanEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SITupletSpanEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rUnaCordaEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKUnfoldedRepeatedMusic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fUnisonoEvent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2UnrelativableMusic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOVoiceSeparator\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2VoltaRepeatedMusic\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL(\t\n !%&'()*+,-./0123456789:;<=>?[\\]^_{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nChoirStaff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nChordNames\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bCueVoice\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aDevnull\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tDrumStaff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tDrumVoice\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bDynamics\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFiguredBass\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nFretBoards\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKGlobal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nGrandStaff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCGregorianTranscriptionStaff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCGregorianTranscriptionVoice\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKLyrics\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rMensuralStaff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rMensuralVoice\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tNoteNames\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nPianoStaff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rRhythmicStaff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQScore\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQStaff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nStaffGroup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bTabStaff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bTabVoice\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKTiming\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rVaticanaStaff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rVaticanaVoice\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQVoice\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL(\t\n !%&'()*+,-./0123456789:;<=>?[\\]^_{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\130\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nAccidental\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4AccidentalCautionary\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3AccidentalPlacement\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4AccidentalSuggestion\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aAmbitus\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1AmbitusAccidental\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vAmbitusLine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIAmbitusNoteHead\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bArpeggio\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIBalloonTextItem\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aBarLine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tBarNumber\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nBassFigure\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3BassFigureAlignment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSBassFigureAlignmentPositioning\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1BassFigureBracket\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNBassFigureContinuation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOBassFigureLine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBeam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tBendAfter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIBreakAlignGroup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOBreakAlignment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rBreathingSign\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tChordName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTClef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOClusterSpanner\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4ClusterSpannerBeacon\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1CombineTextScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKCustos\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tDotColumn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDots\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3DoublePercentRepeat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBDoublePercentRepeatCounter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2DynamicLineSpanner\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vDynamicText\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2DynamicTextSpanner\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aEpisema\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tFingering\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tFretBoard\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tGlissando\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fGraceSpacing\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bGridLine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tGridPoint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aHairpin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHarmonicParenthesesItem\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1HorizontalBracket\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOInstrumentName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEInstrumentSwitch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIKeyCancellation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fKeySignature\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLELaissezVibrerTie\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNLaissezVibrerTieColumn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1LedgerLineSpanner\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLeftEdge\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SILigatureBracket\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rLyricExtender\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vLyricHyphen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nLyricSpace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tLyricText\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIMeasureGrouping\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nMelodyItem\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEMensuralLigature\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rMetronomeMark\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEMultiMeasureRest\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNMultiMeasureRestNumber\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4MultiMeasureRestText\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKNonMusicalPaperColumn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rNoteCollision\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nNoteColumn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNoteHead\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNoteName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vNoteSpacing\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rOctavateEight\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rOttavaBracket\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vPaperColumn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIParenthesesItem\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rPercentRepeat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4PercentRepeatCounter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fPhrasingSlur\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1PianoPedalBracket\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rRehearsalMark\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vRepeatSlash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tRepeatTie\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIRepeatTieColumn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTRest\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rRestCollision\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fScriptColumn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tScriptRow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOSeparationItem\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTSlur\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOSostenutoPedal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMSostenutoPedalLineSpanner\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOSpacingSpanner\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aSpanBar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fStaffGrouper\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fStaffSpacing\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vStaffSymbol\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fStanzaNumber\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTStem\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vStemTremolo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fStringNumber\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fStrokeFinger\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSustainPedal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBSustainPedalLineSpanner\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKSystem\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOSystemStartBar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESystemStartBrace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2SystemStartBracket\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1SystemStartSquare\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vTabNoteHead\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTextScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vTextSpanner\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXTie\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tTieColumn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rTimeSignature\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4TrillPitchAccidental\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SITrillPitchGroup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOTrillPitchHead\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fTrillSpanner\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rTupletBracket\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fTupletNumber\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rUnaCordaPedal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANUnaCordaPedalLineSpanner\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEVaticanaLigature\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1VerticalAlignment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1VerticalAxisGroup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rVoiceFollower\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fVoltaBracket\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3VoltaBracketSpanner\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL|[-+]?(\\d+(\\.\\d+)?|\\.\\d+)|#([tfTF]|[bB][-+]?[01.]+|[oO][-+]?[0-7.]+|[dD][-+]?[0-9.]+|[xX][-+]?[0-9a-fA-F.]+)|[+-](inf|nan)\\.0\SOH\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\a\\\\b(define|defined\\?|define\\*(-public)?|define-(\\*|builtin-markup-(list-)?command|class|(extra-)?display-method|fonts?|grob-property|ly-syntax(-loc|-simple)?|macro(-public)?|markup-(list-)command|method|module|music-function|post-event-display-method|public(-macro|-toplevel)?|safe-public|span-event-display-method)|defmacro(\\*(-public)?)?|lambda\\*?|and|or|if|cond|case|let\\*?|letrec|begin|do|delay|set!|else|(quasi)?quote|unquote(-splicing)?|(define|let|letrec)-syntax|syntax-rules)(?=($|\\s|\\)))|\\b(not|boolean\\?|eq\\?|eqv\\?|equal\\?|pair\\?|cons|set-c[ad]r!|c[ad]{1,4}r|null\\?|list\\?|list|length|append|reverse|list-ref|mem[qv]|member|ass[qv]|assoc|symbol\\?|symbol->string|string->symbol|number\\?|complex\\?|real\\?|rational\\?|integer\\?|exact\\?|inexact\\?|zero\\?|positive\\?|negative\\?|odd\\?|even\\?|max|min|abs|quotient|remainder|modulo|gcd|lcm|numerator|denominator|floor|ceiling|truncate|round|rationalize|exp|log|sin|cos|tan|asin|acos|atan|sqrt|expt|make-rectangular|make-polar|real-part|imag-part|magnitude|angle|exact->inexact|inexact->exact|number->string|string->number)(?=($|\\s|\\)))|\\b(char((-ci)?(=\\?|<\\?|>\\?|<=\\?|>=\\?)|-alphabetic\\?|\\?|-numeric\\?|-whitespace\\?|-upper-case\\?|-lower-case\\?|->integer|-upcase|-downcase|-ready\\?)|integer->char|make-string|string(\\?|-copy|-fill!|-length|-ref|-set!|(-ci)?(=\\?|<\\?|>\\?|<=\\?|>=\\?)|-append)|substring|make-vector|vector(\\?|-length|-ref|-set!|-fill!)?|procedure\\?|apply|map|for-each|force|call-with-(current-continuation|(in|out)put-file)|(in|out)put-port\\?|current-(in|out)put-port|open-(in|out)put-file|close-(in|out)put-port|eof-object\\?|read|(read|peek)-char|write(-char)?|display|newline|call/cc|list-tail|string->list|list->string|vector->list|list->vector|with-input-from-file|with-output-to-file|load|transcript-(on|off)|eval|dynamic-wind|port\\?|values|call-with-values|(scheme-report-|null-|interaction-)environment)(?=($|\\s|\\)))\SOH\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EM[a-zA-Z#][^\\s(){}[\\];$\"]*\SOH\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fschemestring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fschemestring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\"\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\\\\[0fnrtav\\\\\"]\SOH\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tschemesub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tschemesub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EM[a-zA-Z#][^\\s(){}[\\];$\"]*\SOH\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL{\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsection2\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsection2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsection2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fsectionrules\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fsectionrules\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fsectionrules\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\NUL}\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL{\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fsectionrules\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL(\t\n !%&'()*+,-./0123456789:;<=>?[\\]^_{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nChoirStaff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nChordNames\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bCueVoice\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aDevnull\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tDrumStaff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tDrumVoice\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bDynamics\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFiguredBass\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nFretBoards\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKGlobal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nGrandStaff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCGregorianTranscriptionStaff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCGregorianTranscriptionVoice\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKLyrics\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rMensuralStaff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rMensuralVoice\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tNoteNames\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nPianoStaff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rRhythmicStaff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQScore\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQStaff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nStaffGroup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bTabStaff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bTabVoice\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKTiming\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rVaticanaStaff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rVaticanaVoice\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQVoice\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL(\t\n !%&'()*+,-./0123456789:;<=>?[\\]^_{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIInnerChoirStaff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIInnerStaffGroup\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\ACKA(\"?)\\b(?:(?:Accidental|Ambitus|Arpeggio|Auto_beam|Axis_group|Balloon|Bar|Bar_number|Beam|Bend|Break_align|Breathing_sign|Chord_name|Chord_tremolo|Clef|Cluster_spanner|Collision|Completion_heads|Custos|Default_bar_line|Dot_column|Dots|Drum_notes|Dynami_align|Dynamic|Episema|Extender|Figured_bass|Figured_bass_position|Fingering|Font_size|Forbid_line_break|Fretboard|Glissando|Grace_beam|Grace|Grace_spacing|Grid_line_span|Grid_point|Grob_pq|Hara_kiri|Horizontal_bracket)_engraver|(?:Hyphen|Instrument_name|Instrument_switch|Key|Laissez_vibrer|Ledger_line|Ligature_bracket|Lyric|Mark|Measure_grouping|Melody|Mensural_ligature|Metronome_mark|Multi_measure_rest|New_dynamic|New_fingering|Note_head_line|Note_heads|Note_name|Note_spacing|Ottava_spanner|Output_property|Page_turn|Paper_column|Parenthesis|Part_combine|Percent_repeat|Phrasing_slur|Piano_pedal_align|Piano_pedal|Pitch_squash|Pitched_trill|Repeat_acknowledge|Repeat_tie|Rest_collision|Rest|Rhythmic_column|Scheme|Script_column|Script|Script_row)_engraver|(?:Separating_line_group|Slash_repeat|Slur|Spacing|Span_arpeggio|Span_bar|Spanner_break_forbid|Staff_collecting|Staff_symbol|Stanza_number_align|Stanza_number|Stem|String_number|Swallow|System_start_delimiter|Tab_harmonic|Tab_note_heads|Tab_staff_symbol|Text|Text_spanner|Tie|Time_signature|Trill_spanner|Tuplet|Tweak|Vaticana_ligature|Vertical_align|Vertically_spaced_contexts|Volta)_engraver|(?:Beam|Control_track|Drum_note|Dynamic|Key|Lyric|Note|Piano_pedal|Slur|Staff|Swallow|Tempo|Tie|Time_signature)_performer|(?:Note_swallow|Rest_swallow|Skip_event_swallow|Timing)_translator)\\b\\1\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL(\t\n !%&'()*+,-./0123456789:;<=>?[\\]^_{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\130\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nAccidental\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4AccidentalCautionary\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3AccidentalPlacement\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4AccidentalSuggestion\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aAmbitus\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1AmbitusAccidental\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vAmbitusLine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIAmbitusNoteHead\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bArpeggio\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIBalloonTextItem\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aBarLine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tBarNumber\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nBassFigure\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3BassFigureAlignment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSBassFigureAlignmentPositioning\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1BassFigureBracket\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNBassFigureContinuation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOBassFigureLine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBeam\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tBendAfter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIBreakAlignGroup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOBreakAlignment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rBreathingSign\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tChordName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTClef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOClusterSpanner\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4ClusterSpannerBeacon\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1CombineTextScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKCustos\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tDotColumn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTDots\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3DoublePercentRepeat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBDoublePercentRepeatCounter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2DynamicLineSpanner\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vDynamicText\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2DynamicTextSpanner\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aEpisema\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tFingering\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tFretBoard\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tGlissando\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fGraceSpacing\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bGridLine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tGridPoint\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aHairpin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBHarmonicParenthesesItem\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1HorizontalBracket\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOInstrumentName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEInstrumentSwitch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIKeyCancellation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fKeySignature\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLELaissezVibrerTie\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNLaissezVibrerTieColumn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1LedgerLineSpanner\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLeftEdge\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SILigatureBracket\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rLyricExtender\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vLyricHyphen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nLyricSpace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tLyricText\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIMeasureGrouping\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nMelodyItem\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEMensuralLigature\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rMetronomeMark\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEMultiMeasureRest\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNMultiMeasureRestNumber\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4MultiMeasureRestText\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKNonMusicalPaperColumn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rNoteCollision\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nNoteColumn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNoteHead\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNoteName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vNoteSpacing\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rOctavateEight\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rOttavaBracket\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vPaperColumn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIParenthesesItem\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rPercentRepeat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4PercentRepeatCounter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fPhrasingSlur\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1PianoPedalBracket\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rRehearsalMark\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vRepeatSlash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tRepeatTie\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIRepeatTieColumn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTRest\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rRestCollision\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fScriptColumn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tScriptRow\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOSeparationItem\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTSlur\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOSostenutoPedal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMSostenutoPedalLineSpanner\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOSpacingSpanner\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aSpanBar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fStaffGrouper\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fStaffSpacing\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vStaffSymbol\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fStanzaNumber\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTStem\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vStemTremolo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fStringNumber\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fStrokeFinger\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSustainPedal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBSustainPedalLineSpanner\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKSystem\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOSystemStartBar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLESystemStartBrace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2SystemStartBracket\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1SystemStartSquare\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vTabNoteHead\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nTextScript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vTextSpanner\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXTie\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tTieColumn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rTimeSignature\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4TrillPitchAccidental\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SITrillPitchGroup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOTrillPitchHead\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fTrillSpanner\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rTupletBracket\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fTupletNumber\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rUnaCordaPedal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANUnaCordaPedalLineSpanner\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEVaticanaLigature\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1VerticalAlignment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1VerticalAxisGroup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rVoiceFollower\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fVoltaBracket\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3VoltaBracketSpanner\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL(\t\n !%&'()*+,-./0123456789:;<=>?[\\]^_{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\155\NUL\NUL\NUL\NUL\NUL\NUL\NUL\baDueText\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1alignAboveContext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBalignBassFigureAccidentals\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1alignBelowContext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOallowBeamBreak\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIassociatedVoice\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIautoAccidentals\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rautoBeamCheck\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEautoBeamSettings\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vautoBeaming\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEautoCautionaries\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rautomaticBars\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tbarAlways\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3barCheckSynchronize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3barNumberVisibility\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nbaseMoment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANbassFigureFormatFunction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3bassStaffProperties\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SObeamExceptions\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fbeatGrouping\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nbeatLength\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rbeatStructure\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fchordChanges\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3chordNameExceptions\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBchordNameExceptionsFull\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBchordNameExceptionsPartial\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1chordNameFunction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2chordNameSeparator\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOchordNoteNamer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1chordPrefixSpacer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOchordRootNamer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tclefGlyph\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOclefOctavation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fclefPosition\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEconnectArpeggios\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3countPercentRepeats\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKcreateKeyOnClefChange\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rcreateSpacing\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEcrescendoSpanner\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rcrescendoText\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEcurrentBarNumber\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2decrescendoSpanner\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIdecrescendoText\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOdefaultBarType\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEdoubleRepeatType\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vdoubleSlurs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOdrumPitchTable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOdrumStyleTable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSdynamicAbsoluteVolumeFunction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNexplicitClefVisibility\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSexplicitKeySignatureVisibility\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2extendersOverRests\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fextraNatural\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSfiguredBassAlterationDirection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSfiguredBassCenterContinuations\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4figuredBassFormatter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANfiguredBassPlusDirection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKfingeringOrientations\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tfirstClef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vfollowVoice\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bfontSize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vforbidBreak\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tforceClef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fgridInterval\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEhairpinToBarline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3harmonicAccidentals\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rhighStringOne\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIignoreBarChecks\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKignoreFiguredBassRest\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIignoreMelismata\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3implicitBassFigures\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USimplicitTimeSignatureVisibility\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1instrumentCueName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3instrumentEqualizer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOinstrumentName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBinstrumentTransposition\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1internalBarNumber\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3keepAliveInterfaces\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2keyAlterationOrder\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fkeySignature\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKlyricMelismaAlignment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEmajorSevenSymbol\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rmarkFormatter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2maximumFretStretch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rmeasureLength\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SImeasurePosition\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKmelismaBusyProperties\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNmetronomeMarkFormatter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3middleCClefPosition\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rmiddleCOffset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SImiddleCPosition\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOmidiInstrument\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1midiMaximumVolume\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1midiMinimumVolume\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vminimumFret\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKminimumPageTurnLength\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSminimumRepeatLengthForPageTurn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2noteToFretFunction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nottavation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKoutput\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKpedalSostenutoStrings\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3pedalSostenutoStyle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3pedalSustainStrings\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1pedalSustainStyle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4pedalUnaCordaStrings\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2pedalUnaCordaStyle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4printKeyCancellation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEprintOctaveNames\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKprintPartCombineTexts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSproportionalNotationDuration\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3recordEventSequence\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rrehearsalMark\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOrepeatCommands\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3restNumberThreshold\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1scriptDefinitions\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIshapeNoteStyles\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3shortInstrumentName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOshortVocalName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bskipBars\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIskipTypesetting\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nsoloIIText\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsoloText\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEsquashedPosition\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBstaffLineLayoutFunction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstanza\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1stemLeftBeamCount\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2stemRightBeamCount\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANstringNumberOrientations\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEstringOneTopmost\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rstringTunings\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANstrokeFingerOrientations\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOsubdivideBeams\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2suggestAccidentals\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4systemStartDelimiter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSsystemStartDelimiterHierarchy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SItablatureFormat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOtempoUnitCount\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1tempoUnitDuration\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4tempoWholesPerMinute\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOtieWaitForNote\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKtimeSignatureFraction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKtiming\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtonic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1topLevelAlignment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKtrebleStaffProperties\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ftremoloFlags\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEtupletFullLength\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4tupletFullLengthNote\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKtupletSpannerDuration\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNuseBassFigureExtenders\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANverticallySpacedContexts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvocalName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEvoltaOnThisStaff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4voltaSpannerDuration\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bwhichBar\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\EOT\167\\b(?:dedication|(?:sub){0,2}title|poet|composer|meter|opus|arranger|instrument|piece|breakbefore|copyright|tagline|mutopia(title|composer|poet|opus|instrument)|date|enteredby|source|style|maintainer(Email|Web)?|moreInfo|lastupdated|texidoc|footer|(top|bottom|left|right)-margin|(foot|head)-separation|indent|short-indent|paper-(height|width)|horizontal-shift|line-width|(inner|outer)-margin|two-sided|binding-offset|(after|before|between)-title-space|between-system-(space|padding)|page-top-space|page-breaking-between-system-padding|(after|before|between)-title-spacing|between-(scores-)?system-spacing|bottom-system-spacing|top-title-spacing|top-system-spacing|page-breaking-between-system-spacing|system-count|(min-|max-)?systems-per-page|annotate-spacing|auto-first-page-number|blank-(last-)?page-force|first-page-number|page-count|page-limit-inter-system-space|page-limit-inter-system-space-factor|page-spacing-weight|print-all-headers|print-first-page-number|print-page-number|ragged-(bottom|right)|ragged-last(-bottom)?|system-separator-markup|force-assignment|input-encoding|output-scale|((even|odd)(Footer|Header)|(book|score|toc)Title|tocItem)Markup|system-count|(short-)?indent)\\b\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL(\t\n !%&'()*+,-./0123456789:;<=>?[\\]^_{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4barNumberAlignSymbol\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEcentralCPosition\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3extraVerticalExtent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMfingerHorizontalDirection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQinstr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ninstrument\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2keyAccidentalOrder\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKminimumVerticalExtent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANrehearsalMarkAlignSymbol\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsoloADue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBtupletNumberFormatFunction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvocNam\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adefault\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL(\t\n !%&'()*+,-./0123456789:;<=>?[\\]^_{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nChoirStaff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nChordNames\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bCueVoice\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aDevnull\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tDrumStaff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tDrumVoice\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bDynamics\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFiguredBass\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nFretBoards\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKGlobal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nGrandStaff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCGregorianTranscriptionStaff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCGregorianTranscriptionVoice\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKLyrics\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rMensuralStaff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rMensuralVoice\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tNoteNames\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nPianoStaff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rRhythmicStaff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQScore\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQStaff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nStaffGroup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bTabStaff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bTabVoice\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKTiming\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rVaticanaStaff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rVaticanaVoice\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQVoice\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL(\t\n !%&'()*+,-./0123456789:;<=>?[\\]^_{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIInnerChoirStaff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIInnerStaffGroup\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL.\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL(\t\n !%&'()*+,-./0123456789:;<=>?[\\]^_{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\155\NUL\NUL\NUL\NUL\NUL\NUL\NUL\baDueText\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1alignAboveContext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBalignBassFigureAccidentals\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1alignBelowContext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOallowBeamBreak\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIassociatedVoice\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIautoAccidentals\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rautoBeamCheck\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEautoBeamSettings\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vautoBeaming\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEautoCautionaries\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rautomaticBars\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tbarAlways\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3barCheckSynchronize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3barNumberVisibility\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nbaseMoment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANbassFigureFormatFunction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3bassStaffProperties\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SObeamExceptions\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fbeatGrouping\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nbeatLength\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rbeatStructure\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fchordChanges\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3chordNameExceptions\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBchordNameExceptionsFull\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBchordNameExceptionsPartial\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1chordNameFunction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2chordNameSeparator\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOchordNoteNamer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1chordPrefixSpacer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOchordRootNamer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tclefGlyph\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOclefOctavation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fclefPosition\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEconnectArpeggios\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3countPercentRepeats\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKcreateKeyOnClefChange\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rcreateSpacing\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEcrescendoSpanner\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rcrescendoText\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEcurrentBarNumber\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2decrescendoSpanner\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIdecrescendoText\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOdefaultBarType\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEdoubleRepeatType\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vdoubleSlurs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOdrumPitchTable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOdrumStyleTable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSdynamicAbsoluteVolumeFunction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNexplicitClefVisibility\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSexplicitKeySignatureVisibility\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2extendersOverRests\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fextraNatural\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSfiguredBassAlterationDirection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSfiguredBassCenterContinuations\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4figuredBassFormatter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANfiguredBassPlusDirection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKfingeringOrientations\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tfirstClef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vfollowVoice\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bfontSize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vforbidBreak\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tforceClef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fgridInterval\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEhairpinToBarline\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3harmonicAccidentals\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rhighStringOne\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIignoreBarChecks\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKignoreFiguredBassRest\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIignoreMelismata\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3implicitBassFigures\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USimplicitTimeSignatureVisibility\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1instrumentCueName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3instrumentEqualizer\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOinstrumentName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBinstrumentTransposition\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1internalBarNumber\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3keepAliveInterfaces\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2keyAlterationOrder\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fkeySignature\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKlyricMelismaAlignment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEmajorSevenSymbol\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rmarkFormatter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2maximumFretStretch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rmeasureLength\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SImeasurePosition\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKmelismaBusyProperties\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNmetronomeMarkFormatter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3middleCClefPosition\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rmiddleCOffset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SImiddleCPosition\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOmidiInstrument\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1midiMaximumVolume\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1midiMinimumVolume\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vminimumFret\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKminimumPageTurnLength\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSminimumRepeatLengthForPageTurn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2noteToFretFunction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nottavation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKoutput\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKpedalSostenutoStrings\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3pedalSostenutoStyle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3pedalSustainStrings\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1pedalSustainStyle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4pedalUnaCordaStrings\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2pedalUnaCordaStyle\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4printKeyCancellation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEprintOctaveNames\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKprintPartCombineTexts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FSproportionalNotationDuration\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3recordEventSequence\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rrehearsalMark\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOrepeatCommands\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3restNumberThreshold\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1scriptDefinitions\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIshapeNoteStyles\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3shortInstrumentName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOshortVocalName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bskipBars\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIskipTypesetting\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nsoloIIText\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsoloText\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEsquashedPosition\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBstaffLineLayoutFunction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstanza\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1stemLeftBeamCount\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2stemRightBeamCount\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANstringNumberOrientations\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEstringOneTopmost\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rstringTunings\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANstrokeFingerOrientations\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOsubdivideBeams\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2suggestAccidentals\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4systemStartDelimiter\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSsystemStartDelimiterHierarchy\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SItablatureFormat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOtempoUnitCount\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1tempoUnitDuration\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4tempoWholesPerMinute\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOtieWaitForNote\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKtimeSignatureFraction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKtiming\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtonic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1topLevelAlignment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKtrebleStaffProperties\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ftremoloFlags\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEtupletFullLength\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4tupletFullLengthNote\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKtupletSpannerDuration\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNuseBassFigureExtenders\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANverticallySpacedContexts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tvocalName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEvoltaOnThisStaff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4voltaSpannerDuration\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bwhichBar\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL(\t\n !%&'()*+,-./0123456789:;<=>?[\\]^_{|}~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4barNumberAlignSymbol\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEcentralCPosition\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3extraVerticalExtent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMfingerHorizontalDirection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQinstr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ninstrument\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2keyAccidentalOrder\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKminimumVerticalExtent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANrehearsalMarkAlignSymbol\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsoloADue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBtupletNumberFormatFunction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvocNam\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t[A-Za-z]+\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstring\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\"\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SOH\\\\\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\\\"\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtempo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtempo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS\\\\markup(lines)?(?![A-Za-z])\SOH\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmarkup\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE\\d+\\.*\\s*=\\s*\\d+\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bLilyPond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbasic\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL,Wilbert Berendsen (info@wilbertberendsen.nl)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX11\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTLGPL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT*.ly\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT*.LY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.ily\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.ILY\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.lyi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ*.LYI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\blilypond"
