{-# LANGUAGE OverloadedStrings #-}
-- | Automatically generated syntax definition for Bash.
-- DO NOT EDIT THIS FILE MANUALLY.
-- Instead, modify xml/bash.xml and 'make bootstrap'.
module Skylighting.Syntax.Bash (syntax) where

import Skylighting.Types
import Data.Binary

-- | Syntax definition for Bash.
syntax :: Syntax
syntax = decode "\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bbash.xml\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bbuiltins\NUL\NUL\NUL\NUL\NUL\NUL\NUL-\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH.\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsource\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQalias\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXbg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbind\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\abuiltin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXcd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcaller\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acommand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acompgen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcomplete\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcoproc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdirs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdisown\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTecho\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKenable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTeval\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTexec\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTexit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXfc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXfg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOThash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOThelp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ahistory\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTjobs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTkill\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlogout\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTpopd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKprintf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpushd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXpwd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQshift\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQshopt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asuspend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtest\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtime\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtimes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtrap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKulimit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQumask\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aunalias\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTwait\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fbuiltins_var\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKexport\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adeclare\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\agetopts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlet\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlocal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTread\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\breadonly\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\atypeset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQunset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bkeywords\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbreak\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcontinue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdone\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTelif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTelse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTesac\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXfi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXfor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bfunction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKreturn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKselect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTthen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQuntil\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwhile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\funixcommands\NUL\NUL\NUL\NUL\NUL\NUL\SOHf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTarch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXawk\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQb2sum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKbase32\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKbase64\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\abunzip2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbzcat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbzcmp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKbzdiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\abzegrep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\abzfgrep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKbzgrep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbzip2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fbzip2recover\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKbzless\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKbzmore\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKchattr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQchcon\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQchgrp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQchmod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQchown\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTchvt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcksum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXcp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acrontab\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcsplit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdeallocvt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdircolors\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdmesg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rdnsdomainname\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ndomainname\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdumpkeys\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXed\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQegrep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKexpand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfalse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tfgconsole\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfgrep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfold\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfuser\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTgawk\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vgetkeycodes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTgocr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTgrep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQgroff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKgroups\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKgunzip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQgzexe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTgzip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKhostid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bhostname\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQiconv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQigawk\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ainstall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bkbd_mode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\akbdrate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\akillall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlast\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlastb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlink\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXln\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bloadkeys\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nloadunimap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlogin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXls\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlsattr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlsmod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tlsmod.old\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlzcat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlzcmp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlzdiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\alzegrep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\alzfgrep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlzgrep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlzless\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlzma\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\blzmainfo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlzmore\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amapscrn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmd5sum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmesg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmkdir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmkfifo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmknod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmktemp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmore\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmount\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXmv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTnano\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\anetstat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rnisdomainname\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQnproc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQnroff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKnumfmt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKopenvt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpaste\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apathchk\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpgawk\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpidof\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTping\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpinky\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bprintenv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpstree\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXptx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrbash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\breadlink\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\brealpath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXred\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nresizecons\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXrm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrmdir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\trun-parts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKruncon\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsed\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asetfont\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vsetkeycodes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asetleds\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vsetmetamode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tsetserial\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asha1sum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tsha224sum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tsha256sum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tsha384sum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tsha512sum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ashowkey\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQshred\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTshuf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsleep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTssed\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTstat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstdbuf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTstty\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXsu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsync\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXtar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btempfile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\atimeout\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtouch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtput\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtroff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtrue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btruncate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXtty\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKumount\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQuname\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bunexpand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\runicode_start\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\funicode_stop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKunlink\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKunlzma\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTunxz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\butmpdump\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\auuidgen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTvdir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXvi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTwall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXwc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXxz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQxzcat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fypdomainname\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTzcat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTzcmp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQzdiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKzegrep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKzfgrep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKzforce\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQzgrep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQzless\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQzmore\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTznew\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXzsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aaclocal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\baconnect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQaplay\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXapm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bapmsleep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aapropos\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aarecord\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXas\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTas86\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bautoconf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nautoheader\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bautomake\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bbasename\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXbc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbison\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXc++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXcc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcdda2wav\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ncdparanoia\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcdrdao\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acd-read\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcdrecord\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTchfn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKchroot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTchsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQclear\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcmp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXco\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcol\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcomm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcpio\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcpp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcut\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdiff3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fdirectomatic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adirname\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXenv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTexpr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfbset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfind\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTflex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKflex++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXfmt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfree\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXftp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfunzip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXg++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXgc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXgcc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQclang\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aclang++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvalgrind\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bxdg-open\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcmake\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQqmake\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsvn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXgit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrsync\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXgdb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKgetent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKgetopt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\agettext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ngettextize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTgimp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vgimp-remote\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bgimptool\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQgmake\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXgs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOThead\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ahexdump\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTjoin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXld\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTld86\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXldd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTless\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlocate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\blockfile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\alogname\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXlp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlpr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlynx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXm4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmake\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXman\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmsgfmt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQnamei\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTnasm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTnawk\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTnice\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXnl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXnm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTnm86\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTnmap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQnohup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXnop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpasswd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpatch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpcregrep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpcretest\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTperl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKperror\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXpr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bprocmail\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQprune\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bps2ascii\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aps2epsi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aps2frag\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKps2pdf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQps2ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpsbook\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apsmerge\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpsnup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpsresize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpsselect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpstops\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrcs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrev\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXscp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXseq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asetterm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsize86\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQskill\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKslogin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsnice\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsort\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsox\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsplit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXssh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\assh-add\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tssh-agent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nssh-keygen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vssh-keyscan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\astrings\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQstrip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsudo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsuidperl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXtac\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtail\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXtee\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXtr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtsort\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTuniq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQunzip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bupdatedb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKupdmap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKuptime\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQusers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvmstat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOHw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTwget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKwhatis\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\awhereis\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwhich\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXwho\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKwhoami\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwrite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQxargs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTyacc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXyes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXzip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\azsoelim\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdcop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\akdialog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQkfile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQxhost\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\axmodmap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTxset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\216\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKAlternatePatternValue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKAlternatePatternValue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL}\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFindWord\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFindPattern\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOAlternateValue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOAlternateValue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL}\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFindWord\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USFindPathThenPopInAlternateValue\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKAssign\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKAssign\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL(\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vAssignArray\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aAssign2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aAssign2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aAssign2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL`\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fRegularBackq\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fNormalOption\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vAssignArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vAssignArray\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL#\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aComment\NUL)\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aAssign2\NUL[\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOAssignArrayKey\NUL`\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEAssignArrayBackq\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a&();<>|\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fNormalOption\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEAssignArrayBackq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEAssignArrayBackq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL`\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fNormalOption\NUL#\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCommentBackq\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQStart\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCommand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOAssignArrayKey\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOAssignArrayKey\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL[\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tSubscript\NUL=\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fAssumeEscape\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fAssumeEscape\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SO\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\\\\.\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1AssumeRedirection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1AssumeRedirection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v\SOH>>\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIWordRedirection\SOH>|\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIWordRedirection\SOH>&\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rFdRedirection\SOH>(\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fProcessSubst\NUL>\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIWordRedirection\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX<<<\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1StringRedirection\SOH<<\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aHereDoc\SOH<&\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rFdRedirection\SOH<>\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIWordRedirection\SOH<(\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fProcessSubst\NUL<\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIWordRedirection\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQBaseN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQBaseN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO[0-9a-zA-Z@_]+\SOH\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vBashOneLine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vBashOneLine\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL#\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aComment\SOH((\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNExprDblParenOrSubShell\NUL(\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bSubShell\NUL[\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNMaybeBracketExpression\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nMaybeGroup\NUL`\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCommandBackq\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX&>>\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIWordRedirection\SOH&>\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rFdRedirection\SOH&&\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH||\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX&;|\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL+[A-Za-z_][A-Za-z0-9_]*(?=\\+?=|\\[(?:$|[^]]))\SOH\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tVarAssign\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3\t\n !&()*+,;<=>?\\`|~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbreak\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcontinue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdone\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTelif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTelse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTesac\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXfi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXfor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bfunction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXif\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKreturn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKselect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTthen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQuntil\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwhile\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIDispatchKeyword\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3\t\n !&()*+,;<=>?\\`|~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adeclare\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKexport\NUL\NUL\NUL\NUL\NUL\NUL\NUL\agetopts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlet\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlocal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTread\NUL\NUL\NUL\NUL\NUL\NUL\NUL\breadonly\NUL\NUL\NUL\NUL\NUL\NUL\NUL\atypeset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQunset\NAK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aVarName\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NULc([^*?+!@ \t<>|&;()${'\"`\\\\}=#$]|[+!@](?!\\())([^*?+!@ \t<>|&;()${'\"`\\\\}=$]*+([+!@](?!\\())?+)*+[ \t]*\\(\\)\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN:[ \t]+<<[ \t]*'#([^']+)'$\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3PreHereDocMLComment\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcoproc\NAK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKCoproc\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3\t\n !&()*+,;<=>?\\`|~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL-\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH.\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH:\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQalias\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXbg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbind\NUL\NUL\NUL\NUL\NUL\NUL\NUL\abuiltin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcaller\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXcd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acommand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acompgen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcomplete\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcoproc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdirs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKdisown\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTecho\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKenable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTeval\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTexec\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTexit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXfc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXfg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOThash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOThelp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ahistory\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTjobs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTkill\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlogout\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTpopd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKprintf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpushd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXpwd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQshift\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQshopt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsource\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asuspend\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtest\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtime\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtimes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtrap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtype\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKulimit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQumask\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aunalias\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTwait\NAK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCommandArgs\a\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3\t\n !&()*+,;<=>?\\`|~\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOHf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aaclocal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\baconnect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQaplay\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXapm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bapmsleep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aapropos\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTarch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aarecord\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXas\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTas86\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bautoconf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nautoheader\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bautomake\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXawk\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQb2sum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKbase32\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKbase64\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bbasename\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTbash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXbc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbison\NUL\NUL\NUL\NUL\NUL\NUL\NUL\abunzip2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbzcat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbzcmp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKbzdiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\abzegrep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\abzfgrep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKbzgrep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQbzip2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fbzip2recover\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKbzless\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKbzmore\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXc++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXcc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acd-read\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcdda2wav\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ncdparanoia\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcdrdao\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bcdrecord\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKchattr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQchcon\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTchfn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQchgrp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQchmod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQchown\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKchroot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTchsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTchvt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcksum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQclang\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aclang++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQclear\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQcmake\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcmp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXco\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcol\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcomm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXcp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcpio\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcpp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\acrontab\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKcsplit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXcut\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdcop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdeallocvt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdiff3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXdir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tdircolors\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fdirectomatic\NUL\NUL\NUL\NUL\NUL\NUL\NUL\adirname\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQdmesg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rdnsdomainname\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ndomainname\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXdu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bdumpkeys\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXed\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQegrep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXenv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKexpand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTexpr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfalse\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfbset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tfgconsole\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfgrep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfind\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTflex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKflex++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXfmt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfold\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTfree\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXftp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKfunzip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQfuser\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXg++\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTgawk\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXgc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXgcc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXgdb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKgetent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vgetkeycodes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKgetopt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\agettext\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ngettextize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTgimp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vgimp-remote\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bgimptool\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXgit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQgmake\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTgocr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTgrep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQgroff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKgroups\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXgs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKgunzip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQgzexe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTgzip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOThead\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ahexdump\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKhostid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bhostname\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQiconv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXid\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQigawk\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ainstall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTjoin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bkbd_mode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\akbdrate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\akdialog\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQkfile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\akillall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlast\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlastb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXld\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTld86\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXldd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTless\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlink\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXln\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bloadkeys\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nloadunimap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlocate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\blockfile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlogin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\alogname\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXlp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlpr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXls\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlsattr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlsmod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tlsmod.old\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlynx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlzcat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQlzcmp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlzdiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\alzegrep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\alzfgrep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlzgrep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlzless\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTlzma\NUL\NUL\NUL\NUL\NUL\NUL\NUL\blzmainfo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKlzmore\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXm4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmake\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXman\NUL\NUL\NUL\NUL\NUL\NUL\NUL\amapscrn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmd5sum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmesg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmkdir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmkfifo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmknod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmktemp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTmore\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQmount\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKmsgfmt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXmv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQnamei\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTnano\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTnasm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTnawk\NUL\NUL\NUL\NUL\NUL\NUL\NUL\anetstat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTnice\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rnisdomainname\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXnl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXnm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTnm86\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTnmap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQnohup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXnop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQnproc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQnroff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKnumfmt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXod\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKopenvt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpasswd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpaste\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpatch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apathchk\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpcregrep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpcretest\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTperl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKperror\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpgawk\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpidof\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTping\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpinky\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXpr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bprintenv\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bprocmail\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQprune\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bps2ascii\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aps2epsi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aps2frag\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKps2pdf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQps2ps\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpsbook\NUL\NUL\NUL\NUL\NUL\NUL\NUL\apsmerge\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQpsnup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpsresize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bpsselect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpstops\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKpstree\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXptx\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQqmake\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrbash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrcs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\breadlink\NUL\NUL\NUL\NUL\NUL\NUL\NUL\brealpath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXred\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nresizecons\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXrev\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXrm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrmdir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQrsync\NUL\NUL\NUL\NUL\NUL\NUL\NUL\trun-parts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKruncon\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXscp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsed\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXseq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asetfont\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vsetkeycodes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asetleds\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vsetmetamode\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tsetserial\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asetterm\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\asha1sum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tsha224sum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tsha256sum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tsha384sum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tsha512sum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ashowkey\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQshred\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTshuf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsize\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKsize86\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQskill\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsleep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKslogin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsnice\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsort\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsox\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQsplit\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTssed\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXssh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\assh-add\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tssh-agent\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nssh-keygen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vssh-keyscan\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTstat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKstdbuf\NUL\NUL\NUL\NUL\NUL\NUL\NUL\astrings\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQstrip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTstty\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXsu\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsudo\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bsuidperl\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsum\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXsvn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTsync\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXtac\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtail\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXtar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXtee\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btempfile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\atimeout\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtouch\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtput\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXtr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtroff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTtrue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\btruncate\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQtsort\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXtty\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKumount\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQuname\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bunexpand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\runicode_start\NUL\NUL\NUL\NUL\NUL\NUL\NUL\funicode_stop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTuniq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKunlink\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKunlzma\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTunxz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQunzip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bupdatedb\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKupdmap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKuptime\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQusers\NUL\NUL\NUL\NUL\NUL\NUL\NUL\butmpdump\NUL\NUL\NUL\NUL\NUL\NUL\NUL\auuidgen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bvalgrind\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTvdir\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXvi\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKvmstat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOHw\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTwall\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXwc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTwget\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKwhatis\NUL\NUL\NUL\NUL\NUL\NUL\NUL\awhereis\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwhich\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXwho\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKwhoami\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwrite\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQxargs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bxdg-open\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQxhost\NUL\NUL\NUL\NUL\NUL\NUL\NUL\axmodmap\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTxset\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXxz\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQxzcat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTyacc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXyes\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fypdomainname\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTzcat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTzcmp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQzdiff\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKzegrep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKzfgrep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKzforce\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQzgrep\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXzip\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQzless\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQzmore\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTznew\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXzsh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\azsoelim\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCommandArgs\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f0123456789<>\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBCommandMaybeRedirection\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX)}\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH! \DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCommand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOBraceExpansion\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOBraceExpansion\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL{\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIBraceExpansion2\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIBraceExpansion2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIBraceExpansion2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\NUL,\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL{\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMEscapeMaybeBraceExpansion\NUL\\\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fAssumeEscape\NUL`\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCommandBackq\NUL$\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBBraceExpansionVariables\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFindStrings\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFindPattern\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBBraceExpansionVariables\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBBraceExpansionVariables\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1DispatchVariables\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL$\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOBuiltinGetopts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOBuiltinGetopts\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1BuiltinGetoptsOpt\SO\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCommandArgs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1BuiltinGetoptsOpt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1BuiltinGetoptsOpt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL#\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2BuiltinGetoptsOpt2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2BuiltinGetoptsOpt2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2BuiltinGetoptsOpt2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL:\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1BuiltinGetoptsVar\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\t &();<>`|\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFindWord\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMNormalMaybeBraceExpansion\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r%./0123456789\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fNormalOption\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1BuiltinGetoptsVar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1BuiltinGetoptsVar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\DC1\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCommandArgs\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCommandArgs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nBuiltinLet\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nBuiltinLet\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOBuiltinLetArgs\SO\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCommandArgs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rBuiltinLetArg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rBuiltinLetArg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL#\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOBuiltinLetExpr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOBuiltinLetArgs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOBuiltinLetArgs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n0123456789\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4BuiltinLetArgsNumber\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCommandArgs\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rBuiltinLetArg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4BuiltinLetArgsNumber\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4BuiltinLetArgsNumber\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIFindRedirection\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rBuiltinLetArg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOBuiltinLetExpr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOBuiltinLetExpr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\DC1\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\t &();<>`|\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a%+-/:=^\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n0123456789\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNumber\NUL[\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tSubscript\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFindWord\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL#\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMNormalMaybeBraceExpansion\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fNormalOption\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTCase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTCase\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKCaseIn\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFindWord\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bCaseExpr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bCaseExpr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX;;&\DC3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SOH;;\DC3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SOH;&\DC3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTesac\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQStart\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCommand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKCaseIn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKCaseIn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL(\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCasePattern\NUL#\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aComment\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCasePattern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCasePattern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCasePattern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bCaseExpr\NUL\\\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fAssumeEscape\NUL|\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFindWord\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFindPattern\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTesac\DC3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\DC1\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCheckVarAlt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCheckVarAlt\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\NUL}\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX[@]\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX[*]\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL[\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tSubscript\SOH:-\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOAlternateValue\SOH:=\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOAlternateValue\SOH:?\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOAlternateValue\SOH:+\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOAlternateValue\SOH##\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOAlternateValue\SOH%%\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOAlternateValue\SOH^^\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKAlternatePatternValue\SOH,,\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKAlternatePatternValue\NUL:\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKVarSub\NUL/\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bVarSubst\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK#%+-=?\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOAlternateValue\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX,^\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKAlternatePatternValue\NUL@\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1VarTransformation\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bVarError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tCloseFile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tCloseFile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL-\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCommand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCommand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCommandArgs\NUL$\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLECommandVariables\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFindStrings\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL`\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS(?:[^ \t<>|&;()${'\"`\\\\]++|\\\\.)+\SOH\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCommandName\SO\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBCommandMaybeBraceExpansion\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nCommandArg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nCommandArg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL#\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\SOH--\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nLongOption\NUL-\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vShortOption\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fNormalOption\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBCommandArgMaybeRedirection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBCommandArgMaybeRedirection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIFindRedirection\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fNormalOption\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCommandArgs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCommandArgs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX&>>\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIWordRedirection\SOH&>\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rFdRedirection\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT&;`|\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f0123456789<>\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBCommandArgMaybeRedirection\NUL)\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL(\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bSubShell\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nCommandArg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCommandBackq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCommandBackq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL`\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCommandArgs\NUL#\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCommentBackq\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQStart\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCommand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBCommandMaybeBraceExpansion\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBCommandMaybeBraceExpansion\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNDispatchBraceExpansion\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBCommandMaybeRedirection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBCommandMaybeRedirection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIFindRedirection\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCommand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCommandName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCommandName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCommandArgs\DC1\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL$\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLECommandVariables\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFindStrings\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH&&\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\SOH||\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL|\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX);`\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX&<>\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCommandArgs\SOH((\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fExprDblParen\NUL(\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bSubShell\SO\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBCommandMaybeBraceExpansion\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLECommandVariables\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLECommandVariables\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1DispatchVariables\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL$\SYN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bComments\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCommentBackq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCommentBackq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL`\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aComment\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKCoproc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKCoproc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\170(\\$?[A-Za-z_][A-Za-z0-9_]*|\\$\\{[A-Za-z_][A-Za-z0-9_]*\\}|'[A-Za-z_][A-Za-z0-9_]*'|\"(\\$?[A-Za-z_][A-Za-z0-9_]*|\\$\\{[A-Za-z_][A-Za-z0-9_]*\\}|[a-zA-Z0-9_])+\")+(?=\\s+\\{($|\\s))\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nCoprocName\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nCoprocName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nCoprocName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL{\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQGroup\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFindWord\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNDispatchBraceExpansion\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNDispatchBraceExpansion\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\STXz{(?:[^ \t<>|&;{}\\\\`'\"$,]++|\\\\.|`[^`]*`|'[^']*'|\"([^\"\\`]*+|`[^`]*`)*+\"|\\$(?:\\{[^\\[\\] \t<>|&;{}\\\\`'\"$]*+(?:\\[[*@a-zA-Z0-9]\\])\\})?|\\{[^ \t<>|&;{}\\\\`'\"$,]*+\\}|{(?:[^ \t<>|&;{}\\\\`'\"$,]++|\\\\.|`[^`]*`|'[^']*'|\"([^\"\\`]*+|`[^`]*`)*+\"|\\$(?:\\{[^\\[\\] \t<>|&;{}\\\\`'\"$]*+(?:\\[[*@a-zA-Z0-9]\\])\\})?|\\{[^ \t<>|&;{}\\\\`'\"$,]*+\\})*?}|(?R)?+)*?,(?:[^ \t<>|&;{}\\\\`'\"$]++|\\\\.|`[^`]*`|'[^']*'|\"([^\"\\`]*+|`[^`]*`)*+\"|\\$(?:\\{[^\\[\\] \t<>|&;{}\\\\`'\"$]*+(?:\\[[*@a-zA-Z0-9]\\])\\})?|\\{[^ \t<>|&;{}\\\\`'\"$,]*+\\}|{(?:[^ \t<>|&;{}\\\\`'\"$,]++|\\\\.|`[^`]*`|'[^']*'|\"([^\"\\`]*+|`[^`]*`)*+\"|\\$(?:\\{[^\\[\\] \t<>|&;{}\\\\`'\"$]*+(?:\\[[*@a-zA-Z0-9]\\])\\})?|\\{[^ \t<>|&;{}\\\\`'\"$,]*+\\})*?}|(?R)?+)*?}\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOBraceExpansion\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NULJ{(?=([-+]?[0-9]+\\.\\.[-+]?[0-9]+|[a-zA-Z]\\.\\.[a-zA-Z])(\\.\\.[-+]?[0-9]+)?\\})\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2SequenceExpression\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIDispatchKeyword\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIDispatchKeyword\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SO\SOHif\DC3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aNotCond\SOHfi\DC3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTdone\DC3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SOHdo\DC3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQwhile\DC3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aNotCond\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQuntil\DC3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aNotCond\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXfor\DC3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXFor\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKselect\DC3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXFor\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTcase\DC3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTCase\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bfunction\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFunctionDef\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKreturn\DC3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKReturn\SOHin\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTesac\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\DC1\DC3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBDispatchStringVariables\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBDispatchStringVariables\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SOH$'\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tStringEsc\SOH$\"\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bStringDQ\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNDispatchSubstVariables\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNDispatchSubstVariables\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\SOH${\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rVarBraceStart\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX$((\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USExprDblParenSubstOrSubstCommand\SOH$(\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSubstCommand\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1DispatchVariables\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1DispatchVariables\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNDispatchSubstVariables\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBDispatchStringVariables\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANDispatchVarnameVariables\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANDispatchVarnameVariables\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANDispatchVarnameVariables\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL)\\$(?=[A-Za-z_][A-Za-z0-9_]*|[*@#?$!0-9-])\SOH\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMVarNamePrefixedWithDollar\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMEscapeMaybeBraceExpansion\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMEscapeMaybeBraceExpansion\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNDispatchBraceExpansion\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIBraceExpansion2\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vExprBracket\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vExprBracket\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2FindExprBracketEnd\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOExprBracketNot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEExprBracketFinal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEExprBracketFinal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2FindExprBracketEnd\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI-[ao](?=$|[ \t])\SOH\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vExprBracket\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYN(?:[^] \t]++|\\][^ \t])++\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEExprBracketValue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOExprBracketNot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOExprBracketNot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ExprBracketParam1\SOH! \DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBExprBracketTestMaybeNot\SOH!\t\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBExprBracketTestMaybeNot\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ExprBracketParam1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ExprBracketParam1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ExprBracketParam1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ExprBracketParam2\NUL-\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOTestMaybeUnary\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2FindExprBracketEnd\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEExprBracketValue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ExprBracketParam2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ExprBracketParam2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SO\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nSkipSpaces\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBExprBracketParam2_Value\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBExprBracketParam2_Value\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBExprBracketParam2_Value\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ExprBracketParam3\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX!-=\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SITestMaybeBinary\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2FindExprBracketEnd\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEExprBracketValue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ExprBracketParam3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ExprBracketParam3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SO\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nSkipSpaces\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEExprBracketFinal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBExprBracketParam3_Value\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBExprBracketParam3_Value\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBExprBracketParam3_Value\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEExprBracketFinal\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2FindExprBracketEnd\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEExprBracketFinal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEExprBracketValue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBExprBracketTestMaybeNot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBExprBracketTestMaybeNot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL!\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEExprBracketValue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEExprBracketValue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a&();<>|\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\t \RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFindWord\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMNormalMaybeBraceExpansion\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOFindNormalText\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOExprDblBracket\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOExprDblBracket\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL#\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aComment\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKFindExprDblBracketEnd\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ExprDblBracketNot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL!ExprDblBracketDblParentOrSubValue\NUL\NUL\NUL\NUL\NUL\NUL\NUL!ExprDblBracketDblParentOrSubValue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NULu\\((?=\\(((?:[^`'\"()$]++|\\$\\{[^`'\"(){}$]+\\}|\\$(?=[^{`'\"()])|`[^`]*+`|\\((?1)(?:[)]|(?=['\"])))++)(?:[)](?=$|[^)])|[\"']))|\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNExprDblBracketSubValue\SOH((\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBExprDblBracketExprDblParen\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBExprDblBracketExprDblParen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBExprDblBracketExprDblParen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH))\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEFindExprDblParen\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL)\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBExprDblBracketValuePattern\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3ExprDblBracketFinal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3ExprDblBracketFinal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKFindExprDblBracketEnd\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL#\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aComment\NUL)\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL!(?:[^] \t]++|\\](?:[^]]|\\][^ \t]))++\SOH\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBExprDblBracketValuePattern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ExprDblBracketNot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ExprDblBracketNot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4ExprDblBracketParam1\NUL!\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBExprDblBracketTestMaybeNot\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4ExprDblBracketParam1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4ExprDblBracketParam1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4ExprDblBracketParam1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4ExprDblBracketParam2\NUL-\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SITestMaybeUnary2\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX<>\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBExprDblBracketParam3Spe\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKFindExprDblBracketEnd\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBExprDblBracketValueText\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4ExprDblBracketParam2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4ExprDblBracketParam2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SO\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nSkipSpaces\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBExprDblBracketParam2_Value\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBExprDblBracketParam2_Value\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBExprDblBracketParam2_Value\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4ExprDblBracketParam3\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX!-=\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLETestMaybeBinary2\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX<>\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBExprDblBracketParam3Spe\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKFindExprDblBracketEnd\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL#\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aComment\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBExprDblBracketValuePattern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4ExprDblBracketParam3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4ExprDblBracketParam3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SO\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nSkipSpaces\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBExprDblBracketParam3_Value\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBExprDblBracketParam3Spe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBExprDblBracketParam3Spe\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4ExprDblBracketParam3\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4ExprDblBracketParam3\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBExprDblBracketParam3_Value\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBExprDblBracketParam3_Value\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3ExprDblBracketFinal\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKFindExprDblBracketEnd\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX<>\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL#\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aComment\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBExprDblBracketValuePattern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3ExprDblBracketRegex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3ExprDblBracketRegex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANExprDblBracketRegexCheck\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANExprDblBracketRegexCheck\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANExprDblBracketRegexCheck\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANExprDblBracketRegexCheck\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL#\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aComment\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQRegex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNExprDblBracketSubRegex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNExprDblBracketSubRegex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\DC1\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL)\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SOH[^\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fRegexSubChar\NUL[\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fRegexSubChar\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tFindRegex\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNExprDblBracketSubValue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNExprDblBracketSubValue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL(\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ExprDblBracketNot\SOH]]\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBExprDblBracketTestMaybeNot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBExprDblBracketTestMaybeNot\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f!(?=$|[ \t(])\SOH\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4ExprDblBracketParam1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3ExprDblBracketUnary\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3ExprDblBracketUnary\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBExprDblBracketValueText\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMExprDblBracketValueCommon\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMExprDblBracketValueCommon\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\SOH((\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL!ExprDblBracketDblParentOrSubValue\NUL(\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNExprDblBracketSubValue\NUL)\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\SOH&&\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOExprDblBracket\SOH||\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOExprDblBracket\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX&;|\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\t <>\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFindWord\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBExprDblBracketValueExtGlob\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBExprDblBracketValueExtGlob\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL)\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL(\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL ExprDblBracketValueExtGlobNormal\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSFindExprDblBracketValueExtGlob\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX*?|\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFindWord\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL ExprDblBracketValueExtGlobNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL ExprDblBracketValueExtGlobNormal\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL)\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL(\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL ExprDblBracketValueExtGlobNormal\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSFindExprDblBracketValueExtGlob\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX*?\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFindWord\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USExprDblBracketValueMaybeGlobAny\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USExprDblBracketValueMaybeGlobAny\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFindGlobAny\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL[\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBExprDblBracketValuePattern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBExprDblBracketValuePattern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\ACK\NUL\NUL\NUL\NUL\NUL\NUL\SOH\186/|(~|\\.\\.?)($|[/ \t<>|&;)])|([^?*+!@ \t<>|&;()'\"`\\\\/]++|\\\\.|(?:'[^']*+'|\"(?:[^\"\\\\`]*+|`[^`]*+`|\\\\.)*+\"|`[^`]*+`)|\\[(?:[^ \t<>|&;()\"'`\\\\\\[\\]]+|\\\\.|(?:'[^']*+'|\"(?:[^\"\\\\`]*+|`[^`]*+`|\\\\.)*+\"|`[^`]*+`)|\\[:\\w+:\\]|\\[)*\\]|[?*+](?!\\()|[?*+!@]\\(([^?*+!@()'\"`\\\\/]++|\\\\.|(?:'[^']*+'|\"(?:[^\"\\\\`]*+|`[^`]*+`|\\\\.)*+\"|`[^`]*+`)|\\[(?:[^ \t<>|&;()\"'`\\\\\\[\\]]+|\\\\.|(?:'[^']*+'|\"(?:[^\"\\\\`]*+|`[^`]*+`|\\\\.)*+\"|`[^`]*+`)|\\[:\\w+:\\]|\\[)*\\]|[?*+](?!\\())*+(\\)|(?=/)))*+/|\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vPathThenPop\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCExprDblBracketValuePattern2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCExprDblBracketValuePattern2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCExprDblBracketValuePattern2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMExprDblBracketValueCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSFindExprDblBracketValueExtGlob\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX*?\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBExprDblBracketValueText\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBExprDblBracketValueText\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\SOH]]\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USExprDblBracketValueTextMaybeEnd\NUL#\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aComment\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USFindExprDblBracketValueTextPath\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANExprDblBracketValueText2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANExprDblBracketValueText2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANExprDblBracketValueText2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f!%*+,-/:?@^~\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMExprDblBracketValueCommon\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USExprDblBracketValueTextMaybeEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USExprDblBracketValueTextMaybeEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4\\]\\](?=($|[ \t;|&)]))\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USFindExprDblBracketValueTextPath\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH]]\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANExprDblBracketValueText2\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCExprDblBracketValueTextPath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCExprDblBracketValueTextPath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANExprDblBracketValueText2\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fExprDblParen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fExprDblParen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH))\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEFindExprDblParen\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bSubShell\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNExprDblParenOrSubShell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNExprDblParenOrSubShell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NULu\\((?=\\(((?:[^`'\"()$]++|\\$\\{[^`'\"(){}$]+\\}|\\$(?=[^{`'\"()])|`[^`]*+`|\\((?1)(?:[)]|(?=['\"])))++)(?:[)](?=$|[^)])|[\"']))|\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bSubShell\SOH((\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fExprDblParen\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ExprDblParenSubst\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ExprDblParenSubst\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH))\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEFindExprDblParen\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL)\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSubstCommand\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USExprDblParenSubstOrSubstCommand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USExprDblParenSubstOrSubstCommand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NULw\\$\\((?=\\(((?:[^`'\"()$]++|\\$\\{[^`'\"(){}$]+\\}|\\$(?=[^{`'\"()])|`[^`]*+`|\\((?1)(?:[)]|(?=['\"])))++)(?:[)](?=$|[^)])|[\"']))|\SOH\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSubstCommand\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX$((\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ExprDblParenSubst\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIExprSubDblParen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIExprSubDblParen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL)\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEFindExprDblParen\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rExtGlobAndPop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rExtGlobAndPop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL)\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vPathThenPop\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFindWord\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nIncExtGlob\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSExtGlobAndPopInAlternateValue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSExtGlobAndPopInAlternateValue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL)\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL}\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFindWord\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCFindExtGlobInAlternateValue\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nExtPattern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nExtPattern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DC1\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL|\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFindWord\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL)\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFindPattern\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rFdRedirection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rFdRedirection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL#\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aComment\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOFdRedirection2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOFdRedirection2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOFdRedirection2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\FS[0-9]+(?=-?(?=$|[ \t<>|&;)]))\SOH\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tCloseFile\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEWordRedirection2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2FindExprBracketEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2FindExprBracketEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SO\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4\\](?=($|[ \t;|&<>)]))\SOH\NAK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKFindExprDblBracketEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKFindExprDblBracketEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\SO\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH&&\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOExprDblBracket\SOH||\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOExprDblBracket\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4\\]\\](?=($|[ \t;|&)]))\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSFindExprDblBracketValueExtGlob\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSFindExprDblBracketValueExtGlob\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\SOH?(\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBExprDblBracketValueExtGlob\SOH*(\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBExprDblBracketValueExtGlob\SOH+(\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBExprDblBracketValueExtGlob\SOH@(\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBExprDblBracketValueExtGlob\SOH!(\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBExprDblBracketValueExtGlob\NUL[\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USExprDblBracketValueMaybeGlobAny\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USFindExprDblBracketValueTextPath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USFindExprDblBracketValueTextPath\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\ACK\NUL\NUL\NUL\NUL\NUL\NUL\SOH\186/|(~|\\.\\.?)($|[/ \t<>|&;)])|([^?*+!@ \t<>|&;()'\"`\\\\/]++|\\\\.|(?:'[^']*+'|\"(?:[^\"\\\\`]*+|`[^`]*+`|\\\\.)*+\"|`[^`]*+`)|\\[(?:[^ \t<>|&;()\"'`\\\\\\[\\]]+|\\\\.|(?:'[^']*+'|\"(?:[^\"\\\\`]*+|`[^`]*+`|\\\\.)*+\"|`[^`]*+`)|\\[:\\w+:\\]|\\[)*\\]|[?*+](?!\\()|[?*+!@]\\(([^?*+!@()'\"`\\\\/]++|\\\\.|(?:'[^']*+'|\"(?:[^\"\\\\`]*+|`[^`]*+`|\\\\.)*+\"|`[^`]*+`)|\\[(?:[^ \t<>|&;()\"'`\\\\\\[\\]]+|\\\\.|(?:'[^']*+'|\"(?:[^\"\\\\`]*+|`[^`]*+`|\\\\.)*+\"|`[^`]*+`)|\\[:\\w+:\\]|\\[)*\\]|[?*+](?!\\())*+(\\)|(?=/)))*+/|\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCExprDblBracketValueTextPath\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEFindExprDblParen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEFindExprDblParen\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v\SOH&&\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH||\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI!%&*+-/:<=>?^|~\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n0123456789\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNumber\NUL,\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL(\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIExprSubDblParen\NUL[\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tSubscript\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFindWord\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL#\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4MaybeArithmeticBrace\DC1\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFindExtGlob\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFindExtGlob\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\SOH?(\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLERecursiveExtGlob\SOH*(\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLERecursiveExtGlob\SOH+(\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLERecursiveExtGlob\SOH@(\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLERecursiveExtGlob\SOH!(\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLERecursiveExtGlob\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX*?|\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCFindExtGlobInAlternateValue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCFindExtGlobInAlternateValue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH?(\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL RecursiveExtGlobInAlternateValue\SOH*(\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL RecursiveExtGlobInAlternateValue\SOH+(\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL RecursiveExtGlobInAlternateValue\SOH@(\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL RecursiveExtGlobInAlternateValue\SOH!(\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL RecursiveExtGlobInAlternateValue\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX*?|\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOFindGlobAndPop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOFindGlobAndPop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\SOH?(\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rExtGlobAndPop\SOH*(\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rExtGlobAndPop\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX*?\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vPathThenPop\SOH+(\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rExtGlobAndPop\SOH@(\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rExtGlobAndPop\SOH!(\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rExtGlobAndPop\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFindGlobAny\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFindGlobAny\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\\[(?=(?:\\^?\\]\\]|(?:\\^?\\]?)?(?:\\\\.|[^'\" \t<>|&;()\\\\[\\]]+|(?:'[^']*+'|\"(?:[^\"\\\\`]*+|`[^`]*+`|\\\\.)*+\"|`[^`]*+`)|\\[:\\w+:\\])+\\]))\SOH\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vGlobAnyFlag\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOFindNormalText\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOFindNormalText\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOFindGlobAndPop\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\SOH\190(?:~|\\.\\.?|(?:[^*?+!@ \t<>|&;()${'\"`\\\\\\[/]*+(?:[+!@](?!\\()|\\\\.|\\{[^ \t<>|&;{}\\\\`'\"$,]*+\\})?+)*+)(?:/(?:[^*?+!@ \t<>|&;()${'\"`\\\\\\[]*+(?:[+!@](?!\\()|\\\\.|\\{[^ \t<>|&;{}\\\\`'\"$,]*+\\})?+)*+|(?=[*?]|[+!@]\\(|(?:[^*?+!@ \t<>|&;()${'\"`\\\\\\[/]*+(?:[+!@](?!\\()|\\\\.|\\{[^ \t<>|&;{}\\\\`'\"$,]*+\\})?+)*+(?:[/*?]|\\[(?:\\^?\\]\\]|(?:\\^?\\]?)?(?:\\\\.|[^'\" \t<>|&;()\\\\[\\]]+|(?:'[^']*+'|\"(?:[^\"\\\\`]*+|`[^`]*+`|\\\\.)*+\"|`[^`]*+`)|\\[:\\w+:\\])+\\])|[+!@]\\()))|(?:~|\\.\\.?)(?=[ \t<>|&;()]|$)\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vPathThenPop\NUL[\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCFindPathThenPopMaybeGlobAny\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYN[^ \t<>|&;()${'\"`\\\\\\[]+\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEFindOneLineBackq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEFindOneLineBackq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL`\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fOneLineBackq\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USFindPathThenPopInAlternateValue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\USFindPathThenPopInAlternateValue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL&\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH?(\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCPathThenPopInAlternateValue\SOH*(\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCPathThenPopInAlternateValue\SOH+(\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCPathThenPopInAlternateValue\SOH@(\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCPathThenPopInAlternateValue\SOH!(\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCPathThenPopInAlternateValue\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX*?\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCPathThenPopInAlternateValue\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\209(?:~|\\.\\.?|(?:[^*?+!@${'\"`\\\\}/]*+(?:[+!@](?!\\()|\\\\.)?+)*+)(?:/(?:[^*?+!@${'\"`\\\\}]*+(?:[+!@](?!\\()|\\\\.)?+)*+|(?=[*?]|[+!@]\\(|(?:[^*?+!@${'\"`\\\\}/]*+(?:[+!@](?!\\()|\\\\.)?+)*+(?:[/*?]|[+!@]\\()))|(?:~|\\.\\.?)(?=\\}|$)\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCPathThenPopInAlternateValue\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCFindPathThenPopMaybeGlobAny\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCFindPathThenPopMaybeGlobAny\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFindGlobAny\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL[\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vPathThenPop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFindPattern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFindPattern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\SOH?(\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nExtPattern\SOH*(\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nExtPattern\SOH+(\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nExtPattern\SOH@(\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nExtPattern\SOH!(\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nExtPattern\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX*?\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIFindRedirection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIFindRedirection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI[0-9]++(?=[<>])\SOH\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1AssumeRedirection\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1AssumeRedirection\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tFindRegex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tFindRegex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL(\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNExprDblBracketSubRegex\NUL\\\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vRegexEscape\NUL{\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bRegexDup\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK*+.?^|\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFindStrings\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL$\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNRegexDispatchVariables\NUL`\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fRegularBackq\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFindStrings\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFindStrings\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL'\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bStringSQ\NUL\"\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bStringDQ\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFindWord\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFindWord\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFindStrings\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL$\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIRegularVariable\NUL`\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fRegularBackq\NUL\\\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fAssumeEscape\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXFor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXFor\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\SO\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQForIn\SOH((\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ForArithmeticExpr\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ForArithmeticExpr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ForArithmeticExpr\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL;\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH))\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEFindExprDblParen\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQForIn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQForIn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL;\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ENQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STXin\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCommandArgs\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFunctionDef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFunctionDef\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NULm[ \t]+([^*?+!@ \t<>|&;()${'\"`\\\\}=#$]|[+!@](?!\\())([^*?+!@ \t<>|&;()${'\"`\\\\}=$]*+([+!@](?!\\())?+)*+(?:[ \t]*\\(\\))?\SOH\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aGlobAny\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aGlobAny\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\DC1\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\\\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fAssumeEscape\NUL-\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFindStrings\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL]\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SOH[:\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tGlobClass\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vGlobAnyFlag\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vGlobAnyFlag\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL^\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aGlobAny\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aGlobAny\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tGlobClass\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tGlobClass\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DC1\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH:]\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL]\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQGroup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQGroup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rMaybeGroupEnd\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQStart\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCommand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aHereDoc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aHereDoc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETB[ \t]*<<[ \t]*'#([^']+)'$\SOH\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHereDocMLComment\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NULC<<-[ \t]*(?|\"([^\"]+)\"|'([^']+)'|\\\\(.[^ \t<>|&;()${'\"`\\\\]*))(?=[ \t]*$)\SOH\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tHereDocIQ\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL!<<-[ \t]*([^ \t<>|&;()]+)(?=[ \t]*$)\SOH\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nHereDocINQ\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NULB<<[ \t]*(?|\"([^\"]+)\"|'([^']+)'|\\\\(.[^ \t<>|&;()${'\"`\\\\]*))(?=[ \t]*$)\SOH\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bHereDocQ\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL <<[ \t]*([^ \t<>|&;()]+)(?=[ \t]*$)\SOH\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tHereDocNQ\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL;(<<-[ \t]*(?|\"([^\"]+)\"|'([^']+)'|\\\\(.[^ \t<>|&;()${'\"`\\\\]*)))\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fHereDocIQCmd\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EM(<<-[ \t]*([^ \t<>|&;()]+))\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rHereDocINQCmd\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL:(<<[ \t]*(?|\"([^\"]+)\"|'([^']+)'|\\\\(.[^ \t<>|&;()${'\"`\\\\]*)))\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vHereDocQCmd\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN(<<[ \t]*([^ \t<>|&;()]+))\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fHereDocNQCmd\SOH<<\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nHereDocCmd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nHereDocCmd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX%1\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vBashOneLine\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX%1\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHereDocRemainder\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nHereDocINQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nHereDocINQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tHereDocIQ\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HereDocSubstitutions\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rHereDocINQCmd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rHereDocINQCmd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fHereDocIQCmd\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HereDocSubstitutions\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tHereDocIQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tHereDocIQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\\t*%1$\SOH\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vHereDocText\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fHereDocIQCmd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fHereDocIQCmd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nHereDocCmd\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\\t*%2$\SOH\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vHereDocText\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHereDocMLComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHereDocMLComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT#%1$\SOH\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE#?\\[(=*)\\[\\.rst:\SOH\EM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1RST Documentation\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aComment\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aComment\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tHereDocNQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tHereDocNQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bHereDocQ\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HereDocSubstitutions\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fHereDocNQCmd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fHereDocNQCmd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vHereDocQCmd\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HereDocSubstitutions\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bHereDocQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bHereDocQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX%1$\SOH\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vHereDocText\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vHereDocQCmd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vHereDocQCmd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nHereDocCmd\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX%2$\SOH\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vHereDocText\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHereDocRemainder\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHereDocRemainder\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT&;`|\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vBashOneLine\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCommandArgs\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nCommandArg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HereDocSubstitutions\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4HereDocSubstitutions\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\DLE\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL$\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHereDocVariables\NUL`\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCommandBackq\NUL\\\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fAssumeEscape\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vHereDocText\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vHereDocText\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHereDocVariables\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHereDocVariables\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNDispatchSubstVariables\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANDispatchVarnameVariables\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL$\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nIncExtGlob\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nIncExtGlob\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFindExtGlob\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBPathMaybeBraceExpansion\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nLongOption\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nLongOption\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\t &();<>`|\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL=\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fNormalOption\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFindWord\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOFindGlobAndPop\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMOptionMaybeBraceExpansion\NUL[\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNLongOptionMaybeGlobAny\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NULS(?:[^*?+!@ \t<>|&;()${'\"`\\\\\\[=/]*+(?:[+!@](?!\\()|\\\\.|\\{[^ \t<>|&;{}\\\\`'\"$,]*+\\})?+)*+\SOH\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNLongOptionMaybeGlobAny\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNLongOptionMaybeGlobAny\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFindGlobAny\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL[\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4MaybeArithmeticBrace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4MaybeArithmeticBrace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNDispatchBraceExpansion\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNMaybeBracketExpression\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNMaybeBracketExpression\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\\[\\[(?=$|[ \t(])\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOExprDblBracket\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\\[(?=$|[ \t])\SOH\NAK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vExprBracket\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCommand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nMaybeGroup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nMaybeGroup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\\{(?=$|[ \t])\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQGroup\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCommand\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rMaybeGroupEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rMaybeGroupEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2\\}(?=$|[ \t<>|&;)])\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCommand\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMNormalMaybeBraceExpansion\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMNormalMaybeBraceExpansion\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNDispatchBraceExpansion\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fNormalOption\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fNormalOption\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\t &();<>`|\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFindWord\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMNormalMaybeBraceExpansion\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOFindNormalText\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aNotCond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aNotCond\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNotCond2\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNotCond2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bNotCond2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\SOH!\t\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SOH! \DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SO\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNumber\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKNumber\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\v\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\n\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vNumberError\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f[1-9][0-9]*#\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQBaseN\NUL0\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vNumberError\b\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vNumberError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vNumberError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\b\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fOneLineBackq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fOneLineBackq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL`\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQStart\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCommand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMOptionMaybeBraceExpansion\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMOptionMaybeBraceExpansion\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNDispatchBraceExpansion\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBPathMaybeBraceExpansion\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBPathMaybeBraceExpansion\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNDispatchBraceExpansion\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vPathThenPop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vPathThenPop\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\t &();<>`|\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFindWord\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFindExtGlob\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL{\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBPathMaybeBraceExpansion\NUL[\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBPathThenPopMaybeGlobAny\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NULQ(?:[^*?+!@ \t<>|&;()${'\"`\\\\\\[]*+(?:[+!@](?!\\()|\\\\.|\\{[^ \t<>|&;{}\\\\`'\"$,]*+\\})?+)*+\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCPathThenPopInAlternateValue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCPathThenPopInAlternateValue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\t\NUL}\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFindWord\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH?(\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSExtGlobAndPopInAlternateValue\SOH*(\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSExtGlobAndPopInAlternateValue\SOH+(\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSExtGlobAndPopInAlternateValue\SOH@(\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSExtGlobAndPopInAlternateValue\SOH!(\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\GSExtGlobAndPopInAlternateValue\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX*?\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL-(?:[^*?+!@${'\"`\\\\}]*+(?:[+!@](?!\\()|\\\\.)?+)*+\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBPathThenPopMaybeGlobAny\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBPathThenPopMaybeGlobAny\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFindGlobAny\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL[\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3PreHereDocMLComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3PreHereDocMLComment\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL:\NAK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2<<[ \t]*'#([^']+)'$\SOH\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEHereDocMLComment\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fProcessSubst\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fProcessSubst\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL)\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQStart\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCommand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1RST Documentation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1RST Documentation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI#BLOCK-COMMENT$\SOH\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b#?\\]%1\\]\SOH\EM\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEreStructuredText\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLERecursiveExtGlob\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLERecursiveExtGlob\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL)\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFindWord\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nIncExtGlob\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBPathThenPopMaybeGlobAny\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL RecursiveExtGlobInAlternateValue\NUL\NUL\NUL\NUL\NUL\NUL\NUL RecursiveExtGlobInAlternateValue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL)\ETB\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL}\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFindWord\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ESCFindExtGlobInAlternateValue\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQRegex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQRegex\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\DC1\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3ExprDblBracketFinal\NUL)\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SOH[^\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tRegexChar\NUL[\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tRegexChar\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tFindRegex\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tRegexChar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tRegexChar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX-]\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vRegexInChar\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vRegexInChar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SORegexCharClass\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SORegexCharClass\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DC1\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH:]\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL]\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4RegexCharClassSelect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4RegexCharClassSelect\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\SOH[:\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SORegexCharClass\SOH[.\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKRegexCollatingSymbols\SOH[=\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKRegexEquivalenceClass\NUL[\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKRegexCollatingSymbols\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKRegexCollatingSymbols\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DC1\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH.]\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL]\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNRegexDispatchVariables\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNRegexDispatchVariables\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1DispatchVariables\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL$\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bRegexDup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bRegexDup\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\b\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL,\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKRegexEquivalenceClass\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKRegexEquivalenceClass\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DC1\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH=]\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL]\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vRegexEscape\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vRegexEscape\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RSx[0-9a-fA-F]{1,2}|[0-7]{1,3}|.\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vRegexInChar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vRegexInChar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\SOH-]\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SORegexInCharEnd\NUL-\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\\\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vRegexEscape\NUL[\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4RegexCharClassSelect\NUL]\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\t ()\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFindStrings\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SORegexInCharEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SORegexInCharEnd\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL-\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL]\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fRegexSubChar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fRegexSubChar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX-]\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SORegexSubInChar\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SORegexSubInChar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SORegexSubInChar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SORegexSubInChar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vRegexInChar\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fRegularBackq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fRegularBackq\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL`\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL#\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fCommentBackq\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQStart\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCommand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIRegularVariable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIRegularVariable\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1DispatchVariables\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL$\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKReturn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKReturn\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2SequenceExpression\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2SequenceExpression\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f+-0123456789\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH..\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL}\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vShortOption\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vShortOption\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL/\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vPathThenPop\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nLongOption\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nSkipSpaces\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nSkipSpaces\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQStart\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQStart\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vBashOneLine\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCommand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bStringDQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bStringDQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\DLE\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\\\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOStringDQEscape\NUL$\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMStringDQDispatchVariables\NUL`\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fRegularBackq\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMStringDQDispatchVariables\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMStringDQDispatchVariables\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SYNDispatchSubstVariables\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\CANDispatchVarnameVariables\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL$\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOStringDQEscape\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOStringDQEscape\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\SOH\\\"\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SOH\\\\\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SOH\\`\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SOH\\$\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SO\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\\\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tStringEsc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tStringEsc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\DLE\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL'\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NULZ\\\\(?:[abeEfnrtv\\\\'\"?]|[0-7]{1,3}|x[A-Fa-f0-9]{1,2}|u[A-Fa-f0-9]{1,4}|U[A-Fa-f0-9]{1,8}|c.)\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1StringRedirection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1StringRedirection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL#\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aComment\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2StringRedirection2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2StringRedirection2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2StringRedirection2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\t &();<>`|\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFindWord\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bStringSQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bStringSQ\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\DLE\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL'\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\b\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bSubShell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bSubShell\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQStart\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCommand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tSubscript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tSubscript\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL]\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n0123456789\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nSubscript2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nSubscript2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nSubscript2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\DC1\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL]\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFindWord\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFindPattern\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1SubstBraceCommand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1SubstBraceCommand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQStart\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCommand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSubstCommand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fSubstCommand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL)\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQStart\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aCommand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SITestMaybeBinary\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SITestMaybeBinary\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL1(?:-(?:e[fq]|[nolg]t|[nlg]e)|==?|!=)(?=\\\\?$|[ \t])\SOH\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEExprBracketValue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLETestMaybeBinary2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLETestMaybeBinary2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SITestMaybeBinary\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v=~(?=[ \t(])\SOH\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3ExprDblBracketRegex\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SUBExprDblBracketValuePattern\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOTestMaybeUnary\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOTestMaybeUnary\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NUL*-[abcdefghkprstuwxGLNOSovRnz](?=\\\\?$|[ \t])\SOH\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1ExprBracketParam2\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEExprBracketValue\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SITestMaybeUnary2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SITestMaybeUnary2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NULi-[abcdefghkprstuwxGLNOSovRnz](?=\\\\?$|[ \t])(?!\\s+(?:=~|(?:-(?:e[fq]|[nolg]t|[nlg]e)|==?|!=)(?=\\\\?$|[ \t])))\SOH\DLE\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3ExprDblBracketUnary\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETBExprDblBracketValueText\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tVarAssign\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tVarAssign\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\NUL[\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tSubscript\NUL=\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKAssign\SOH+=\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKAssign\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bVarBrace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bVarBrace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL}\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\DC1\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCheckVarAlt\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK!$*-?@\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCheckVarAlt\b\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCheckVarAlt\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bVarError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOVarBracePrefix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOVarBracePrefix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\DC1\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4VarBracePrefixSuffix\b\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4VarBracePrefixSuffix\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX#*@\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3VarBracePrefixSharp\NUL}\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3VarBracePrefixSharp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC3VarBracePrefixSharp\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL#\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bVarError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4VarBracePrefixSuffix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC4VarBracePrefixSuffix\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL}\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX*@\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX[@]\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX[*]\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bVarError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rVarBraceStart\NUL\NUL\NUL\NUL\NUL\NUL\NUL\rVarBraceStart\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQ\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX!}\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bVarBrace\NUL!\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOVarBracePrefix\NUL#\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bVarBrace\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1SubstBraceCommand\NUL|\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1SubstBraceCommand\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1SubstBraceCommand\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bVarBrace\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bVarError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bVarError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL}\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aVarName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aVarName\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\agetopts\NAK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOBuiltinGetopts\EOT\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETXlet\NAK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nBuiltinLet\DC1\NAK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVarNameArgs\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX.:\NAK\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVarNameArgs\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nVarNameArg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nVarNameArg\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL#\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL-\CAN\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vShortOption\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVarNameArg2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVarNameArg2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVarNameArg2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT\NUL[\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\tSubscript\NUL=\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKAssign\NUL(\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vAssignArray\DC1\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fNormalOption\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVarNameArgs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVarNameArgs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nVarNameArg\SO\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vCommandArgs\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMVarNamePrefixedWithDollar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EMVarNamePrefixedWithDollar\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DC1\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1!#$*-0123456789?@\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKVarSub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACKVarSub\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a\NUL}\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n0123456789\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL:\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL$\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fVarVariables\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vFindStrings\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL`\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fRegularBackq\NUL\\\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fAssumeEscape\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bVarSubst\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bVarSubst\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX#%/\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVarSubstPat\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVarSubstPat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVarSubstPat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vVarSubstPat\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL/\DC4\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOAlternateValue\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NAKAlternatePatternValue\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1VarTransformation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1VarTransformation\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL}\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\nAEKLPQUaku\DC2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bVarError\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fVarVariables\NUL\NUL\NUL\NUL\NUL\NUL\NUL\fVarVariables\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DC1DispatchVariables\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL$\GS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\DC1\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIWordRedirection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SIWordRedirection\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\DLE\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL#\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\aComment\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEWordRedirection2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEWordRedirection2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\DLEWordRedirection2\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ETX\STX\NUL\NUL\NUL\NUL\NUL\NUL\NUL\n\t &();<>`|\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\SI\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bFindWord\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK\NUL\NUL\NUL\NUL\NUL\NUL\NULQ(?:[^*?+!@ \t<>|&;()${'\"`\\\\\\[]*+(?:[+!@](?!\\()|\\\\.|\\{[^ \t<>|&;{}\\\\`'\"$,]*+\\})?+)*+\SOH\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTBash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\vPathThenPop\RS\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\SOH\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\"Wilbert Berendsen (wilbert@kde.nl)\NUL\NUL\NUL\NUL\NUL\NUL\NUL\STX54\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOTLGPL\NUL\NUL\NUL\NUL\NUL\NUL\NUL\f\NUL\NUL\NUL\NUL\NUL\NUL\NUL\EOT*.sh\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ACK*.bash\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b*.ebuild\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b*.eclass\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a*.exlib\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v*.exheres-0\NUL\NUL\NUL\NUL\NUL\NUL\NUL\a.bashrc\NUL\NUL\NUL\NUL\NUL\NUL\NUL\r.bash_profile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\v.bash_login\NUL\NUL\NUL\NUL\NUL\NUL\NUL\b.profile\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bPKGBUILD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\bAPKBUILD\NUL\NUL\NUL\NUL\NUL\NUL\NUL\ENQStart"
